-- ============================================================================
--
--   NAME
--      gisinst.sql
--
--   DESCRIPTION
--      Control  script for creating the Global Imaging Application v2
--	(GIS)
--
--   HISTORY
--      29/09/2000 David Gough Original version
--
-- ============================================================================

set echo off
set verify off
set serverout on
set heading off

accept apps_usr prompt        'Enter APPS User-name           : ' 
accept apps_pwd prompt        'Enter APPS password            : ' hide
accept applsys_usr prompt     'Enter APPLSYS User-name        : ' 
accept applsys_pwd prompt     'Enter APPLSYS password         : ' hide
accept img_usr prompt         'Enter IMG User-name            : '
accept img_pwd prompt         'Enter IMG password             : ' hide 
accept table_t prompt         'Enter IMG tablespace           : '
accept table_i prompt         'Enter IMG Index Tablespace     : '
accept applsys_table_i prompt 'Enter APPLSYS Index Tablespace : '

PROMPT     Press <return> to continue or <ctrl-c> to exit.;
pause

---------------------------------------------------------------------------
--  Create log file and check passwords                                   -
---------------------------------------------------------------------------
spool gisinst.log

SELECT 'gisinst log file : '||
          to_char(SYSDATE, 'DD-MON-YY HH24:MI.SS')
FROM   sys.dual;


WHENEVER SQLERROR EXIT FAILURE ROLLBACK;

connect &&apps_usr/&&apps_pwd
SELECT  'APPS password correct.'
FROM    dual;

connect &&applsys_usr/&&applsys_pwd
SELECT  'APPLSYS password correct.'
FROM    dual;

connect &&img_usr/&&img_pwd
SELECT  'IMG password correct.'
FROM    dual;

WHENEVER SQLERROR CONTINUE

connect &&apps_usr/&&apps_pwd
-------------------------------------------------------------------------------
--
-- Register the application
--
------------------------------------------------------------------------------- 
@gis_register_application

-------------------------------------------------------------------------------
--                                                                            -
--  Register this version of software                                         -
--                                                                            -
-------------------------------------------------------------------------------

PROMPT
PROMPT  Updating FND_Product_Installations ....
PROMPT

Declare
--
  v_app_name            glob_apps.app_name%type         := 'IMAGING' ;
  v_app_version         glob_apps.app_version%type      := '2.0.0' ;
  v_app_description     glob_apps.app_description%type  := 'Global Imaging v2 new product' ;
  v_app_enabled         glob_apps.app_enabled_flag%type := 'Y' ;
  v_app_disable_flag    varchar2(1)                     := 'Y' ;
  v_version_exists      varchar2(1)                     := 'N' ;
  v_product_exists      varchar2(1)                     := 'N' ;
--
  cursor version_exists is
    select 'Y'
    from   glob_apps
    where  app_name    = v_app_name
    and    app_version = v_app_version ; 
    
  cursor product_exists is
    select 'Y'
    from fnd_product_installations
    where application_id  =
         	(SELECT  application_id
          	FROM    fnd_application
          	WHERE   application_short_name = 'IMAGING') ;
--
Begin
  /*
   * Do we need to disble any previous versions of this application ?
   */
  if upper(v_app_disable_flag) = 'Y'
  then
    update      glob_apps
    set         app_enabled_flag = 'N'
    where       app_name = v_app_name
    and         app_version <> v_app_version ;
  end if ;
  /*
   * Check to see if Application already regsitered
   */
  open  version_exists ;
  fetch version_exists into v_version_exists ;
  close version_exists ;
  /*
   * If it does not exist, the we need to insert it . Otherwise
   * we want to udpate it
   */
  if v_version_exists <> 'Y'
  then
    insert into glob_apps
       (app_name,
        app_enabled_flag,
        app_description,
        app_installed_date,
        app_version,
        app_mandatory_use_flag)
    values
       (v_app_name,
        upper(v_app_enabled),
        v_app_description,
        sysdate,
        v_app_version,
        'Y') ;
  else
    update glob_apps
        set app_enabled_flag = upper(v_app_enabled)
    where  app_name          = v_app_name
    and    app_version       = v_app_version ;
  end if ;

  /*
   * Check to see if product installation exists
   */
  open  product_exists ;
  fetch product_exists into v_product_exists ;
  close product_exists ;
  /*
   * If it does not exist, the we need to insert it . Otherwise
   * we want to udpate it
   */
  if v_product_exists <> 'Y'
  then 
  	insert into fnd_product_installations
		(APPLICATION_ID
		,ORACLE_ID
		,LAST_UPDATE_DATE
		,LAST_UPDATED_BY
		,CREATION_DATE
		,CREATED_BY
		,LAST_UPDATE_LOGIN
		,PRODUCT_VERSION
		,STATUS
		,INDUSTRY
		,TABLESPACE
		,INDEX_TABLESPACE
		,TEMPORARY_TABLESPACE
		,SIZING_FACTOR
		,DB_STATUS
		,INSTALL_GROUP_NUM)
		SELECT  apps.application_id,
				ora.oracle_id,
				sysdate,
				1,
				sysdate,
				1,
				1,
				'2.0',
				'I',
				'C',
				null,
				null,
				null,
				null,
				'l',
				1
		FROM    fnd_application apps,
				FND_ORACLE_USERID  ora
		WHERE   apps.application_short_name = 'IMAGING'
		and     apps.application_short_name = ora.oracle_username;
	else  
 		UPDATE fnd_product_installations
  		SET    last_update_date = SYSDATE,
               product_version  = '2.0'
  		WHERE  application_id  =
         	(SELECT  application_id
          	FROM    fnd_application
          	WHERE   application_short_name = 'IMAGING') ;
    end if;
End;
/
commit;

-- correct context column name for
-- fnd_documents_tl and set usage code to active
UPDATE FND_DESCRIPTIVE_FLEXS
SET CONTEXT_COLUMN_NAME = 'DOC_ATTRIBUTE_CATEGORY'
where application_table_name = 'FND_DOCUMENTS_TL';

COMMIT;

UPDATE fnd_columns
SET flexfield_usage_code = 'D'
,flexfield_application_id = 0
,flexfield_name = 'ATCHMT_DOCUMENT_FLEX'
WHERE table_id = ( SELECT table_id
					FROM fnd_tables
					WHERE table_name = 'FND_DOCUMENTS_TL')
AND column_name like 'DOC_ATTRIBUTE%';

COMMIT;
/

connect &&img_usr/&&img_pwd
prompt CREATING IMAGING TABLES
prompt                
-- create imaging tables
@../tables/gis_doc_tables.sql

prompt CREATING IMAGING INDEXES
prompt              
-- create imaging indexes
@../indexes/gis_indexes.sql

prompt CREATING IMAGING VIEWS
prompt 
-- create imaging views
@../views/gis_views.sql

prompt CREATING IMAGING SEQUENCES
prompt
-- create imaging sequences
@../sequences/gis_sequences.sql

prompt GIVING REQUIRED GRANTS
prompt
-- give required grants
@../grants/gis_imaging_grants

prompt CREATING REQUIRED SYNONYMS
prompt
-- create imaging synonyms
@../synonyms/gis_imaging_synonyms

prompt CREATING IMAGING PACKAGES
prompt
-- create required packages
connect &&apps_usr/&&apps_pwd
@gis_install_pack_spec
@gis_install_pack_bodies

COMMIT;

PROMPT Install completed

exit
