CREATE OR REPLACE
PACKAGE BODY apps.gis_apps_search AS
-- ============================================================================
--
--   NAME
--      gis_apps_search_pkb.sql
--
--   DESCRIPTION
--      This script is used to create the gis__apps_search package body
--      It controls the web inquiry screens of GIS for application 
--		queries 
--      
--   HISTORY
--      03/07/2001 David Gough In Development
--
--
-- ============================================================================

FUNCTION IndexedSearchAvail( p_context VARCHAR2) 
RETURN BOOLEAN IS

l_returnVal BOOLEAN;

BEGIN
	IF p_context = 'Agreements'
	THEN
		l_returnVal := FALSE;
	ELSIF p_context = 'Contracts'
	THEN
		l_returnVal := TRUE;
	ELSIF p_context = 'Order Management'
	THEN
		l_returnVal := TRUE;
	ELSIF p_context = 'Payables'
	THEN
		l_returnVal := FALSE;
	ELSIF p_context = 'Customer'
	THEN
		l_returnVal := TRUE;	
	ELSIF p_context = 'Projects'
	THEN
		l_returnVal := FALSE;
	ELSE
		l_returnVal := FALSE;
	END IF;
	RETURN l_returnVal;
END IndexedSearchAvail;

FUNCTION securityIdforContext( p_context VARCHAR2, p_org NUMBER) 
RETURN NUMBER IS

ln_returnValue gis_search.idNumber;
BEGIN
	IF p_context = 'Customer'
		OR p_context = 'Payables' 
		OR p_context = 'Receivables' 
		OR p_context = 'HR Assignments'
		OR p_context = 'Suppliers'
	THEN
		SELECT set_of_books_id
		INTO ln_returnValue
		FROM hr_operating_units
		WHERE organization_id = p_org;	
	ELSIF  	p_context = 'Education Events' 
		OR p_context = 'Education Bookings'
	THEN
		SELECT business_group_id
		INTO ln_returnValue
		FROM hr_operating_units
		WHERE organization_id = p_org;
	ELSE
		ln_returnValue := p_org;	
	END IF;
	RETURN ln_returnValue;
EXCEPTION
	WHEN OTHERS
	THEN
		htp.p( gis_search.showErr( null,'gis_search.orgIdForRecord'));
END securityIdforContext;

PROCEDURE ListDocuments(p_docRef VARCHAR2
						,p_pkValue VARCHAR2
						,p_context VARCHAR2
						,p_userType VARCHAR2
						,p_userId VARCHAR2
						,p_respId VARCHAR2
						,p_org VARCHAR2 DEFAULT NULL
						,p_attributes VARCHAR2) IS
	
	CURSOR cur_attachedDocuments( f_entityName VARCHAR2, f_pk1_value VARCHAR2, f_securityTag NUMBER) IS
	SELECT docTl.document_id
	,att.seq_num
	,docTl.description
	,catTl.user_name category_description
	,docTl.file_name
	,doc.usage_type usage_type_descr
	,docTl.media_id
	,docdfv.storage_location
	,nvl(catDfv.secure_document,'OPEN') secure_document
	,att.entity_name
	,doc.security_id
	,doc.security_type
	FROM fnd_document_categories_dfv catDfv
	,fnd_document_categories cat
	,fnd_document_categories_tl catTl
	,fnd_documents doc
	,fnd_documents_tl docTl
	,fnd_documents_tl_dfv docdfv
	,fnd_attached_documents_dfv attdfv
	,fnd_attached_documents att
	WHERE att.entity_name = f_entityName--'OE_ORDER_HEADERS'
	AND att.pk1_value = f_pk1_value--'3896203'
	AND att.rowid = attdfv.rowid
	AND att.document_id = docTl.document_id
	AND docTl.language= userenv('LANG')
	AND docTl.rowid = docdfv.rowid
	AND doc.document_id = docTl.document_id
	AND doc.datatype_id = 6
	AND doc.category_id = catTl.category_id
	AND catTl.language= userenv('LANG')
	AND catTl.category_id = cat.category_id
	AND cat.rowid = catDfv.rowid
	AND doc.security_id = f_securityTag
	ORDER BY seq_num;
	
	row_attachedDocuments cur_attachedDocuments%ROWTYPE;
	l_url gis_search.largeVarchar;
	l_context gis_search.stdVarchar := replace(p_context,'+',' ');
	ln_orgId gis_search.idNumber;
	l_storage_location gis_search.stdVarchar;
	
	FUNCTION orgIdForRecord( p_securityType NUMBER, p_securityId NUMBER) 
	RETURN NUMBER IS
	
	ln_returnValue gis_search.idNumber;
	BEGIN
		IF p_securityType = 1
		THEN
			ln_returnValue := p_securityId;
		ELSIF  p_securityType = 2
		THEN
			SELECT organization_id
			INTO ln_returnValue
			FROM hr_operating_units
			WHERE set_of_books_id = p_securityId;		
		ELSIF  p_securityType = 3
		THEN
			SELECT organization_id
			INTO ln_returnValue
			FROM hr_operating_units
			WHERE business_group_id = p_securityId;
		ELSIF  p_securityType = 4
		THEN
			ln_returnValue := p_securityId;		
		END IF;
		RETURN ln_returnValue;
	EXCEPTION
		WHEN OTHERS
		THEN
			htp.p( gis_search.showErr( null,'gis_search.orgIdForRecord'));
	END orgIdForRecord;
	
BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'gis_apps_search.listDocuments');				
	gis_image_util.InfoHeader( p_attributes); 
	htp.formHidden( 'p_pkValue',p_pkValue); 
	htp.formHidden( 'p_docRef',p_docRef);  
	htp.formHidden( 'p_org',p_org);
	htp.formHidden( 'p_context',p_context);
   htp.p(gis_search.js('function updateField(field, oldValue, docId, docRef, pkValue, context, userType, userId, respId, attributes, orgId)
			{
				url = '''||gis_image_util.c_pack_url||'gis_apps_search.UpdateField?p_field='' + field + ''&p_value='' + oldValue + ''&p_docId='' + docId;
				url = url + ''&p_docRef='' + docRef + ''&p_pkValue='' + pkValue +''&p_context='' + context + ''&p_userType='' + userType;
				url = url + ''&p_userId='' + userId + ''&p_respId='' + respId + ''&p_attributes='' + attributes + ''&p_orgId='' + orgId;
				window.open( url, "UpdateField", "width=420,height=200,dependent=no,left=5,top=5,screenX=1,screenY=50,resizable=1,status=0,scrollbars=1");
			}'));	
	ln_orgId := securityIdforContext( p_context, p_org);
	IF NOT cur_attachedDocuments%ISOPEN
	THEN
		OPEN cur_attachedDocuments( p_docRef, p_pkValue, ln_orgId);
	END IF;
-- 	htp.formSelectOpen(cname=>'p_context',nsize=>'8');		
	FETCH cur_attachedDocuments INTO row_attachedDocuments;
	IF cur_attachedDocuments%NOTFOUND THEN
		htp.br;
		htp.br;
		htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
		htp.p('<FONT size=''5''><B>No Documents Found</B></FONT>');
	ELSE
-- get the org id for this record
		ln_orgId := orgIdForRecord( row_attachedDocuments.security_type, row_attachedDocuments.security_id);		
		htp.p('  <TABLE  WIDTH="100%" BGCOLOR="WHITE" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
		htp.p('	<TR>');
		htp.p('		<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Seq Num</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Description</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Category</B></FONT></TD>
				  	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Storage</B></FONT></TD>
				  	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Secure</B></FONT></TD>');
				  --	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Usage Type</B></FONT></TD>
		htp.p('	</TR>');

	WHILE cur_attachedDocuments%FOUND
		LOOP
			-- get the access code and url to view the image through fnd_gfm
			l_url := fnd_gfm.construct_download_url(gis_image_util.get_pack_url,row_attachedDocuments.media_id);
				
			htp.p('	<TR>');

		-- test for secure flag
			IF gis_search.secureDocument(row_attachedDocuments.secure_document) = 'Yes'
			THEN
			-- test if user has access to this secure document 
				IF gis_search.viewSecureDocument( p_userId, ln_orgId, p_context)
				THEN
-- document description will always be there
-- document is secure but user has access rights
					htp.p('	<TD><FONT COLOR="BLACK" SIZE="2"><A HREF="JavaScript:viewimage('''','''','''
							||l_url||'''); imageDisplayed(''Yes''); " '|| gis_search.onMouseOver('View Document')
							||'>'||row_attachedDocuments.seq_num||'</A></FONT></TD>');
				ELSE
-- user does not have secure document access rights
					htp.p('	<TD><FONT COLOR="BLACK" SIZE="2">'||row_attachedDocuments.seq_num||'</FONT></TD>');
				END IF;
-- the document is not secure- free for all
			ELSE
				htp.p('	<TD><FONT COLOR="BLACK" SIZE="2"><A HREF="JavaScript:viewimage('''','''','''
						||l_url||'''); imageDisplayed(''Yes''); " '|| gis_search.onMouseOver('View Document')
						||'>'||row_attachedDocuments.seq_num||'</A></FONT></TD>');
			END IF;
-- format location field if blank
			IF 	row_attachedDocuments.storage_location IS NULL OR
				row_attachedDocuments.storage_location = ' '
			THEN
				l_storage_location := '&nbsp&nbsp';
			ELSE
				l_storage_location :=row_attachedDocuments.storage_location;
			END IF;		 
			htp.p('<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2"><A HREF="JavaScript:updateField(''description'','''
							||gis_search.validURLstring(row_attachedDocuments.description)||'''
							,'''|| row_attachedDocuments.document_id ||'''
							,'''|| p_docRef || '''
							,'''|| p_pkValue || '''
							,'''|| replace(p_context,' ','+') || '''
							,'''|| replace(p_userType,' ','+') || '''
							,'''|| p_userId || '''
							,'''|| p_respId || '''
							,'''|| replace(p_attributes,' ','+') || '''
							,'''|| p_org || ''')"'
							||gis_search.onMouseOver('Edit/Update Field')||'>'|| nvl(row_attachedDocuments.description,'-')|| '</A></FONT></TD>
					<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">'|| row_attachedDocuments.category_description|| '</FONT></TD>
				  	<TD ALIGN="CENTER"><FONT COLOR="BLACK" ><A HREF="JavaScript:updateField(''storage'','''
							||gis_search.validURLstring(row_attachedDocuments.storage_location)||'''
							,'''|| row_attachedDocuments.document_id ||'''
							,'''|| p_docRef || '''
							,'''|| p_pkValue || '''
							,'''|| replace(p_context,' ','+') || '''
							,'''|| replace(p_userType,' ','+') || '''
							,'''|| p_userId || '''
							,'''|| p_respId || '''
							,'''|| replace(p_attributes,' ','+') || '''
							,'''|| p_org || ''')"'
							||gis_search.onMouseOver('Edit/Update Field')||'>'||l_storage_location||'</FONT></TD>');
			htp.p('<TD ALIGN="CENTER"><FONT COLOR="BLACK" >'||gis_search.secureDocument(row_attachedDocuments.secure_document)||'</TD>');
			htp.p('	</TR>');	

			FETCH cur_attachedDocuments INTO row_attachedDocuments;
		END LOOP;
		htp.p('	</TABLE>');
	END IF;
	CLOSE cur_attachedDocuments; 
	htp.line;
	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('    <TR>');
	htp.p('      <TD ALIGN="CENTER">');
	htp.p('			<A HREF="JavaScript:if (parent.QueryFrame.document.indexedQueryOptions.imageDisplayed.Value == ''Yes''){parent.ViewingFrame.history.go(-1);imageDisplayed(''No'');}parent.SelectFrame.history.go(-1) " gis_search.onMouseOver="window.status=''Back to query results''; ');
	htp.p('				return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_m.gif" ');
	htp.p('				BORDER="0" ALT="Back to query results" ALIGN="TOP"></A></TD></TR>');
	htp.p('	</TABLE>');
	gis_image_util.pageclose;
--	htp.formClose;
EXCEPTION
	WHEN OTHERS
	THEN
		htp.p(gis_search.showErr( null, 'gis_apps_search.ListDocuments'));		
END ListDocuments;

PROCEDURE indexedQueryOptions(	p_document VARCHAR2 DEFAULT NULL
								, p_context VARCHAR2 DEFAULT NULL
								,p_userId VARCHAR2 DEFAULT NULL
								,p_userType VARCHAR2 DEFAULT NULL
								,p_respId VARCHAR2) IS

l_document VARCHAR2(25) := REPLACE( p_document,' ','+');
l_context VARCHAR2(50) := replace(p_context,'+',' ');
x_context VARCHAR2(50);
y_context VARCHAR2(50):= replace(p_context,' ','_');  
l_searchOption NUMBER(1); 
v_viewFrame VARCHAR2(50);
								
BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'indexedQueryOptions');				
	gis_image_util.InfoHeader( l_context || ' - Query');
	IF l_context = 'Old Renewals'
	THEN
		x_context := 'Contracts';
		v_viewFrame := 'SelectFrame';
	ELSE
		x_context := l_context;
		v_viewFrame := 'ViewingFrame';
	END IF;

	htp.formOpen('gis_apps_search.'||y_context|| 'IQActions', cmethod=>'POST',ctarget=>v_viewFrame, cattributes=>'NAME="indexedQueryOptions"');
	htp.formHidden( 'p_userId', p_userId);
	htp.formHidden( 'p_userType', p_userType);
	htp.formHidden( 'p_respId', p_respId);
	htp.formHidden( 'p_context', l_context);
    htp.formHidden( 'imageDisplayed', 'No');
    
	htp.p('  <TABLE WIDTH="95%" BORDER="0" ALIGN="CENTER" CELLSPACING="0" CELLPADDING="2">');
	-- display valid orgs to select from
	gis_search.CountryInput( p_attrib=>'no_all_option',p_userId=>p_userId, p_context=>x_context);
				
	IF l_context = 'Agreements'
	THEN
		htp.p('Query Action not yet defined for selected context');	
	ELSIF l_context = 'Contracts'
	THEN
		ContractsQuery( p_userId, p_userType, p_respId);  
		l_searchOption := 6;
	ELSIF l_context = 'Old Renewals'
	THEN
		OldRenewalsQuery( p_userId, p_userType, p_respId);  
		l_searchOption := 7;
	ELSIF l_context = 'Order Management'
	THEN
		OrderHeadersQuery( p_userId, p_userType, p_respId);
		l_searchOption := 5;
	ELSIF l_context = 'Payables'
	THEN
		htp.p('Query Action not yet defined for selected context');	
	ELSIF l_context = 'Customer'
	THEN
		raCustomerQuery( p_userId, p_userType, p_respId);
		l_searchOption := 8;	
	ELSIF l_context = 'Projects'
	THEN
		htp.p('Query Action not yet defined for selected context');	
	ELSE
		htp.p('Query Action not yet defined for selected context');
	END IF;
	htp.p('	</TABLE>');		
	
	htp.line;
	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('    <TR>');
	htp.p('      <TD ALIGN="CENTER" VALIGN="MIDDLE">');
	htp.p('<A HREF="'||gis_image_util.c_pack_url||'gis_search.QueryContext?p_document='||p_document||
										'&p_userType='||REPLACE(p_userType,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId||'" gis_search.onMouseOver="window.status=''Back''; ');
	htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_l.gif" ');
	htp.p('		BORDER="0" ALT="Back" ALIGN="TOP"></A>');
	htp.p('<A HREF="javascript:document.indexedQueryOptions.reset()" gis_search.onMouseOver="window.status=''Reset Fields''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_reset_m.gif" BORDER="0" ');
	htp.p('		ALT="Reset Fields" ALIGN="TOP"></A>');
	htp.p('<A HREF="javascript:if (isValid()){ parent.SelectFrame.location = '''||gis_image_util.c_pack_url||
			'gis_image_util.BlankFrame'' ;searchmenu('||l_searchOption||','''||p_document||''')}" gis_search.onMouseOver="window.status=''Search''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_search_r.gif" BORDER="0" ');
	htp.p('		ALIGN="TOP" ALT="Search"></A>');	
	htp.p('		</TD>');
	htp.p('    </TR>');
	htp.p('  </TABLE>');
	htp.formClose;
	gis_image_util.pageclose;
END indexedQueryOptions;

PROCEDURE CustomerQueryFields IS
BEGIN
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Customer Name</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_soldTo" COLS=15 TYPE=TEXT size="22" maxlength="50">');
	htp.p('				<FONT size=2><A HREF="javaScript: var org;
														  recCount = document.indexedQueryOptions.p_org.length;
														  soldTo = document.indexedQueryOptions.p_soldTo.value;
														  soldTo = soldTo.replace(''&'',''~''); 
														  soldTo = soldTo.replace('' '',''+'');
														  soldTo = soldTo.replace('' '',''+'');
														  soldTo = soldTo.replace('' '',''+'');
														  for(var i = 0;i< recCount;i++)
	    												  { 
	    												  	if (document.indexedQueryOptions.p_org[i].selected == true)
	    												  	{  
														  		org = document.indexedQueryOptions.p_org[i].value;
														  	}
														  }
														  org = document.indexedQueryOptions.p_org.value;
														  url = '''||gis_image_util.c_pack_url||'gis_search.CustNameLov?p_org='' + org + ''&p_custName='' + soldTo;								  
									  					  doLov(url,''p_soldTo'');" 
										gis_search.onMouseOver="window.status=''Confirm Entry''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="'||
										gis_image_util.c_image_url||'b_query.gif" BORDER="0" ALIGN="TOP" ALT="Confirm Customer Name"></A></TD>');
	htp.p('    </TR>');	
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Customer Number</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_customerNumber" COLS=15 TYPE=TEXT size="15" maxlength="15">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
END CustomerQueryFields;

PROCEDURE raCustomerQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2) IS
							
BEGIN
	htp.p( gis_search.js(' function isValid(){return true;}'));
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Customer Name</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_customerName" COLS=15 TYPE=TEXT size="20" maxlength="50">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Customer Number</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_customerNumber" COLS=15 TYPE=TEXT size="12" maxlength="12">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
--	htp.p('    <TR>');
--	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
--	htp.p('			<FONT size=2><B>Document Ref.</B></FONT></DIV></TD>');
--	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
--	htp.p('			<INPUT NAME="p_docRef" COLS=15 TYPE=TEXT size="22" maxlength="50">');
--	htp.p('				<FONT size=2></TD>');
--	htp.p('    </TR>');	
	-- std query fields
--	CustomerQueryFields;
END raCustomerQuery; 
 
PROCEDURE OrderHeadersQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2) IS
							
BEGIN
-- javascript code for calling the lov window
htp.p('	<SCRIPT LANGUAGE="javascript">
		<!--BEGIN Script
			function doLov(url, returnValTo)
			{
				window.open( url, "ConfirmLookup", "width=450,height=275,dependent=no,left=5,top=5,screenX=1,screenY=50,resizable=1,status=0,scrollbars=1");
			}	

// javaScript code that checks that entered dates are in a valid format
// i.e. dd-mmm-yyyy or dd/mmm/yyyy. Calls validation functions contained in the 
// core_functions.js file
		function isValid()
		{
			var lDate;
			var valid = true;
 			if(document.indexedQueryOptions.p_orderDateFrom.value !="")
 			{
  				lDate = document.indexedQueryOptions.p_orderDateFrom.value;
  				if(checkDate( lDate)) valid =  true;
  				else
  				{
  					alert( "Date format " + lDate + " is incorrect.....Query canceled. The correct format is DD-MON-YYYY or DD/MON/YYYY" );
  					valid = false;
  				} 
  			}
			if(document.indexedQueryOptions.p_orderDateTo.value !="")
 			{
  				lDate = document.indexedQueryOptions.p_orderDateTo.value;
  				if(checkDate( lDate)) valid =  true;
   				else
  				{
  					alert( "Date format " + lDate + " is incorrect.....Query canceled. The correct format is DD-MON-YYYY or DD/MON/YYYY" );
  					valid = false;
  				} 
  			}
  			return valid;
		}
		//-->
 		</SCRIPT>');	

	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Order Number</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_orderNumber" COLS=15 TYPE=TEXT size="20" maxlength="50">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Order Date From</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_orderDateFrom" COLS=15 TYPE=TEXT size="12" maxlength="12"><A HREF="#" 
					onClick="window.dateField = document.indexedQueryOptions.p_orderDateFrom;calendar = 
					window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=200,HEIGHT=250,RESIZABLE=0'')"><IMG SRC="' || 
					gis_image_util.c_image_url || 'b_cal.gif" BORDER="0" ALT="Calendar" ALIGN="TOP"></A>');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Order Date To</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_orderDateTo" COLS=15 TYPE=TEXT size="12" maxlength="12"><A HREF="#" 
					onClick="window.dateField = document.indexedQueryOptions.p_orderDateTo;calendar = 
					window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=200,HEIGHT=250,RESIZABLE=0'')"><IMG SRC="' || 
					gis_image_util.c_image_url || 'b_cal.gif" BORDER="0" ALT="Calendar" ALIGN="TOP"></A>');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Document Ref.</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_docRef" COLS=15 TYPE=TEXT size="22" maxlength="50">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	-- std query fields
	CustomerQueryFields;
END OrderHeadersQuery; 

PROCEDURE ContractsQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2) IS
							
BEGIN
-- javascript code for calling the lov window
htp.p( gis_search.js('	function doLov(url, returnValTo)
			{
				window.open( url, "ConfirmLookup", "width=450,height=275,dependent=no,left=5,top=5,screenX=1,screenY=50,resizable=1,status=0,scrollbars=1");
			}	
 		
 		    function isValid(){return true;};'));	
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Contract Number</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_contractNumber" COLS=15 TYPE=TEXT size="20" maxlength="50">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Contract Modifier</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_contractModifier" COLS=15 TYPE=TEXT size="20" maxlength="45">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	-- std query fields
	CustomerQueryFields;
END ContractsQuery;

PROCEDURE OldRenewalsQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2) IS
							
BEGIN
-- javascript code for calling the lov window
htp.p( gis_search.js('	function doLov(url, returnValTo)
			{
				window.open( url, "ConfirmLookup", "width=450,height=275,dependent=no,left=5,top=5,screenX=1,screenY=50,resizable=1,status=0,scrollbars=1");
			}
			
		function isValid(){return true;};'));		

	htp.p('    <TR>');
	htp.p('      <TD WIDTH="40%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
	htp.p('			<FONT size=2><B>Renewal ID</B></FONT></DIV></TD>');
	htp.p('      <TD WIDTH="60%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
	htp.p('			<INPUT NAME="p_renewalId" COLS=15 TYPE=TEXT size="20" maxlength="50">');
	htp.p('				<FONT size=2></TD>');
	htp.p('    </TR>');	
	htp.p('    <TR>');
	htp.p('    <TR>');
	-- std query fields
	CustomerQueryFields;
END OldRenewalsQuery;



--
-- This function returns a boolean value depending on whether the record being passed in
-- has any attachments. TRUE = yes FALSE = no.
--
FUNCTION AttachedDocumentCheck( p_pkValue VARCHAR2, p_entityName VARCHAR2, p_org VARCHAR2 DEFAULT NULL, p_context VARCHAR2) 
RETURN BOOLEAN IS

CURSOR cur_attachedDocuments( f_entityName VARCHAR2, f_pk1_value VARCHAR2, f_securityTag NUMBER) IS
SELECT 'Y' AS doc_exists
FROM fnd_documents doc
,fnd_attached_documents att
WHERE entity_name = f_entityName--'OE_ORDER_HEADERS'
AND pk1_value = f_pk1_value--'3896203'
AND att.document_id = doc.document_id
AND doc.datatype_id = 6
AND doc.security_id = f_securityTag;

row_attachedDocuments cur_attachedDocuments%ROWTYPE;
l_returnValue BOOLEAN;
l_securityTag gis_search.idNumber;

BEGIN
	IF nvl( p_pkValue,0) = 0
	THEN
		l_returnValue := FALSE;
	ELSE
		l_securityTag := securityIdforContext( p_context, p_org);
	 	IF NOT cur_attachedDocuments%ISOPEN
		THEN
			OPEN cur_attachedDocuments( p_entityName, p_pkValue, l_securityTag);
		END IF;
		
		FETCH cur_attachedDocuments INTO row_attachedDocuments;
		IF cur_attachedDocuments%NOTFOUND THEN
			l_returnValue := FALSE;
		ELSE
			l_returnValue := TRUE;
		END IF;
		CLOSE cur_attachedDocuments;
	END IF;
	RETURN l_returnValue;
END AttachedDocumentCheck;

PROCEDURE CustomerIQActions(	p_userId VARCHAR2
							 	,p_userType VARCHAR2
							 	,p_respId VARCHAR2
							 	,p_context VARCHAR2
							 	,p_org VARCHAR2   
							 	,p_orgCount VARCHAR2
							 	,imageDisplayed VARCHAR2
							 	,p_customerName VARCHAR2 DEFAULT NULL
							 	,p_customerNumber VARCHAR2 DEFAULT NULL
							 	,p_orgName VARCHAR2 DEFAULT NULL) IS
							 		
TYPE  cv_type IS REF CURSOR;
cv    cv_type;
v_sql gis_search.largeVarchar;
v_customerName hz_parties.party_name%type; 
v_customerNumber hz_cust_accounts.account_number%type;
v_partyType hz_parties.party_type%type;
v_partyNumber hz_parties.party_number%type; 
v_origSystemReference hz_parties.orig_system_reference%type;
v_status hz_parties.status%type;
v_customerType hz_cust_accounts.customer_type%type;
v_customerProspectCode  gis_search.stdVarchar;--stdVarchar;
v_customerKey gis_search.stdVarchar;
l_context gis_search.stdVarchar := replace(p_context,'+',' ');
v_customerId hz_parties.party_id%type;


BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'gis_search.CustomerIQActions');				
	gis_image_util.InfoHeader( l_context || ' - Query Results');
	dbms_application_info.set_client_info(p_org);
	v_sql := 	'SELECT party_type '||
				',party_number '||
				',customer_name '||
				',customer_number '||
				',orig_system_reference '||
				',decode(status,''A'',''Active'',''Inactive'') status '||
				',customer_type '||
				',customer_prospect_code '||
				',customer_key '||
				',customer_id '||
				'from ra_customers '||
				'where 1=1 ';

	IF nvl( p_customerNumber,'0') != '0'
	THEN                                    
		v_sql := v_sql || ' AND customer_number = '''|| p_customerNumber ||'''';
	END IF;  
	IF nvl( p_customerName,'0') != '0'
	THEN                                    
		IF (instr( p_customerName,'%')) > 0
		THEN
		v_sql := v_sql || ' AND customer_name like '''||p_customerName ||'''';
		ELSE
		v_sql := v_sql || ' AND customer_name = '''|| p_customerName ||'''';
		END IF;		
	END IF;  
	v_sql := v_sql || ' order by customer_name';              
	OPEN cv FOR v_sql;
   	FETCH cv INTO  	 v_partyType
   				   	, v_partyNumber
   				   	, v_customerName
   					, v_customerNumber
   					, v_origSystemReference
   					, v_status
   					, v_customerType
   					, v_customerProspectCode
   					, v_customerKey
   					, v_customerId;
   	IF cv%notfound 
   	THEN
   	   	htp.br;
		htp.br;
		htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
		htp.p('<FONT size=''5''><B>No Records Found</B></FONT>');
	ELSE
		htp.p('  <TABLE  WIDTH="100%" BGCOLOR="WHITE" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
		htp.p('	<TR>');
		htp.p('		<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Customer Name</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Customer Number</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Status</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Orig System Ref</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Type</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Prospect Code</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Key</B></FONT></TD>');
		htp.p('	</TR>');
		LOOP
			htp.p('	<TR>');
			IF (AttachedDocumentCheck(v_customerId,'AR_CUSTOMERS', p_org, p_context))
			THEN
				htp.p('	<TD><FONT COLOR="BLUE" SIZE="2"><A HREF="javaScript:viewIndexedDocs('''||gis_image_util.c_pack_url||
						'gis_apps_search.ListDocuments?p_docRef=AR_CUSTOMERS&p_pkValue='||v_customerId||
						'&p_context='||REPLACE(l_context,' ','+')||'&p_userType='||REPLACE(p_userType,' ','+')||
						'&p_userId='||p_userId||'&p_respId='||p_respId||'&p_org='|| p_org ||
						'&p_attributes=Customer+:+'||v_customerNumber||''')">'||v_customerName ||'</A></FONT></TD>');
			ELSE 
				htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| v_customerName ||'</FONT></TD>'); 
			END IF;
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerNumber,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_status,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_origSystemReference,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerType,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerProspectCode,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerKey,'-') ||'</FONT></TD>');
			htp.p('	</TR>');	
   			FETCH cv INTO  	 v_partyType
   				   			, v_partyNumber
		   				   	, v_customerName
		   					, v_customerNumber
		   					, v_origSystemReference
		   					, v_status
		   					, v_customerType
		   					, v_customerProspectCode
		   					, v_customerKey
		   					, v_customerId;
   			EXIT WHEN cv%notfound;
  		END LOOP;
  	END IF;
  	CLOSE cv;
	htp.p('</TABLE>');	 
	gis_image_util.pageclose;
EXCEPTION
	WHEN OTHERS
	THEN
		htp.p( gis_search.showErr( 'Query being executed at time of error: '|| v_sql, 'gis_search.CustomerIQActions'));	
END CustomerIQActions;    

PROCEDURE ContractsIQActions(	p_userId VARCHAR2
							 		,p_userType VARCHAR2
							 		,p_respId VARCHAR2
							 		,p_context VARCHAR2
							 		,p_org VARCHAR2
							 		,p_orgCount VARCHAR2
							 		,imageDisplayed VARCHAR2
							 		,p_contractNumber VARCHAR2 DEFAULT NULL
							 		,p_contractModifier VARCHAR2 DEFAULT NULL
							 		,p_soldTo VARCHAR2 DEFAULT NULL
							 		,p_customerNumber VARCHAR2 DEFAULT NULL
							 		,p_orgName VARCHAR2 DEFAULT NULL) IS
							 		
TYPE  cv_type IS REF CURSOR;
cv    cv_type;
v_sql gis_search.largeVarchar;
v_contractNumber okc_k_headers_b.contract_number%type; 
v_contractModifier okc_k_headers_b.contract_number_modifier%type;
l_context gis_search.stdVarchar := replace(p_context,'+',' ');
v_shortDescription okc_k_headers_v.short_description%type; 
v_customerName hz_parties.party_name%type;
v_customerNumber hz_cust_accounts.account_number%type;
v_statusCode okc_k_headers_b.sts_code%type;
v_customerId hz_parties.party_id%type;
v_okcId okc_k_headers_b.id%type;
l_custHasAttDocs BOOLEAN;

BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'OrderIndexedQueryActions');				
	gis_image_util.InfoHeader( l_context || ' - Query Results');
	dbms_application_info.set_client_info(p_org);
	v_sql := 'SELECT okc.contract_number_modifier '||
			 ', okc.contract_number ' ||
			 ', okc.short_description ' ||
			 ', prt.customer_name '||
			 ', prt.customer_number '||
			 ', okc.sts_code '||
			 ', prt.customer_id '||
			 ', okc.id '||
			 'FROM okc_k_headers_v okc '||
			 ' ,okc_k_party_roles_v  kpr '||
			 ' ,ra_customers prt '||
			 ' WHERE prt.customer_id = kpr.object1_id1 ' ||
			 ' AND  kpr.rle_code = ''CUSTOMER''' ||
			 ' AND  kpr.jtot_object1_code = ''OKX_PARTY''' ||
			 ' AND  kpr.chr_id = nvl(okc.chr_id_renewed_to, chr_id_renewed)';   
	IF nvl( p_contractNumber,0) != 0
	THEN
		v_sql := v_sql || ' AND okc.contract_number = '''|| p_contractNumber ||'''';
	END IF;  
	IF nvl( p_contractModifier,'0') != '0'
	THEN                                    
		IF (instr( p_contractModifier,'%')) > 0
		THEN
			v_sql := v_sql || ' AND okc.contract_number_modifier like '''|| p_contractModifier ||'''';
		ELSE
			v_sql := v_sql || ' AND okc.contract_number_modifier = '''|| p_contractModifier ||'''';
		END IF;		
	END IF;  
	IF nvl( p_customerNumber,0) != 0
	THEN
		v_sql := v_sql || ' AND prt.customer_number = '|| p_customerNumber;
	END IF;  
	IF nvl( p_soldTo,'0') != '0'
	THEN
		v_sql := v_sql || ' AND prt.customer_name = '''|| p_soldTo ||'''';
	END IF;
	v_sql := v_sql || ' order by okc.contract_number';              
--	   htp.p( v_sql);
	OPEN cv FOR v_sql;
   	FETCH cv INTO v_contractModifier
   				, v_contractNumber
   				, v_shortDescription
   				, v_customerName
   				, v_customerNumber
   				, v_statusCode
   				, v_customerId
   				, v_okcId;
   	IF cv%notfound 
   	THEN
   	   	htp.br;
		htp.br;
		htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
		htp.p('<FONT size=''5''><B>No Records Found</B></FONT>');
	ELSE
		htp.p('  <TABLE  WIDTH="100%" BGCOLOR="WHITE" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
		htp.p('	<TR>');
		htp.p('		<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Contract Number</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Contract Modifier</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Status</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Description</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Customer Name</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Customer Number</B></FONT></TD>');
		htp.p('	</TR>');
		IF NOT (AttachedDocumentCheck(v_customerId,'AR_CUSTOMERS', p_org, p_context))
		THEN
			l_custHasAttDocs := FALSE;
		ELSE
			l_custHasAttDocs := TRUE;
		END IF;		
		LOOP
			htp.p('	<TR>');
			IF (AttachedDocumentCheck(v_okcId,'OKC_K_HEADERS_V', p_org, p_context))
			THEN
				htp.p('	<TD><FONT COLOR="BLUE" SIZE="2"><A HREF="javaScript:viewIndexedDocs('''||gis_image_util.c_pack_url||
						'gis_apps_search.ListDocuments?p_docRef=OKC_K_HEADERS_V&p_pkValue='||v_okcId||
						'&p_context='||REPLACE(l_context,' ','+')||'&p_userType='||REPLACE(p_userType,' ','+')||
						'&p_userId='||p_userId||'&p_respId='||p_respId||'&p_org='|| p_org ||'&p_attributes=Contract+:+'||
						v_contractNumber||''')">'|| v_contractNumber ||'</A></FONT></TD>');
			ELSE 
				htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| v_contractNumber ||'</FONT></TD>'); 
			END IF;
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_contractModifier,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_statusCode,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_shortDescription,'-') ||'</FONT></TD>');
			IF l_custHasAttDocs
			THEN			
				htp.p('	<TD><FONT COLOR="BLUE" SIZE="2"><A HREF="javaScript:viewIndexedDocs('''||gis_image_util.c_pack_url||
						'gis_apps_search.ListDocuments?p_docRef=AR_CUSTOMERS&p_pkValue='||v_customerId||'&p_context='||
						REPLACE(l_context,' ','+')||'&p_userType='||REPLACE(p_userType,' ','+')||'&p_userId='||p_userId||
						'&p_respId='||p_respId||'&p_org='|| p_org ||'&p_attributes=Customer+:+'||v_customerName||''')">'||
						v_customerName ||'</A></FONT></TD>');
			ELSE
				htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerName,'-') ||'</FONT></TD>');
			END IF;
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerNumber,'-') ||'</FONT></TD>');
			htp.p('	</TR>');	
			FETCH cv INTO  v_contractModifier
   						, v_contractNumber
   			   			, v_shortDescription
   						, v_customerName
   						, v_customerNumber
   			   			, v_statusCode
   			   			, v_customerId
   						, v_okcId;
   			EXIT WHEN cv%notfound;
  		END LOOP;
  	END IF;
  	CLOSE cv;
	htp.p('</TABLE>');	 
	gis_image_util.pageclose;	
END ContractsIQActions;    

PROCEDURE Old_RenewalsIQActions(	p_userId VARCHAR2
							 		,p_userType VARCHAR2
							 		,p_respId VARCHAR2
							 		,p_context VARCHAR2
							 		,p_org VARCHAR2
							 		,p_orgCount VARCHAR2
							 		,imageDisplayed VARCHAR2
							 		,p_renewalId VARCHAR2 DEFAULT NULL
							 		,p_soldTo VARCHAR2 DEFAULT NULL
							 		,p_customerNumber VARCHAR2 DEFAULT NULL
							 		,p_orgName VARCHAR2 DEFAULT NULL) IS
							 		
TYPE  cv_type IS REF CURSOR;
cv    cv_type;
v_sql varchar2(2000);
v_renewalId fnd_documents_tl.doc_attribute_category%type; 
l_context VARCHAR2(50) := replace(p_context,'+',' ');
v_customerName hz_parties.party_name%type;
v_customerNumber hz_cust_accounts.account_number%type;
v_mediaId fnd_documents_tl.media_id%type;
l_custHasAttDocs BOOLEAN;
l_url VARCHAR2(2000);

BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'OrderIndexedQueryActions');				
	gis_image_util.InfoHeader( l_context || ' - Query Results');
	v_sql := 'SELECT doc.doc_attribute3 '||
			 ', doc.doc_attribute1 ' ||
			 ', doc.doc_attribute2 ' ||
			 ', doc.media_id ' ||
			 ' FROM fnd_documents_vl doc '||
			 ' WHERE doc.doc_attribute_category = ''Old Renewal''' ||
			 ' AND doc.doc_attribute6 = ''COMPLETED'''||
			 ' AND doc.datatype_id = 6 ';   
	IF nvl( p_renewalId,0) != 0
	THEN
		v_sql := v_sql || ' AND doc.doc_attribute3 = '''|| p_renewalId ||'''';
	END IF;  
	IF nvl( p_customerNumber,0) != 0
	THEN
		v_sql := v_sql || ' AND doc.doc_attribute2 = '''|| p_customerNumber ||'''';
	END IF;  
	IF nvl( p_soldTo,'0') != '0'
	THEN
		v_sql := v_sql || ' AND doc.doc_attribute1 = '''|| p_soldTo ||'''';
	END IF;
	v_sql := v_sql || ' order by doc.doc_attribute3';              
--	   htp.p( v_sql);
	OPEN cv FOR v_sql;
   	FETCH cv INTO  v_renewalId
   				, v_customerName
   				, v_customerNumber
   				, v_mediaId;
   	IF cv%notfound 
   	THEN
   	   	htp.br;
		htp.br;
		htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
		htp.p('<FONT size=''5''><B>No Records Found</B></FONT>');
	ELSE
		htp.p('  <TABLE  WIDTH="100%" BGCOLOR="WHITE" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
		htp.p('	<TR>');
		htp.p('		<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Renewal ID</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Customer Name</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Customer Number</B></FONT></TD>');
		htp.p('	</TR>');
		LOOP               
			-- get the access code and url to view the image through fnd_gfm
			l_url := fnd_gfm.construct_download_url(gis_image_util.get_pack_url,v_mediaId);
			htp.p('	<TR>');                                                                
			htp.p('	<TD><FONT COLOR="BLUE" SIZE="2"><A HREF="javaScript:viewimage('''','''','''||l_url||''')">'|| v_renewalId ||'</A></FONT></TD>');
			---htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| v_renewalId ||'</FONT></TD>'); 
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerName,'-') ||'</FONT></TD>');
			htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| nvl(v_customerNumber,'-') ||'</FONT></TD>');
			htp.p('	</TR>');	
   	FETCH cv INTO  v_renewalId
   				, v_customerName
   				, v_customerNumber
   				, v_mediaId;
   			EXIT WHEN cv%notfound;
  		END LOOP;
  	END IF;
  	CLOSE cv;
	htp.p('</TABLE>');	 
	gis_image_util.pageclose;	
END Old_RenewalsIQActions;

PROCEDURE Order_ManagementIQActions(	p_userId VARCHAR2
							 		,p_userType VARCHAR2
							 		,p_respId VARCHAR2
							 		,p_context VARCHAR2
							 		,p_org VARCHAR2
							 		,p_orgCount VARCHAR2
							 		,imageDisplayed VARCHAR2
							 		,p_orderNumber VARCHAR2 DEFAULT NULL
							 		,p_orderDateFrom VARCHAR2 DEFAULT NULL
							 		,p_orderDateTo VARCHAR2 DEFAULT NULL
							 		,p_docRef VARCHAR2 DEFAULT NULL
							 		,p_soldTo VARCHAR2 DEFAULT NULL
							 		,p_customerNumber VARCHAR2 DEFAULT NULL
							 		,p_orgName VARCHAR2 DEFAULT NULL) IS
cid INTEGER;
sqlSource VARCHAR2(3000);
rowCount INTEGER;
l_orderNumber NUMBER;
l_orgSysDocumentRef VARCHAR2(50);
l_orderedDate DATE;
l_soldTo VARCHAR2(150);
l_customerNumber hz_cust_accounts.account_number%type;
l_agreement VARCHAR2(50);
l_headerId oe_order_headers_all.header_id%type;
l_soldToOrgId NUMBER(15);
l_custPoNumber VARCHAR2(50);
l_agreementId NUMBER;

l_context VARCHAR2(50) := replace(p_context,'+',' ');
l_custHasAttDocs BOOLEAN;

BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'OrderIndexedQueryActions');				
	gis_image_util.InfoHeader( l_context || ' - Query Results');
	dbms_application_info.set_client_info(p_org);
	sqlSource := 	'SELECT oe.order_number '||
					',oe.orig_sys_document_ref '||
					',oe.ordered_date '||
					',oe.sold_to '||
					',oe.customer_number '||
					',agr.name '||
					',oe.header_id '||
					',oe.sold_to_org_id '||
					',oe.cust_po_number '||
					',oe.agreement_id '||
					'FROM oe_agreements agr '||
					',oe_order_headers_v oe '||
					'WHERE oe.agreement_id = agr.agreement_id(+) ';-- outer join required for orders that do not
																   -- have attached agreements DG 23-03-01
					
	-- build custom where clause
	IF nvl( p_orderNumber,0) != 0
	THEN
		sqlSource := sqlSource || ' AND order_number = '||p_orderNumber;
	END IF;
	-- order date from
	IF NVL(p_orderDateFrom,'0') != '0'
	THEN
		sqlSource := sqlSource || ' AND oe.ordered_date >= '''||TO_DATE(p_orderDateFrom)||'''';
	END IF;
	-- order date to
	IF NVL(p_orderDateTo,'0') != '0'
	THEN
		sqlSource := sqlSource || ' AND oe.ordered_date <= '''||TO_DATE(p_orderDateTo)||'''';
	END IF;
-- orig_sys_document_ref
	IF nvl( p_docRef,'0') != '0'
	THEN
		IF instr( p_docRef,'%') > 0
		THEN
			sqlSource := sqlSource || ' AND orig_sys_document_ref like '''||p_docRef||'''';
		ELSE
			sqlSource := sqlSource || ' AND orig_sys_document_ref = '''||p_docRef||'''';
		END IF;
	END IF;
	-- sold to customer name
	IF p_soldTo IS NOT NULL
	THEN
		sqlSource := sqlSource || ' AND sold_to = '''||p_soldTo||'''';
	END IF;
	-- customer number
	IF nvl( p_customerNumber,0) != 0
	THEN
		sqlSource := sqlSource || ' AND customer_number = '''||p_customerNumber||'''';
	END IF;
	sqlSource := sqlSource ||' ORDER BY order_number';
--	htp.p( sqlSource);		
	cid := dbms_sql.open_cursor;
	dbms_sql.parse( cid, sqlSource, dbms_sql.v7);
	
 	dbms_sql.define_column( cid, 1, l_orderNumber);
 	dbms_sql.define_column( cid, 2, l_orgSysDocumentRef ,50);	      
 	dbms_sql.define_column( cid, 3, l_orderedDate);
 	dbms_sql.define_column( cid, 4, l_soldTo ,150);
 	dbms_sql.define_column( cid, 5, l_customerNumber,150);
 	dbms_sql.define_column( cid, 6, l_agreement, 50);
 	dbms_sql.define_column( cid, 7, l_headerId);
 	dbms_sql.define_column( cid, 8, l_soldToOrgId);
 	dbms_sql.define_column( cid, 9, l_custPoNumber,50);
 	dbms_sql.define_column( cid, 10, l_agreementId);
 	 	 		 	
	rowCount := dbms_sql.execute_and_fetch( cid);
	IF rowCount != 1
	THEN
		htp.br;
		htp.br;
		htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
		htp.p('<FONT size=''5''><B>No Records Found</B></FONT>');
	ELSE
			htp.p('  <TABLE  WIDTH="100%" BGCOLOR="WHITE" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
			htp.p('	<TR>');
			htp.p('		<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Order Number</B></FONT></TD>
						<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Org Sys Document Ref</B></FONT></TD>
						<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Ordered Date</B></FONT></TD>
						<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Sold To</B></FONT></TD>
						<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Customer Number</B></FONT></TD>
						<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Agreement</B></FONT></TD>
						<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Cust PO Num</B></FONT></TD>');
			htp.p('	</TR>');

		IF NOT (AttachedDocumentCheck(l_soldToOrgId,'AR_CUSTOMERS', p_org, p_context))
		THEN
			l_custHasAttDocs := FALSE;
		ELSE
			l_custHasAttDocs := TRUE;
		END IF;			
				
		WHILE  rowCount = 1	
		LOOP
			dbms_sql.column_value( cid, 1,  l_orderNumber);
			dbms_sql.column_value( cid, 2,  l_orgSysDocumentRef);
			dbms_sql.column_value( cid, 3,  l_orderedDate);	
			dbms_sql.column_value( cid, 4,  l_soldTo);
			dbms_sql.column_value( cid, 5,  l_customerNumber);
			dbms_sql.column_value( cid, 6,  l_agreement);
			dbms_sql.column_value( cid, 7,  l_headerId);
			dbms_sql.column_value( cid, 8,  l_soldToOrgId);
			dbms_sql.column_value( cid, 9,  l_custPoNumber);
			dbms_sql.column_value( cid, 10,  l_agreementId);
												
			htp.p('	<TR>');
		--	htp.p('<TD><A HREF="'||gis_image_util.c_pack_url||'gis_search.ListDocuments?p_docRef=orderHeader>');
			--	htp.p('		return true" onMouseOut="window.status='' ''; return true"><FONT COLOR="'||l_hrefColor||'" SIZE="2">' || arr_columns(1) ||' </FONT></A></TD>');
			
			IF NOT (AttachedDocumentCheck(l_headerId,'OE_ORDER_HEADERS', p_org, p_context ))
			THEN
				htp.p('		<TD><FONT COLOR="BLACK" SIZE="2">'|| l_orderNumber ||'</FONT></TD>');			
			ELSE			
				htp.p('		<TD><FONT COLOR="BLUE" SIZE="2"><A HREF="javaScript:viewIndexedDocs('''||gis_image_util.c_pack_url||
								'gis_apps_search.ListDocuments?p_docRef=OE_ORDER_HEADERS&p_pkValue='||l_headerId||
							'&p_context='||REPLACE(l_context,' ','+')||'&p_userType='||REPLACE(p_userType,' ','+')||
							'&p_userId='||p_userId||'&p_respId='||p_respId||'&p_org='||p_org||'&p_attributes=Order+Number+:+'||l_orderNumber||''')" '
								||gis_search.onMouseOver('View Attachments for Order # '||l_orderNumber)||'>'|| l_orderNumber ||'</A></FONT></TD>');
			END IF;
			htp.p('			<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2" >'|| nvl(l_orgSysDocumentRef,'-')|| '</FONT></TD>
						<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2" >'|| l_orderedDate|| '</FONT></TD>');
			IF l_custHasAttDocs
			THEN			
				htp.p('			<TD><FONT COLOR="BLUE" SIZE="2"><A HREF="javaScript:viewIndexedDocs('''||gis_image_util.c_pack_url||'gis_apps_search.ListDocuments?p_docRef=AR_CUSTOMERS&p_pkValue='||l_soldToOrgId||
								'&p_context='||REPLACE(l_context,' ','+')||'&p_userType='||REPLACE(p_userType,' ','+')||
								'&p_userId='||p_userId||'&p_respId='||p_respId||p_respId||'&p_org='||p_org||
								'&p_attributes=Sold+To+:+'||replace(l_soldTo,' ','+')||''')" '
								||gis_search.onMouseOver('View Attachments for '||l_soldTo)||'>'|| l_soldTo ||'</A></FONT></TD>');
			ELSE
				htp.p('			<TD><FONT COLOR="BLACK" SIZE="2">'|| l_soldTo ||'</FONT></TD>');	
			END IF;			
			htp.p('		<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">'|| l_customerNumber|| '</FONT></TD>');
			IF NOT (AttachedDocumentCheck(l_agreementId,'OE_AGREEMENTS', p_org, p_context))
			THEN
				htp.p('		<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">'|| nvl(l_agreement,'-') ||'</FONT></TD>');			
			ELSE
				htp.p('		<TD ALIGN="CENTER"><FONT COLOR="BLUE" SIZE="2"><A HREF="javaScript:viewIndexedDocs('''||
							gis_image_util.c_pack_url||'gis_apps_search.ListDocuments?p_docRef=OE_AGREEMENTS&p_pkValue='||
							l_agreementId||'&p_context='||REPLACE(l_context,' ','+')||'&p_userType='||REPLACE(p_userType,' ','+')||
							'&p_userId='||p_userId||'&p_respId='||p_respId||'&p_org='||p_org||'&p_attributes=Agreement+:+'||
							replace(l_agreement,' ','+')||''')" '||gis_search.onMouseOver('View Attached Documents')||'>'|| l_agreement ||
							'</A></FONT></TD>');
			END IF;
			htp.p('			<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">'|| nvl(l_custPoNumber,'-')|| '</FONT></TD>');
			htp.p('	</TR>');			
			
			rowCount := dbms_sql.fetch_rows( cid);
		END LOOP;
		htp.p('</TABLE>');
	END IF;		
	 	
	dbms_sql.close_cursor( cid); 
	gis_image_util.pageclose;	
END Order_ManagementIQActions;

PROCEDURE SaveUpdate( 	p_field VARCHAR2
						,p_newValue VARCHAR2 DEFAULT NULL
						,p_docId VARCHAR2
						,p_docRef VARCHAR2 DEFAULT NULL
						,p_pkValue VARCHAR2 DEFAULT NULL
						,p_context VARCHAR2 DEFAULT NULL
						,p_userType VARCHAR2 DEFAULT NULL
						,p_userId VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2 DEFAULT NULL
						,p_attributes VARCHAR2 DEFAULT NULL
						,p_orgId VARCHAR2)
IS

v_mesg VARCHAR2(2000);

BEGIN
	IF p_newValue IS NOT NULL
	THEN
		v_mesg := 'alert("Value '|| p_newValue || ' saved: "); 	
					opener.parent.SelectFrame.document.location="gis_apps_search.ListDocuments?p_docRef='||p_docRef
					||'&p_pkValue='||p_pkValue
					||'&p_context='||replace(p_context,' ','+')
					||'&p_userType='||replace(p_userType,' ','+')
					||'&p_userId='||p_userId
					||'&p_respId='||p_respId 
					||'&p_org='|| p_orgId 
					||'&p_attributes='||replace(p_attributes,' ','+')
					||'" ; close();';
		IF p_field = 'description'
		THEN
			UPDATE fnd_documents_tl
			SET description = p_newValue
			WHERE document_id = p_docId;
		ELSIF p_field = 'storage'
		THEN
			UPDATE fnd_documents_tl
			SET doc_attribute10 = p_newValue -- doc_attribute10 = storage location
			WHERE document_id = p_docId;
		END IF;

	ELSE
		v_mesg := 'alert("No value found... Update canceled"); close();';
	END IF;
	
	htp.p( gis_search.js(v_mesg));
	COMMIT;
	EXCEPTION
		WHEN OTHERS
		THEN
			v_mesg := 'alert("Error during update... Operation canceled"); close();';
			ROLLBACK;
			htp.p( gis_search.js(v_mesg));
END SaveUpdate;
    
PROCEDURE UpdateField( 	p_field VARCHAR2 DEFAULT NULL
						,p_value VARCHAR2 DEFAULT NULL
						,p_docId VARCHAR2 DEFAULT NULL
						,p_docRef VARCHAR2 DEFAULT NULL
						,p_pkValue VARCHAR2 DEFAULT NULL
						,p_context VARCHAR2 DEFAULT NULL
						,p_userType VARCHAR2 DEFAULT NULL
						,p_userId VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2 DEFAULT NULL
						,p_attributes VARCHAR2 DEFAULT NULL
						,p_orgId VARCHAR2) IS

BEGIN
	gis_image_util.pageopen(p_heading => 'Alter Field',p_procedure=>'gis_apps_search.UpdateField');				
	gis_image_util.InfoHeader('Update ' || replace(initcap(p_field),'~','''') || '...');
	htp.formOpen('gis_apps_search.SaveUpdate', cmethod=>'POST', cattributes=>'NAME="UpdateField"');
	htp.formHidden('p_field',p_field);
	htp.formHidden('p_docId',p_docId);
	htp.formHidden('p_docRef',p_docRef);
	htp.formHidden('p_pkValue',p_pkValue);
	htp.formHidden('p_context',p_context);
	htp.formHidden('p_userType',p_userType);
	htp.formHidden('p_userId',p_userId);
	htp.formHidden('p_respId',p_respId);
	htp.formHidden('p_attributes',p_attributes); 
	htp.formHidden('p_orgId',p_orgId);
	
	htp.p('  <TABLE  WIDTH="80%" BGCOLOR="WHITE" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
	htp.p('		<TR>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Current Value:</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" >'|| replace(replace(p_value,'~',''''),'^','#') ||'</FONT></TD>
				</TR>
					<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>New Value:</B></FONT></TD>
					<TD BGCOLOR="#C9C9C9"><INPUT NAME="p_newValue" COLS=15 TYPE=TEXT size="25" maxlength="50"></TD>
				</TR>
			</TABLE>');	
	htp.br;		
	htp.p('  <TABLE  WIDTH="100%"  BORDER="0" CELLSPACING="0" CELLPADDING="2">
				<TR>	
					<TD ALIGN="RIGHT"><A HREF="javascript:close()"'|| gis_search.onMouseOver('Close')||'><IMG SRC="' || gis_image_util.c_image_url || 'b_cancel_l.gif" BORDER="0" ALT="Cancel" ALIGN="TOP"></A></TD>
					<TD ALIGN="LEFT"><A HREF="javaScript:document.UpdateField.submit()"'|| gis_search.onMouseOver('Save Changes')||'><IMG SRC="' || gis_image_util.c_image_url || 'b_save_r.gif" BORDER="0" ALT="Save Changes" ALIGN="TOP"></A></TD>
				</TR>
	         </TABLE>');


	htp.formClose;
	gis_image_util.pageclose;
END UpdateField;

END gis_apps_search;
