CREATE OR REPLACE PACKAGE GIS_AR_INTERFACE AS

/*-------------------------------------------------------------------------+
 | PUBLIC PROCEDURE                                                        |
 |    customer_exists                                                      |
 |                                                                         |
 | DESCRIPTION                                                             |
 |    This is a stub module for global imaging to check if a customer      |
 |    exists.                                                              |
 |                                                                         |
 | ARGUMENTS                                                               |
 |    n_gtn_id                GTN ID                                       |
 |    v_customer_number       Customer number to validate                  |
 |    v_customer_name         Customer name                                |
 |    n_status                Return status as:                            |
 |                            -1     Error encountered                     |
 |                            0      Customer does not exist               |
 |                            1      Customer exists, STATUS = 'A'ctive    |
 |                            2      Customer exists, STATUS = 'I'nactive  |
 |    v_err                   Error message                                |
 |                                                                         |
 | RETURNS                                                                 |
 |                                                                         |
 | NOTES                                                                   |
 |                                                                         |
 | EXAMPLE                                                                 |
 |    customer_exists(1348, '270380600', v_customer_name, n_status, v_err) |
 |                                                                         |
 | MODIFICATION HISTORY                                                    |
 |    31-May-2000      Patrick Low     Created.                            |
 |    01-Jun-2000      Patrick Low     Convert parameters to Hungarian     |
 |                                     notation, add event logging         |
 |                                                                         |
 +-------------------------------------------------------------------------*/

PROCEDURE customer_exists (n_gtn_id          IN  NUMBER,
                           v_customer_number IN  VARCHAR2,
                           v_customer_name   OUT VARCHAR2,
                           n_status          OUT NUMBER,
                           v_err             OUT VARCHAR2);

/*-------------------------------------------------------------------------+
 | PUBLIC PROCEDURE                                                        |
 |    create_customer                                                      |
 |                                                                         |
 | DESCRIPTION                                                             |
 |    This is a stub module for global imaging to create a customer via    |
 |    the open interface tables.                                           |
 |                                                                         |
 | ARGUMENTS                                                               |
 |    n_org_id                Organization ID                              |
 |    n_gtn_id                GTN ID                                       |
 |    n_gis_new_customer_id   Unique sequence number from GIS source       |
 |    n_gis_status            Return status of customer interface process  |
 |    d_gis_status_date       Date of customer interface process           |
 |    v_gis_customer_name     Name of new customer                         |
 |    v_err                   Error message                                |
 |                                                                         |
 | RETURNS                                                                 |
 |                                                                         |
 | NOTES                                                                   |
 |                                                                         |
 | EXAMPLE                                                                 |
 |    create_customer(4074, 23, 68, n_status, d_status_date, 'ACME', v_err)|
 |                                                                         |
 | MODIFICATION HISTORY                                                    |
 |    31-May-2000      Patrick Low     Created.                            |
 |    01-Jun-2000      Patrick Low     Convert parameters to Hungarian     |
 |                                     notation, add event logging         |
 |                                                                         |
 +-------------------------------------------------------------------------*/

PROCEDURE create_customer (n_org_id               IN  NUMBER,
                           n_gtn_id               IN  NUMBER,
                           n_gis_new_customer_id  IN  NUMBER,
                           n_gis_status           OUT NUMBER,
                           d_gis_status_date      OUT DATE,
                           v_gis_customer_name    IN  VARCHAR2,
                           v_err                  OUT VARCHAR2);

END GIS_AR_INTERFACE;
/