CREATE OR REPLACE
PACKAGE BODY apps.gis_image_util IS

--------------------------------------------------------------------------------------------------------
-- file name: gis_image_util_pkb.sql
--
-- Description: Body for utility functions and procedures used in GIS
--				All functions/procedures accessed from different web forms should be
--				placed in this package for easy reference and maintenance.
--
--	History: 24-04-2001 David Gough OTA application details added to function
--									applicationId
--           12/06/2001 David Gough init procedure added because of problems with url
--						formation on emea databases;
--           18/06/2001 Patrick Low Added menu option for Document Administrator
--
---------------------------------------------------------------------------------------------------------   

--
-- initialise global variables
--
PROCEDURE init IS
BEGIN
	c_pack_url := rtrim(FND_WEB_CONFIG.WEB_SERVER,'/')||'/'||rtrim(ltrim(icx_plug_utilities.getPLSQLagent,'/'),'/')||'/';
END init;

FUNCTION get_pack_url
RETURN VARCHAR2 IS
BEGIN
	RETURN rtrim(FND_WEB_CONFIG.WEB_SERVER,'/')||'/'||rtrim(ltrim(icx_plug_utilities.getPLSQLagent,'/'),'/')||'/';
END get_pack_url;
--
-- procedure that runs from the concurrent manager that allows the update of
-- the custom url profile option
--  
PROCEDURE UPDATE_URL( errbuf  out  varchar2,retcode out  varchar2,URL IN VARCHAR) IS

n_profo_id NUMBER(15);
n_app_id NUMBER(15);
v_selfServiceUrl VARCHAR2(250) := rtrim(FND_WEB_CONFIG.WEB_SERVER,'/')||'/'||rtrim(ltrim(icx_plug_utilities.getPLSQLagent,'/'),'/')||'/';

BEGIN
	fnd_file.put_line( fnd_file.log, 'Updating Custom URL to ' || URL);
    SELECT profile_option_id, application_id
    INTO   n_profo_id, n_app_id
    FROM   fnd_profile_options
    WHERE  profile_option_name = 'GISMIS_CUSTOM_URL';

    UPDATE fnd_profile_option_values 
    SET profile_option_value = URL
      ,last_update_date = SYSDATE
      ,last_updated_by = 1
      ,last_update_login = 0
   WHERE application_id = n_app_id
   AND   profile_option_id = n_profo_id
   AND   level_id = 10001
   AND   level_value = 0;
   
   fnd_file.put_line( fnd_file.log, 'Updating form functions URL to ' || v_selfServiceUrl);
-- now update the form functions for the required responsibilities
	UPDATE  fnd_form_functions
	SET web_host_name = v_selfServiceUrl
	,last_update_date = SYSDATE
	,last_updated_by = 1
	,last_update_login = 0
	WHERE FUNCTION_NAME IN ('GIS_01_ADMIN','GIS_02_PROCESSOR','GIS_04_INQUIRY','GIS_03_SCANNER_OPERATOR','GIS_05_REPORTS');
	COMMIT;
   fnd_file.put_line( fnd_file.log, 'Updates Completed');
	retcode := '0';                     -- (successful completion)
  	errbuf  := '';
EXCEPTION
  WHEN OTHERS 
  THEN
    retcode := '2';                   -- (error)
    fnd_message.retrieve(errbuf);
END UPDATE_URL; 

FUNCTION currentAccess( p_user_id NUMBER, p_responsibility_id NUMBER, p_function VARCHAR2)
RETURN VARCHAR2 IS

CURSOR cur_accessRights( f_user_id NUMBER, f_responsibility_id NUMBER, f_function VARCHAR2) IS
SELECT
	usr.user_name,
	usrep.responsibility_id,
	usrep.responsibility_application_id,
	func.function_name
	,resp.responsibility_name
FROM
	fnd_user usr
	,fnd_user_resp_groups usrep
	,fnd_responsibility_vl resp
	,fnd_menus menu
	,fnd_menu_entries ent
	,fnd_form_functions func
WHERE usr.user_id = f_user_id --1000081
AND usrep.responsibility_id = f_responsibility_id --52379
AND func.function_name = f_function --'GIS_ADMIN'
AND usrep.responsibility_id = resp.responsibility_id
AND resp.application_id = usrep.responsibility_application_id
AND usr.user_id = usrep.user_id
AND nvl(usrep.end_date,SYSDATE+1) > SYSDATE
AND nvl(usr.end_date,SYSDATE+1) > SYSDATE
AND resp.menu_id = menu.menu_id
AND menu.menu_id = ent.menu_id
AND ent.function_id = func.function_id;

l_returnValue gis_search.stdVarchar := 'NOT_FOUND';

BEGIN
	FOR rec IN cur_accessRights( p_user_id, p_responsibility_id, p_function)
	LOOP
		l_returnValue := rec.responsibility_name;
	END LOOP;                 
	RETURN l_returnValue;
END currentAccess;

FUNCTION userAccessRights( p_user_id NUMBER, p_responsibility_id NUMBER) RETURN VARCHAR2
IS

CURSOR cur_accessRights( f_user_id NUMBER, f_responsibility_id NUMBER, f_function VARCHAR2) IS
SELECT
	usr.user_name,
	usrep.responsibility_id,
	usrep.responsibility_application_id,
	func.function_name
FROM
	fnd_user usr
	,fnd_user_resp_groups usrep
	,fnd_responsibility resp
	,fnd_menus menu
	,fnd_menu_entries ent
	,fnd_form_functions func
WHERE usr.user_id = f_user_id --1000081
AND usrep.responsibility_id = f_responsibility_id --52379
AND func.function_name = f_function --'GIS_ADMIN'
AND usrep.responsibility_id = resp.responsibility_id
AND resp.application_id = usrep.responsibility_application_id
AND usr.user_id = usrep.user_id
AND nvl(usrep.end_date,SYSDATE+1) > SYSDATE
AND nvl(usr.end_date,SYSDATE+1) > SYSDATE
AND resp.menu_id = menu.menu_id
AND menu.menu_id = ent.menu_id
AND ent.function_id = func.function_id;

row_accessRights cur_accessRights%ROWTYPE;
l_access VARCHAR2(50);
l_functionList gis_search.stringArray := gis_search.stringArray( 'GIS_01_ADMIN'
																,'GIS_03_SCANNER_OPERATOR'
																,'GIS_04_INQUIRY'
																,'GIS_10_APPS_INQUIRY'
																,'GIS_02_PROCESSOR'
																,'GIS_05_REPORTS'
																,'GIS_06_DOCUMENT_ADMINSTRATOR');
BEGIN
--    FOR i  IN 1..l_functionList.last AND l_returnValue = 'NOT_FOUND'
--    LOOP
--    	l_returnValue :=( p_user_id, p._responsibility_id, l_functionList(i));-- != 'NOT_FOUND'
--    	IF l_returnValue  != 'NOT_FOUND'
--    	THEN
--    		l_returnValue := 	
--    	END IF
    
--    END LOOP;
	
    IF NOT cur_accessRights%ISOPEN THEN
      OPEN cur_accessRights( p_user_id, p_responsibility_id, 'GIS_01_ADMIN');
    END IF;  
    FETCH cur_accessRights INTO row_accessRights;
    IF cur_accessRights%FOUND THEN
		RETURN 'Administration User';
    END IF;
    CLOSE cur_accessRights;

    IF NOT cur_accessRights%ISOPEN THEN
      OPEN cur_accessRights( p_user_id, p_responsibility_id, 'GIS_03_SCANNER_OPERATOR');
    END IF;
    FETCH cur_accessRights INTO row_accessRights;
    IF cur_accessRights%FOUND THEN
		RETURN 'Scan Operator';
    END IF;
    CLOSE cur_accessRights;
    
    IF NOT cur_accessRights%ISOPEN THEN
      OPEN cur_accessRights( p_user_id, p_responsibility_id, 'GIS_04_INQUIRY');
    END IF;
    FETCH cur_accessRights INTO row_accessRights;
    IF cur_accessRights%FOUND THEN
		RETURN 'Inquiry User';
    END IF;
    CLOSE cur_accessRights;

    IF NOT cur_accessRights%ISOPEN THEN
      OPEN cur_accessRights( p_user_id, p_responsibility_id, 'GIS_10_APPS_INQUIRY');
    END IF;
    FETCH cur_accessRights INTO row_accessRights;
    IF cur_accessRights%FOUND THEN
		RETURN 'Inquiry User';
    END IF;
    CLOSE cur_accessRights;
    
    IF NOT cur_accessRights%ISOPEN THEN
      OPEN cur_accessRights( p_user_id, p_responsibility_id, 'GIS_02_PROCESSOR');
    END IF;
    FETCH cur_accessRights INTO row_accessRights;
    IF cur_accessRights%FOUND THEN
		RETURN 'Process User';
    END IF;
    CLOSE cur_accessRights;

    IF NOT cur_accessRights%ISOPEN THEN
      OPEN cur_accessRights( p_user_id, p_responsibility_id, 'GIS_05_REPORTS');
    END IF;
    FETCH cur_accessRights INTO row_accessRights;
    IF cur_accessRights%FOUND THEN
		RETURN 'Reports User';
    END IF;
    CLOSE cur_accessRights;

    IF NOT cur_accessRights%ISOPEN THEN
      OPEN cur_accessRights( p_user_id, p_responsibility_id, 'GIS_06_DOCUMENT_ADMINSTRATOR');
    END IF;
    FETCH cur_accessRights INTO row_accessRights;
    IF cur_accessRights%FOUND THEN
		RETURN 'Document Administrator';
    END IF;
    CLOSE cur_accessRights;
    
	RETURN 'Error';
END userAccessRights;

FUNCTION applicationId( p_context VARCHAR2) 
RETURN NUMBER IS

l_appId NUMBER(15);

BEGIN
	IF p_context = 'Order Management' OR p_context = 'Agreements' OR p_context = 'Customer'
	THEN
		l_appId := gis_image_util.n_omAppId;
	ELSIF p_context = 'Receivables'
	THEN
		l_appId := gis_image_util.n_arAppId;
	ELSIF p_context = 'Projects'
	THEN
		l_appId := gis_image_util.n_paAppId;
	ELSIF p_context = 'Payables' OR p_context = 'Web Expenses'
	THEN
		l_appId := gis_image_util.n_apAppId;
	ELSIF p_context = 'Contracts'
	THEN
		l_appId := gis_image_util.n_coAppId;
	ELSIF p_context = 'Education Bookings' OR p_context = 'Education Events'
	THEN
		l_appId := gis_image_util.n_otaAppId;
	ELSIF p_context = 'HR Assignments'
	THEN
		l_appId := gis_image_util.n_hrAppId;
	ELSIF p_context = 'Suppliers'
	THEN
		l_appId := gis_image_util.n_poAppId;
	END IF;	
	RETURN l_appId;
END applicationId;

PROCEDURE whiteFrame IS

BEGIN
htp.p('<HTML>');
htp.p('<HEAD>');
htp.p('	<TITLE>Global Imaging System v2</TITLE>');
htp.p('<BODY>');
htp.p('<P>');
htp.p('</HEAD>');
htp.p('</BODY>');
htp.p('</HTML>');
END;

PROCEDURE imagingStart(p_user_id           VARCHAR2 DEFAULT NULL,
                       p_responsibility_id VARCHAR2 DEFAULT NULL,
                       p_resolution_height VARCHAR2 DEFAULT NULL)
IS

BEGIN
    -- Modified by Patrick Low: 06/03/2001
    -- Write cookie with resolution information
    owa_util.mime_header('text/html', false);
    owa_cookie.send('gis_resolution_height', p_resolution_height);
    owa_util.http_header_close;

	htp.p('<HTML>');
	htp.p('<HEAD>');
--	htp.p( '<SCRIPT LANGUAGE="javascript">' );
--	htp.p( 'aWindow = window.open("","theWindow","toolbar = no","menubar=no")');
--	htp.p( '</SCRIPT>');
	htp.p('	<TITLE>Global Imaging System v2 - '|| userAccessRights( p_user_id ,p_responsibility_id)||' </TITLE>');
	htp.p('</HEAD>');
    -- Modified by Patrick Low: 06/03/2001
    -- Make frames a % of screen width to handle higher resolution monitor usage
--	htp.p('<FRAMESET   COLS="325,*"  BORDER="1" >');
	htp.p('<FRAMESET   COLS="33%,67%"  BORDER="1" >');
	htp.p('	<FRAMESET  ROWS = "45%,55% " BORDER="0" >');
	htp.p('		<FRAME SRC="'||c_pack_url||'gis_image_util.OptionFrame?p_user_id='||p_user_id||'&p_responsibility_id='||p_responsibility_id||'" NAME="SelectFrame"  MARGINWIDTH="0" MARGINHEIGHT="0" SCROLLING="auto">');
	--htp.p('		<FRAME SRC="'||c_pack_url||'gis_image_util.BlankFrame" NAME="SelectFrame" MARGINWIDTH="0" MARGINHEIGHT="0" SCROLLING="auto">');
	htp.p('		<FRAME SRC="'||c_pack_url||'gis_image_util.Blankframe" NAME="QueryFrame"  MARGINWIDTH="0" MARGINHEIGHT="0" SCROLLING="auto">');
	htp.p('	</FRAMESET>');
	htp.p('	<FRAME SRC="'||c_pack_url||'gis_image_util.whiteframe" NAME="ViewingFrame" SCROLLING="auto" NORESIZE>');
	--htp.p('	<FRAME SRC="http://fintst3.us.oracle.com:2112/hrdev/gis_image_util.ViewingFrame" NAME="ViewingFrame" SCROLLING="auto" NORESIZE>');
	htp.p('</FRAMESET>');
	htp.p('<NOFRAMES>');
	htp.p('<BODY>');
	htp.p('<P>');
	htp.p('</BODY>');
	htp.p('</NOFRAMES>');
	htp.p('</HTML>');
END imagingStart;

PROCEDURE SaveComments(p_file_id NUMBER,
                       p_comment VARCHAR2,
                       p_input   VARCHAR2,
                       p_user_id NUMBER) IS
  CURSOR cComment IS
    SELECT doc.rowid doc_rowid, v.comments_id, text.rowid text_rowid
    FROM   fnd_documents_tl doc, fnd_documents_tl_dfv v, fnd_documents_short_text text, fnd_documents d
    WHERE  doc.media_id = p_file_id
    AND    doc.rowid = v.rowid
    AND    text.media_id(+) = TO_NUMBER(v.comments_id)
    AND    doc.document_id = d.document_id
    AND    d.datatype_id = 
      (SELECT datatype_id
       FROM   fnd_document_datatypes
       WHERE  name = 'FILE'
       AND    NVL(start_date_active, SYSDATE) <= SYSDATE
       AND    NVL(end_date_active, SYSDATE) >= SYSDATE);
  rComment cComment%ROWTYPE;
  nMediaID NUMBER := NULL;
  vUser    VARCHAR2(100) := NULL;
BEGIN
  IF p_input IS NOT NULL THEN
    SELECT user_name
    INTO   vUser
    FROM   fnd_user
    WHERE  user_id = p_user_id;
    OPEN cComment;
    FETCH cComment INTO rComment;
    IF rComment.text_rowid IS NOT NULL THEN
      -- Update comment
      UPDATE fnd_documents_short_text
        SET  short_text = short_text ||
                          CHR(10) ||
                          CHR(10) ||
                          vUser || ': ' || TO_CHAR(SYSDATE, 'DD-MON-YYYY HH24:MI:SS') ||
                          CHR(10) ||
                          CHR(10) ||
                          p_input
        WHERE rowid = rComment.text_rowid;
    ELSE
      -- Insert comment
      SELECT fnd_documents_short_text_s.nextval
      INTO   nMediaID
      FROM   dual;
      INSERT INTO fnd_documents_short_text
        (media_id,
         short_text,
         app_source_version)
      VALUES
        (nMediaID,
         vUser || ': ' || TO_CHAR(SYSDATE, 'DD-MON-YYYY HH24:MI:SS') ||
         CHR(10) ||
         CHR(10) ||
         p_input,
         'GIS');
      UPDATE fnd_documents_tl_dfv
        SET  comments_id = nMediaID
        WHERE rowid = rComment.doc_rowid;
    END IF;
    CLOSE cComment;
    COMMIT;
  END IF;
  htp.p('<SCRIPT language="javaScript">
<!--BEGIN Script
function closeWindow()
{
  setTimeout("window.close();", 1500)
}
//-->
</SCRIPT>');
  gis_image_util.pageopen(p_heading => 'Comments For File ' || TO_CHAR(p_file_id), p_attrib => 'onLoad="closeWindow()"');
  gis_image_util.InfoHeader('Comments For File ' || TO_CHAR(p_file_id));
  htp.p('<FORM>');
  htp.p('<TABLE WIDTH="95%" BORDER="0" CELLSPACING="0" CELLPADDING="1">');          
  htp.p('<TR>' );
  IF p_input IS NOT NULL THEN
    htp.p('<TD ALIGN="CENTER"><FONT SIZE=2>Comment saved successfully</FONT></TD>');
  ELSE
    htp.p('<TD ALIGN="CENTER"><FONT SIZE=2>NO comments entered</FONT></TD>');
  END IF;
  htp.p('</TR>' );
  htp.p('</TABLE>');
  htp.p('<TABLE WIDTH="95%" BORDER="0" CELLSPACING="0" CELLPADDING="1">');  
  htp.p('    <TR>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('      <TD WIDTH="98%" ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('    </TR>');
  htp.p('    <TR>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
--  htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><INPUT type="button" onClick="window.close()" value=" OK "></TD>');
  htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><A HREF="javascript:window.close()" onMouseOver="window.status=''Close''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || c_image_url || 'b_ok_m.gif" BORDER="0" ALT="Close" ALIGN="TOP"></A>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('    </TR>');
  htp.p('  </TABLE>');
  htp.p('</FORM>');
  gis_image_util.pageclose;
END SaveComments;

PROCEDURE LogComments(p_file_id NUMBER,
                      p_user_id NUMBER) IS
  CURSOR cDoc IS
    SELECT v.comments_id
    FROM   fnd_documents_tl t, fnd_documents_tl_dfv v, fnd_documents d
    WHERE  t.media_id = p_file_id
    AND    t.rowid = v.rowid
    AND    t.document_id = d.document_id
    AND    d.datatype_id = 
      (SELECT datatype_id
       FROM   fnd_document_datatypes
       WHERE  name = 'FILE'
       AND    NVL(start_date_active, SYSDATE) <= SYSDATE
       AND    NVL(end_date_active, SYSDATE) >= SYSDATE);
  rDoc     cDoc%ROWTYPE;
  CURSOR cComments IS
    SELECT short_text
    FROM   fnd_documents_short_text
    WHERE  media_id = TO_NUMBER(rDoc.comments_id);
   rComments cComments%ROWTYPE;
BEGIN
  -- Use onBlur to keep comments window ALWAYS ON TOP
  gis_image_util.pageopen(p_heading => 'Comments For File ' || TO_CHAR(p_file_id), p_attrib => 'onLoad="window.focus()" onBlur="window.focus()"');
  gis_image_util.InfoHeader('Comments For File ' || TO_CHAR(p_file_id));
  htp.formOpen('gis_image_util.savecomments', 'POST', cattributes=>'NAME="log_comments"');
  htp.formHidden('p_file_id', TO_CHAR(p_file_id));
  htp.p('<TABLE WIDTH="95%" BORDER="0" CELLSPACING="0" CELLPADDING="1">');  
  htp.p('    <TR>');
  htp.p('      <TD COLSPAN=3  ALIGN="CENTER" VALIGN="MIDDLE">Comments History</TD>');
  htp.p('    </TR>');
  OPEN cDoc;
  FETCH cDoc INTO rDoc;
  htp.p('    <TR>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  IF cDoc%FOUND THEN
    OPEN cComments;
    FETCH cComments INTO rComments;
    IF cComments%FOUND THEN
      htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><TEXTAREA READONLY NAME="p_comment" ROWS=10 COLS=70 WRAP=PHYSICAL>' || rComments.short_text || '</TEXTAREA></TD>');
    ELSE
      htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><TEXTAREA READONLY NAME="p_comment" ROWS=10 COLS=70 WRAP=PHYSICAL></TEXTAREA></TD>');
    END IF;
    CLOSE cComments;
  ELSE
    htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><INPUT type="text" name="p_comment" ></TD>');  
  END IF;
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('    </TR>');
  htp.p('    <TR>');
  htp.p('      <TD COLSPAN=3  ALIGN="CENTER" VALIGN="MIDDLE">Log Comment</TD>');
  htp.p('    </TR>');
  htp.p('    <TR>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><TEXTAREA NAME="p_input" ROWS=10 COLS=70 WRAP=PHYSICAL></TEXTAREA></TD>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('    </TR>');
  CLOSE cDoc;
  htp.p('    <TR>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><A HREF="javascript:window.close()" onMouseOver="window.status=''Cancel''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || c_image_url || 'b_cancel_l.gif" BORDER="0" ALT="Cancel" ALIGN="TOP"></A>');
  htp.p('      <A HREF="javascript:document.log_comments.submit()" onMouseOver="window.status=''Save''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || c_image_url || 'b_save_r.gif" BORDER="0" ALT="Save" ALIGN="TOP"></A></TD>');
  htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || c_image_url || 'empty.gif"></TD>');
  htp.p('    </TR>');
  htp.p('  </TABLE>');
  htp.formHidden('p_user_id', TO_CHAR(p_user_id));
  htp.p('</FORM>');
  gis_image_util.pageclose;
END LogComments;

PROCEDURE UpdateLocation(p_user_id      NUMBER,
                         p_process      VARCHAR2 DEFAULT NULL,
                         p_old_location VARCHAR2 DEFAULT NULL,
                         p_new_location VARCHAR2 DEFAULT NULL,
                         p_scanner_id   VARCHAR2 DEFAULT NULL,
                         p_search_user  VARCHAR2 DEFAULT NULL) IS

  v_SQL             VARCHAR2(5000) := NULL;
  v_SQLUpdate       VARCHAR2(5000) := NULL;
  TYPE              cv_type IS REF CURSOR;
  cShow             cv_type;
  c_Scanner_Id      gis_scanners.scanner_id%TYPE;
  c_Processed_By    fnd_user.user_name%TYPE;
  c_Location        fnd_documents_tl_dfv.storage_location%TYPE;
  c_Doc_Category    fnd_documents_tl.doc_attribute_category%TYPE;
  c_Description     fnd_documents_tl.description%TYPE;

  cursor_name    INTEGER;
  rows_processed INTEGER;
BEGIN
  htp.p('<SCRIPT language="javaScript">
<!--BEGIN Script
function clearWindow()
{
  setTimeout("viewimage('''', '''', ''gis_image_util.ViewingFrame'');", 1500)
}
//-->
</SCRIPT>');
  IF NVL(p_process, 'NULL') = 'UPDATE' THEN
    gis_image_util.pageopen(p_heading => 'Update Storage Location', p_attrib => 'onLoad="clearWindow()"');
  ELSE
    gis_image_util.pageopen(p_heading => 'Update Storage Location');
  END IF;
  gis_image_util.InfoHeader('Update Storage Location');
  IF NVL(p_process, 'NULL') = 'UPDATE' THEN
    htp.formOpen('gis_image_util.blankFrame', 'POST', cattributes=>'NAME="updatelocation"');
  ELSE
    htp.formOpen('gis_image_util.updatelocation', 'POST', cattributes=>'NAME="updatelocation"');
    htp.formHidden('p_user_id', TO_CHAR(p_user_id));
  END IF;
  htp.p('<SCRIPT language="javaScript">
<!--BEGIN Script
function checkFields()
{
  var nullError = ""
  var returnValue
  
  if (document.updatelocation.p_old_location.value == "" && nullError == "")
  {
    confirm("Old location is required.")
    nullError = "1"
    document.updatelocation.p_old_location.focus()
  }
  if (document.updatelocation.p_new_location.value == "" && nullError == "")
  {
    confirm("New location is required.")
    nullError = "1"
    document.updatelocation.p_new_location.focus()
  }
  if (nullError != "")
  {
    nullError = ""
  }
  else 
  {
    document.updatelocation.submit()
  }
}
//-->
</SCRIPT>');
  IF p_process IS NULL AND
     p_old_location IS NULL AND
     p_new_location IS NULL THEN
    -- Show inputs to do update
    htp.p('<TABLE WIDTH="95%" BORDER="1" CELLSPACING="0" CELLPADDING="1">');
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="CENTER" COLSPAN=2><FONT SIZE=2>Location Details</FONT></TD>');      
    htp.p('  </TR>' );
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="RIGHT"><FONT SIZE=2>Old Location</FONT></TD>');      
    htp.p('    <TD ALIGN="LEFT"><FONT SIZE=2><INPUT type="text" name="p_old_location" size="22" maxlength="100"></FONT></TD>');
    htp.p('  </TR>' );
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="RIGHT"><FONT SIZE=2>New Location</FONT></TD>');      
    htp.p('    <TD ALIGN="LEFT"><FONT SIZE=2><INPUT type="text" name="p_new_location" size="22" maxlength="100"></FONT></TD>');
    htp.p('  </TR>' );
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="CENTER" COLSPAN=2><FONT SIZE=2>Search Details</FONT></TD>');      
    htp.p('  </TR>' );
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="RIGHT"><FONT SIZE=2>Scanner ID</FONT></TD>');      
    htp.p('    <TD ALIGN="LEFT"><FONT SIZE=2><INPUT type="text" name="p_scanner_id" size="22" maxlength="100"></FONT></TD>');
    htp.p('  </TR>' );
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="RIGHT"><FONT SIZE=2>User ID</FONT></TD>');      
    htp.p('    <TD ALIGN="LEFT"><FONT SIZE=2><INPUT type="text" name="p_search_user" size="22" maxlength="100"></FONT></TD>');
    htp.p('  </TR>' );
    htp.p('</TABLE>' );
    htp.p('<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');  
    htp.p('  <TR>');
    htp.p('    <TD WIDTH="98%" ALIGN="CENTER"><A HREF="javascript:checkFields()" onMouseOver="window.status=''OK''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || c_image_url || 'b_ok_m.gif" BORDER="0" ALT="OK" ALIGN="TOP"></A></TD>');
    htp.p('  </TR>');
    htp.p('</TABLE>');
    htp.formHidden('p_process', 'SHOW');
  ELSIF p_process = 'SHOW' AND
        p_old_location IS NOT NULL AND
        p_new_location IS NOT NULL THEN
    -- Build SQL statement dynamically for mulitple variable input
    v_SQL := 'SELECT s.scanner_id, u.user_name processed_by, v.storage_location, t.doc_attribute_category, t.description ' ||
             'FROM   fnd_documents_tl t, fnd_documents_tl_dfv v, fnd_lobs l, ' ||
             '       gis_scanners s, gis_doc_status stat, gis_doc_status_types st, fnd_user u ' ||
             'WHERE  t.rowid = v.rowid ' ||
             'AND    v.index_status_id = ''PROCESSED'' ' ||
             'AND    v.storage_location = ''' || p_old_location || ''' ' ||
             'AND    t.media_id = l.file_id ' ||
             'AND    l.program_name = ''GIS'' ' ||
             'AND    l.program_tag = s.scanner_id ' ||
             'AND    t.document_id = stat.document_id ' ||
             'AND    stat.doc_status_type_id = st.doc_status_type_id ' ||
             'AND    st.doc_status_name = ''PROCESSED'' ' ||
             'AND    stat.last_updated_by = u.user_id ';
    IF p_scanner_id IS NOT NULL THEN
      v_SQL := v_SQL || 'AND    s.scanner_id = ''' || UPPER(RTRIM(p_scanner_id)) || ''' ';
    END IF;
    IF p_search_user IS NOT NULL THEN
      v_SQL := v_SQL || 'AND    u.user_name = ''' || UPPER(RTRIM(p_search_user)) || ''' ';
    END IF;

    htp.p('<TABLE WIDTH="100%" BORDER="1" CELLSPACING="0" CELLPADDING="2">');  
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Scanner</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Processed By</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Location</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Doc Category</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Description</FONT></TD>');
    htp.p('  </TR>');

    OPEN cShow FOR v_SQL;
    LOOP
      FETCH cShow INTO c_Scanner_Id, c_Processed_By, c_Location, c_Doc_Category, c_Description;
      EXIT WHEN cShow%NOTFOUND;
      /* Show data for search */
      htp.p('  <TR>' );
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || c_Scanner_Id || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || c_Processed_By || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || c_Location || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || c_Doc_Category || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || c_Description || '</FONT></TD>');
      htp.p('  </TR>');
    END LOOP;
    CLOSE cShow;
    htp.p('</TABLE>');
    htp.formHidden('p_process', 'UPDATE');
    htp.formHidden('p_old_location', p_old_location);
    htp.formHidden('p_new_location', p_new_location);    
    htp.formHidden('p_scanner_id', p_scanner_id);
    htp.formHidden('p_search_user', p_search_user);
    htp.p('<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');  
    htp.p('  <TR>');
    htp.p('    <TD WIDTH="98%" ALIGN="CENTER"><A HREF="javascript:document.updatelocation.submit()" onMouseOver="window.status=''OK''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || c_image_url || 'b_ok_m.gif" BORDER="0" ALT="OK" ALIGN="TOP"></A></TD>');
    htp.p('  </TR>');
    htp.p('</TABLE>');
  ELSE
    -- Update all old locations to new locations

    v_SQL := 'SELECT v.rowid ' ||
             'FROM   fnd_documents_tl t, fnd_documents_tl_dfv v, fnd_lobs l, ' ||
             '       gis_scanners s, gis_doc_status stat, gis_doc_status_types st, fnd_user u ' ||
             'WHERE  t.rowid = v.rowid ' ||
             'AND    v.index_status_id = ''PROCESSED'' ' ||
             'AND    v.storage_location = ''' || p_old_location || ''' ' ||
             'AND    t.media_id = l.file_id ' ||
             'AND    l.program_name = ''GIS'' ' ||
             'AND    l.program_tag = s.scanner_id ' ||
             'AND    t.document_id = stat.document_id ' ||
             'AND    stat.doc_status_type_id = st.doc_status_type_id ' ||
             'AND    st.doc_status_name = ''PROCESSED'' ' ||
             'AND    stat.last_updated_by = u.user_id ';
    IF p_scanner_id IS NOT NULL THEN
      v_SQL := v_SQL || 'AND    s.scanner_id = ''' || UPPER(RTRIM(p_scanner_id)) || ''' ';
    END IF;
    IF p_search_user IS NOT NULL THEN
      v_SQL := v_SQL || 'AND    u.user_name = ''' || UPPER(RTRIM(p_search_user)) || ''' ';
    END IF;

    -- Update WHO info first
    v_SQLUpdate := 'UPDATE fnd_documents_tl SET last_updated_by = ' || TO_CHAR(p_user_id) || ', ' ||
                   'last_update_date = SYSDATE ' ||
                   'WHERE rowid IN ' ||
                   '(' ||
                   v_SQL ||
                   ')';
    cursor_name := dbms_sql.open_cursor;
    DBMS_SQL.PARSE(cursor_name, v_SQLUpdate, dbms_sql.native);
    rows_processed := dbms_sql.execute(cursor_name);
    DBMS_SQL.close_cursor(cursor_name);

    -- Update rows by old value    
    v_SQLUpdate := 'UPDATE fnd_documents_tl_dfv SET storage_location = ''' || p_new_location || ''' ' ||
                   'WHERE rowid IN ' ||
                   '(' ||
                   v_SQL ||
                   ')';
    cursor_name := dbms_sql.open_cursor;
    DBMS_SQL.PARSE(cursor_name, v_SQLUpdate, dbms_sql.native);
    rows_processed := dbms_sql.execute(cursor_name);
    DBMS_SQL.close_cursor(cursor_name);
    COMMIT;
    
    htp.p('<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');  
    htp.p('  <TR>');
    htp.p('    <TD WIDTH="98%" ALIGN="CENTER">Updated storage location from ''' || p_old_location || ''' to ''' || p_new_location || ''' for listed images.</A></TD>');
    htp.p('  </TR>');
    htp.p('  <TR>');
    htp.p('    <TD WIDTH="98%" ALIGN="CENTER"><A HREF="javascript:viewimage('''', '''', ''gis_image_util.ViewingFrame'');" onMouseOver="window.status=''OK''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || c_image_url || 'b_ok_m.gif" BORDER="0" ALT="OK" ALIGN="TOP"></A></TD>');
    htp.p('  </TR>');
    htp.p('</TABLE>');
  END IF;
  htp.p('</FORM>');
  gis_image_util.pageclose;
END UpdateLocation;

PROCEDURE ViewingFrame( p_userType VARCHAR2 DEFAULT NULL) IS

BEGIN
	htp.p('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2//EN">');
	htp.p('<HTML>');
	htp.p('<HEAD>');
	htp.p('	<META NAME="GENERATOR" Content="Visual Page 1.0 for Windows">');
	htp.p('	<META HTTP-EQUIV="Content-Type" CONTENT="text/html;CHARSET=iso-8859-1">');
	htp.p('	<TITLE>Viewing Frame</TITLE>');
    htp.p('     <SCRIPT LANGUAGE = "javaScript" src="'||c_jscript_url||'core_functions.js">');
    htp.p('     </SCRIPT>');
--	htp.p('	<LINK 	rel= STYLESHEET');
--	htp.p('		href="'||c_html_url||'core_styles.css"');
--	htp.p('		type="text/css">');
	htp.p('</HEAD>');
	htp.p('<BODY onLoad="checkplugin()"> ');
	htp.p('<HR>');
	htp.p('<DIV CLASS="logo" id="applog">');
	htp.p('	<TABLE  WIDTH="50%" ALIGN="CENTER" CELLSPACING="0" CELLPADDING="3" BORDER="0">');
	htp.p('		<TR>');
	htp.p('		<TR></TR>');
	htp.p('			<TD>');
	htp.p('				<IMG SRC= "'||c_image_url||'logo.gif"  ALIGN="CENTRE" ALT="logo.gif">');
	htp.p('			</TD>');
	htp.p('		</TR>');
	htp.p('		<TR></TR>');
	htp.p('	</TABLE>');
	htp.p('	<TABLE  WIDTH="25%" ALIGN="CENTER" CELLSPACING="0" CELLPADDING="3" BORDER="0">');
	htp.p('		<TR>');
	htp.p('			<TD>');
	htp.p('				<IMG SRC="'||c_image_url||'appslogo.gif"   ALT="appslogo.gif">');
	htp.p('			</TD>');
	htp.p('		</TR>');
	htp.p('	</TABLE>');
	htp.p('	<TABLE  WIDTH="95%" ALIGN="CENTER" CELLSPACING="0" CELLPADDING="0" BORDER="0">');
	htp.p('		<TR>');
	htp.p('			<TD ALIGN="CENTER">');
	htp.p('				<BASEFONT   SIZE="4"><P><B>Global Imaging System - '|| p_userType || '</B></P></BASEFONT>');
	htp.p(rtrim(FND_WEB_CONFIG.WEB_SERVER,'/')||'/'||rtrim(ltrim(icx_plug_utilities.getPLSQLagent,'/'),'/')||'/');
	htp.p('			</TD>');
	htp.p('		</TR>');
	htp.p('	</TABLE>');
	htp.p('</DIV>');
	htp.p('<HR>');
	htp.p('</body>');
	htp.p('</HTML>');
END Viewingframe;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE OptionFrame(p_user_id VARCHAR2 DEFAULT NULL, p_responsibility_id VARCHAR2 DEFAULT NULL) IS

vUseraccess VARCHAR2(25); 
l_noAccess BOOLEAN := TRUE;

BEGIN
	htp.p('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Frameset//EN" "http://www.w3.org/TR/REC-html40/frameset.dtd">');
	pageopen(p_heading=>'Global Imaging System v2',p_procedure=>'OptionFrame');
	htp.p('<TABLE WIDTH="100%" CELLSPACING="0" CELLPADDING="3" BORDER="0">');
	htp.p('  <TR>');
		-- Amended by Patrick Low: 10-AUG-2000
		--   - update to have link to call PreIndex package code from Index link

-- the options available are dependent on the users access ( GIS Responsibility)
	vUseraccess := userAccessRights( p_user_id ,p_responsibility_id);
	
--	l_noAccess := TRUE;
	IF vUseraccess = 'Scan Operator'
	THEN  		
	    htp.p( '<SCRIPT LANGUAGE="javascript">' );
    	htp.p( 'menu(1,'''||c_pack_url||'gis_preindex.list_doc_types?p_user_id=' || p_user_id || ''',
						'''||c_pack_url||'gis_image_util.Blankframe'');
				parent.ViewingFrame.location = "'||c_pack_url||'gis_image_util.ViewingFrame?p_userType=Scanner+Operator";
    			</SCRIPT>');
    	l_noAccess := FALSE;
	END IF;
	IF vUseraccess = 'Process User'
	THEN 
	    htp.p( '<SCRIPT LANGUAGE="javascript">' );
    	htp.p( 'menu(2,'''||c_pack_url||'gis_process_image.BlankFrame'',
						'''||c_pack_url||
						'gis_search.QueryContext?p_document=&p_navTo=gis_process_image.processImage&p_target=SelectFrame&p_userType=Process+User&p_userId='||
						p_user_id||'&p_respId='||p_responsibility_id||''')' );
    	htp.p( '</SCRIPT>');
    	l_noAccess := FALSE;
	END IF;
	IF vUseraccess = 'Administration User'
	THEN
	    htp.p( '<SCRIPT LANGUAGE="javascript">' );
    	htp.p( 'menu(3,'''||c_pack_url||'gis_admin_screen.adminMenu?p_userId=' || p_user_id || ''',
						'''||c_pack_url||'gis_image_util.Blankframe'')' );
    	htp.p( '</SCRIPT>');
    	l_noAccess := FALSE;
	END IF;

	IF vUseraccess = 'Inquiry User'
	THEN
	    htp.p( '<SCRIPT LANGUAGE="javascript">' );
    	htp.p( 'menu(4,'''||c_pack_url||'gis_search.QueryIndex?p_document=&p_userType=Inquiry+User&p_userId='||
    				p_user_id||'&p_respId='||p_responsibility_id||''','''||c_pack_url||'gis_image_util.Blankframe'')' );
    	htp.p( '</SCRIPT>');
    	l_noAccess := FALSE;
	END IF;

    -- Added: Patrick Low 12/03/2001
     --       Add option to call reports package from reports link in SSA
	IF vUseraccess = 'Reports User'
	THEN
	    htp.p( '<SCRIPT LANGUAGE="javascript">' );
    	htp.p( 'menu(1,'''||c_pack_url||'gis_metrics_report.show_fields?p_user_id='||
                     p_user_id||''','''||c_pack_url||'gis_image_util.BlankFrame'');
                parent.ViewingFrame.location = "'||c_pack_url||'gis_image_util.ViewingFrame?p_userType=Reports+User";' );
    	htp.p( '</SCRIPT>');
    	l_noAccess := FALSE;
	END IF;

	IF vUseraccess = 'Document Administrator'
	THEN
	    htp.p( '<SCRIPT LANGUAGE="javascript">' );
    	htp.p( 'menu(1,'''||c_pack_url||'gis_attach_util.adminMenu?p_user_id=' || p_user_id || ''',
                       '''||c_pack_url||'gis_image_util.Blankframe'');
                parent.ViewingFrame.location = "'||c_pack_url||'gis_image_util.ViewingFrame?p_userType=Document+Administrator";' );
    	htp.p( '</SCRIPT>');
    	l_noAccess := FALSE;
	END IF;

	IF l_noAccess
	THEN
		htp.p('<B>No Access Rights Found</B>');
	END IF;
	htp.p('		</TD>');
	htp.p('  </TR>');
-- will need this later
--	htp.p('  <TR>');
--	htp.p('    <TD ALIGN="CENTER"><SPAN CLASS="info">User:&nbsp;David Gough&nbsp;&middot;&nbsp;</SPAN><A HREF="img_util.menu" onClick="window.open( ''/imaging'', ''usersGuide'', ''height=600,width=700,scrollbars,titlebar,resizable'' )" onMouseOver="window.status=''Users` Guide''; return true" onMouseOut="window.status=''; return true" CLASS="info">Users''&nbsp;Guide</A><SPAN CLASS="info">&nbsp;&middot;&nbsp</SPAN><SPAN CLASS="info">Any&nbsp;problem?&nbsp;</SPAN><A HREF="mailto:sscimaging@ie.oracle.com" CLASS="info">Email us!</A></TD>');
--	htp.p('  </TR>');
	htp.p('</TABLE>');
	pageclose;
END OptionFrame;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE BlankFrame IS

BEGIN
	pageopen(p_heading => 'Document Search',p_procedure=>'BlankFrame');
	infoHeader(' Imaging System');
	pageclose;
END BlankFrame;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE InfoHeader(p_heading  VARCHAR2 DEFAULT NULL
                     , p_image VARCHAR2 DEFAULT 'searching2.gif'
                     , p_attrib VARCHAR2 DEFAULT NULL
                     ,p_right_image VARCHAR2 DEFAULT 'empty.gif'
                     ,p_alt_value VARCHAR2 DEFAULT NULL
                     ,p_right_link VARCHAR2 DEFAULT NULL) IS
                     
  CURSOR cur_docContext IS
    SELECT 'All' descriptive_flex_context_code
    FROM   dual
    UNION
    SELECT con.descriptive_flex_context_code
    FROM   FND_DESCR_FLEX_CONTEXTS_VL con
    WHERE  con.descriptive_flexfield_name = 'ATCHMT_DOCUMENT_FLEX'
    AND    descriptive_flex_context_code != 'Global Data Elements'
    ORDER BY descriptive_flex_context_code;
    row_docContext cur_docContext%ROWTYPE;
BEGIN 
	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('    <TR BGCOLOR="#C9C9C9">');--"#102031">');
	htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="'||c_image_url||p_image||'"></TD>');
	htp.p('      <TD WIDTH="98%" ALIGN="CENTER"><FONT color=BLACK SIZE=3><B>'|| p_heading ||'</B></FONT></TD>');
	htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE">');
	IF  p_right_link IS NULL
	THEN
	     htp.p('<IMG SRC="'||c_image_url||p_right_image||'" ALT="'||p_alt_value||'"></TD>');	    
	ELSE
	     htp.p('<A HREF="javaScript:'||p_right_link||'"><IMG SRC="'||c_image_url||p_right_image||'" ALT="'||p_alt_value||'"></A></TD>');
    END IF;
	htp.p('    </TR>');
	htp.p('  </TABLE>');
--	htp.p('    <TR>');
--	htp.p('      <TD COLSPAN=3 BACKGROUND="'||c_image_url||'line_hc.gif" ALIGN="CENTER">');
--	htp.p('				<IMG SRC="'||c_image_url||'empty.gif" WIDTH=100 HEIGHT=1></TD>');
--	htp.p('    </TR>');
    -- Modified by Patrick Low
    -- Mulitple internal parameters are passed in p_attrib, delimited by ","
    -- The first value is used for context switching
	IF SUBSTR(p_attrib, 1, INSTR(p_attrib, ',') - 1) = '1'
	THEN
--		htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
-- show the time the screen was last refreshed using the local PC's clock and not the database clock
--		htp.p('  <TR BGCOLOR="#C9C9C9"><TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">
--					<SCRIPT TYPE="text/javascript">
--					<!--
--					var time = new Date();
--					var str = new String(time.toString());
--					str = str.substr(0,str.length-4);
--					document.write( "Refreshed@" + str);
--					// --></SCRIPT></FONT></TD></TR></TABLE>');
		htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="0">');                  
		htp.p('		<TR BGCOLOR="#C9C9C9">');
		htp.p('			<TD><FONT COLOR="BLACK" SIZE="2"> myList</FONT></TD><TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">Age</FONT></TD>
						<TD><FONT COLOR="BLACK" SIZE="2">Organization</FONT></TD><TD><FONT COLOR="BLACK" SIZE="2">Order</FONT></TD>');
		htp.p('		</TR>');
		htp.p('		<TR BGCOLOR="#C9C9C9">');
		htp.p('			<TD ALIGN="CENTER" VALIGN="CENTER"><INPUT TYPE="CHECKBOX" NAME="myList" VALUE="1"></TD>');
--		htp.p('			<TD ALIGN="LEFT" VALIGN="CENTER"><IMG SRC="'||c_image_url||'b_outchecked.gif" ALT="Show my outchecked documents"></TD>');
	 	htp.p( '        <TD ALIGN="CENTER"><FONT size=2>');
	 	htp.formSelectOpen(cname=>'p_age',nsize=>'1');	
	 	-- Modified by PL: 27/10/2000
	 	-- Ticket 940275 requests default to be All
	 	htp.formSelectOption('All','SELECTED', cattributes=>'VALUE="0"' );
	 	htp.formSelectOption('Today',cattributes=>'VALUE="1"' );
	 	htp.formSelectOption('2-7 Days',cattributes=>'VALUE="7"' );
	 	htp.formSelectOption('8+ Days',cattributes=>'VALUE="8"' );
	 	htp.formSelectClose;
	 	htp.p('</FONT></TD>');
--	 	htp.formHidden( p_attrib);  -- use for debug only
	   	gis_search.CountryInput('1',(substr(p_attrib,3,(instr(p_attrib,',',4)-3))), -- the user id
	   								(substr(p_attrib,(instr(p_attrib,',',1,2))+1,length(p_attrib) - (instr(p_attrib,',',1,2)+1))));
	   							--	length(p_attrib) - (instr(p_attrib,',',1,2)));-- the context
	 	htp.p( '        <TD ALIGN="CENTER"><FONT size=2>');
	 	htp.formSelectOpen(cname=>'p_order',nsize=>'1');	
	 	htp.formSelectOption('Age Asc','SELECTED',cattributes=>'VALUE="1"' );  
	 	htp.formSelectOption('Age Desc',cattributes=>'VALUE="2"' );
	 	htp.formSelectOption('Doc Type',cattributes=>'VALUE="3"' );
	 	htp.formSelectOption('Descr',cattributes=>'VALUE="4"' );
	 	htp.formSelectClose;
	   	htp.p( '  		</FONT></TD>' );	   	
		htp.p('		</TR>');
		htp.p('  </TABLE>');
	ELSIF SUBSTR(p_attrib, 1, INSTR(p_attrib, ',') - 1) = '2' THEN
	    -- Added by Patrick Low for default category to show fields for
	    -- Must move this to seperate procedure
		htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');                  
		htp.p('		<TR BGCOLOR="#C9C9C9">');
		htp.p('         <TD ALIGN="RIGHT"><FONT COLOR="BLACK" SIZE=2>Default Category</FONT></TD>');
	 	htp.p('         <TD ALIGN="LEFT"><FONT SIZE=2>');
        htp.formSelectOpen(cname=>'DOCCAT_LOV',nsize=>'1');	
        IF NOT cur_docContext%ISOPEN THEN
          OPEN cur_docContext;
        END IF;
        FETCH cur_docContext INTO row_docContext;
        IF cur_docContext%NOTFOUND THEN
          htp.formSelectOption('ERROR','SELECTED',cattributes=>'VALUE="0"' );
        -- put some sort of error message in here
        ELSE
          WHILE cur_docContext%FOUND LOOP
            IF row_docContext.descriptive_flex_context_code = SUBSTR(p_attrib, INSTR(p_attrib, ',') + 1) THEN
              -- Default selected
              htp.formSelectOption(row_docContext.descriptive_flex_context_code,
                                   CSELECTED => 'SELECTED',
                                   CATTRIBUTES=>'value="' || row_docContext.descriptive_flex_context_code || '"');
            ELSE
              -- Not selected
              htp.formSelectOption(row_docContext.descriptive_flex_context_code,
                                   CATTRIBUTES=>'value="' || row_docContext.descriptive_flex_context_code || '"');
            END IF;
            FETCH cur_docContext INTO row_docContext;
          END LOOP;
        END IF;
        CLOSE cur_docContext;
        htp.formSelectClose;
	 	htp.p('         </FONT></TD>');
		htp.p('     </TR>');
		htp.p('  </TABLE>');
	END IF;                                           
END InfoHeader;             

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------	
PROCEDURE  Error_message(p_message  VARCHAR2 DEFAULT NULL) IS
BEGIN
-- This procedure displays an error screen on the web browser
-- and displays user defined error message to the screen.
  pageopen(p_heading => 'Error Report'); 
  infoHeader('Error Report');
  htp.p('<FONT SIZE="+2">Sorry...</FONT>');
  htp.line ;
  htp.br;
  htp.paragraph;
  htp.paragraph;
  htp.print('<CENTER>'||p_message||'</CENTER>');
  htp.br;
  htp.print('<CENTER><EM> Please go back and try again. </EM></CENTER>');
  htp.paragraph;
  htp.paragraph;
  pageclose;
END error_message;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE pageclose IS
BEGIN
  htp.bodyclose;
  htp.htmlclose;
END pageclose;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE pageheader(p_heading IN VARCHAR2,
					 p_procedure IN VARCHAR2 DEFAULT NULL,
                     p_refresh IN VARCHAR2 DEFAULT NULL,
                     p_refresh_url IN VARCHAR2 DEFAULT NULL) IS
    cResol   owa_cookie.cookie;
    vResol   VARCHAR2(50) := NULL;
BEGIN
    -- Modified by Patrick Low: 06/03/2001
    -- Get cookie with resolution information
    BEGIN
      cResol := owa_cookie.get('gis_resolution_height');
      -- Set specified resolution
      vResol := cResol.vals(1);
    EXCEPTION
      WHEN OTHERS THEN
        -- Default to lowest resolution if not set - should not get here !!!
        vResol := '768';
    END;
    
	htp.headopen;
	htp.meta(CHTTP_EQUIV =>'Content-Type'
		 , CNAME => NULL
	      , CCONTENT => 'text/html; charset=iso-8859-1');
	htp.meta(CHTTP_EQUIV => 'Author'
	      , CNAME =>'David Gough, Patrick Low, Fernando Gonzalez'
	      , CCONTENT => 'Global Imaging - Procedure '||p_procedure);
	htp.meta(CHTTP_EQUIV =>'Created'
	     , CNAME => NULL
		,CCONTENT => TO_CHAR(SYSDATE, 'DD-MON-YYYY HH:MI'));
    -- Added by Patrick Low: 04/10/2000
    htp.meta(CHTTP_EQUIV =>'no-cache'
	     , CNAME => NULL
		,CCONTENT => NULL);
    -- Modified by Patrick Low: 06/03/2001
	htp.meta(CHTTP_EQUIV =>'Client Height Resolution'
	     , CNAME => NULL
		,CCONTENT => vResol);
	IF p_refresh IS NOT NULL AND p_refresh_url IS NOT NULL then
	 htp.p('<META HTTP-EQUIV="Refresh"CONTENT="'||p_refresh||';URL='||p_refresh_url||'">');
	END IF;
	htp.title(p_heading);
--	htp.p('		<LINK 	rel= "stylesheet"');
--	htp.p('		type="text/css"');	
--	htp.p('		href="'||c_html_url||'core_styles.css">');

    -- Modified by Patrick Low: 06/03/2001
    -- Assign stylesheet based on resolution height
    -- Stylesheets moved from html directory to stylesheet directory
    IF vResol = '864' THEN
      -- 1152 X 768
      htp.p('       <LINK rel="stylesheet" type="text/css" href="'||c_ss_url||'864_styles.css">');
    ELSIF vResol IN ('1024', '1200') THEN
      -- 1280 X 1024, 1600 X 1200
      htp.p('       <LINK rel="stylesheet" type="text/css" href="'||c_ss_url||'1024_styles.css">');
    ELSE
      -- 640 X 480, 800 X 600, 1024 X 768
      htp.p('       <LINK rel="stylesheet" type="text/css" href="'||c_ss_url||'core_styles.css">');
    END IF;

	htp.p('		<SCRIPT LANGUAGE = "javaScript" src="'||c_jscript_url||'core_functions.js"></SCRIPT>');
	htp.headclose;
END pageheader;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE pageopen(p_heading IN VARCHAR2,
				   p_procedure IN VARCHAR2 DEFAULT NULL, p_attrib VARCHAR2 DEFAULT NULL) IS
BEGIN
  htp.htmlopen;
  pageheader(p_heading => p_heading, p_procedure => p_procedure);
  htp.bodyopen( CATTRIBUTES => c_background_color||' '||c_text_color||' '||c_link_colors ||' '||p_attrib );
END pageopen;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE dummypage IS
BEGIN
  pageopen(p_heading => 'Dummy Development Page',p_procedure =>'dummypage');
  htp.p('Test Page');
  pageclose;
END dummypage;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
FUNCTION test 
RETURN VARCHAR2 IS

l_str VARCHAR2(15) := 'Function test';
BEGIN
	RETURN l_str;
END test; 

PROCEDURE show_calendar IS
BEGIN
  htp.p('<SCRIPT language="JavaScript">
<!--BEGIN Script

function setDate() {
    this.dateField   = opener.dateField;
    this.inDate      = dateField.value;

    // SET DAY MONTH AND YEAR TO TODAYS DATE
    var now   = new Date();
    var day   = now.getDate();
    var month = now.getMonth();
    // This is a Y2K feature ONLY for Netscape
    var year  = now.getFullYear();
    if (year < 100) {
        year += 1900;
    }
    // IF A DATE WAS PASSED IN THEN PARSE THAT DATE
    if (inDate.indexOf("-")) {
        var inDay   = inDate.substring(0,inDate.indexOf("-"));
            if (inDay.substring(0,1) == "0" && inDay.length > 1)
                inDay = inDay.substring(1,inDay.length);
            inDay = parseInt(inDay);
        var inMonth = inDate.substring(inDate.indexOf("-") + 1, inDate.lastIndexOf("-"));
            if (inMonth.substring(0,1) == "0" && inMonth.length > 1)
                inMonth = inMonth.substring(1,inMonth.length);
        var inYear  = parseInt(inDate.substring(inDate.lastIndexOf("-") + 1, inDate.length));
        if (inDay) {
            day = inDay;
        }
        if (inMonth) {
          switch (inMonth)
          {
            case "JAN" :
              month = 1;
              break
            case "FEB" :
              month = 2;
              break
            case "MAR" :
              month = 3;
              break
            case "APR" :
              month = 4;
              break
            case "MAY" :
              month = 5;
              break
            case "JUN" :
              month = 6;
              break
            case "JUL" :
              month = 7;
              break
            case "AUG" :
              month = 8;
              break
            case "SEP" :
              month = 9;
              break
            case "OCT" :
              month = 10;
              break
            case "NOV" :
              month = 11;
              break
            case "DEC" :
              month = 12;
              break
          }
          month = month-1;
        }
        if (inYear) {
            year = inYear;
        }
    }
    this.focusDay                           = day;
    document.calControl.month.selectedIndex = month;
    document.calControl.year.value          = year;
    displayCalendar(day, month, year);
}

function setToday() {
    // SET DAY MONTH AND YEAR TO TODAYS DATE
    var now   = new Date();
    var day   = now.getDate();
    var month = now.getMonth();
    // This is a Y2K feature ONLY for Netscape
    var year  = now.getFullYear();
    if (year < 100) {
        year += 1900;
    }
    this.focusDay                           = day;
    document.calControl.month.selectedIndex = month;
    document.calControl.year.value          = year;
    displayCalendar(day, month, year);
}

function isFourDigitYear(year) {
    if (year.length != 4) {
        alert ("Sorry, the year must be four-digits in length.");
        document.calControl.year.select();
        document.calControl.year.focus();
    }
    else {
        return true;
    }
}

function selectDate() {
    var year  = document.calControl.year.value;
    if (isFourDigitYear(year)) {
        var day   = 0;
        var month = document.calControl.month.selectedIndex;
        displayCalendar(day, month, year);
    }
}

function setPreviousYear() {
    var year  = document.calControl.year.value;
    if (isFourDigitYear(year)) {
        var day   = 0;
        var month = document.calControl.month.selectedIndex;
        year--;
        document.calControl.year.value = year;
        displayCalendar(day, month, year);
    }
}

function setPreviousMonth() {
    var year  = document.calControl.year.value;
    if (isFourDigitYear(year)) {
        var day   = 0;
        var month = document.calControl.month.selectedIndex;
        if (month == 0) {
            month = 11;
            if (year > 1000) {
                year--;
                document.calControl.year.value = year;
            }
        }
        else {
            month--;
        }
        document.calControl.month.selectedIndex = month;
        displayCalendar(day, month, year);
    }
}

function setNextMonth() {
    var year  = document.calControl.year.value;
    if (isFourDigitYear(year)) {
        var day   = 0;
        var month = document.calControl.month.selectedIndex;
        if (month == 11) {
            month = 0;
            year++;
            document.calControl.year.value = year;
        }
        else {
            month++;
        }
        document.calControl.month.selectedIndex = month;
        displayCalendar(day, month, year);
    }
}

function setNextYear() {
    var year  = document.calControl.year.value;
    if (isFourDigitYear(year)) {
        var day   = 0;
        var month = document.calControl.month.selectedIndex;
        year++;
        document.calControl.year.value = year;
        displayCalendar(day, month, year);
    }
}

function displayCalendar(day, month, year) {       

    day     = parseInt(day);
    month   = parseInt(month);
    year    = parseInt(year);
    var i   = 0;
    var now = new Date();

    if (day == 0) {
        var nowDay = now.getDate();
    }
    else {
        var nowDay = day;
    }
    var days         = getDaysInMonth(month+1,year);
    var firstOfMonth = new Date (year, month, 1);
    var startingPos  = firstOfMonth.getDay();
    days += startingPos;

    // MAKE BEGINNING NON-DATE BUTTONS BLANK
    for (i = 0; i < startingPos; i++) {
        document.calButtons.elements[i].value = "     ";
    }

    // SET VALUES FOR DAYS OF THE MONTH
    for (i = startingPos; i < days; i++)  
    {
        if (i-startingPos+1 < 10)
        {
            document.calButtons.elements[i].value = "  " + i-startingPos+1 + "  ";
        }
        else
        {
            document.calButtons.elements[i].value = i-startingPos+1;
        }
        document.calButtons.elements[i].onClick = "returnDate"
    }

    // MAKE REMAINING NON-DATE BUTTONS BLANK
    for (i=days; i<42; i++)  {
        document.calButtons.elements[i].value = "     ";
    }

    // GIVE FOCUS TO CORRECT DAY
    document.calButtons.elements[focusDay+startingPos-1].focus();
}

// GET NUMBER OF DAYS IN MONTH
function getDaysInMonth(month,year)  {
    var days;
    if (month==1 || month==3 || month==5 || month==7 || month==8 ||
        month==10 || month==12)  days=31;
    else if (month==4 || month==6 || month==9 || month==11) days=30;
    else if (month==2)  {
        if (isLeapYear(year)) {
            days=29;
        }
        else {
            days=28;
        }
    }
    return (days);
}

// CHECK TO SEE IF YEAR IS A LEAP YEAR
function isLeapYear (Year) {
    if (((Year % 4)==0) && ((Year % 100)!=0) || ((Year % 400)==0)) {
        return (true);
    }
    else {
        return (false);
    }
}

// SET FORM FIELD VALUE TO THE DATE SELECTED
function returnDate(inDay)
{
    var day   = inDay;
    var month = (document.calControl.month.selectedIndex)+1;
    var year  = document.calControl.year.value;
    var newMonth = document.calControl.month[document.calControl.month.selectedIndex].value
    if ((""+month).length == 1)
    {
        month="0"+month;
    }
    if ((""+day).length == 1)
    {
        day="0"+day;
    }
    if (day != "   ") {
        dateField.value = day + "-" + newMonth + "-" + year;
        window.close()
    }
}
// -->
</SCRIPT>');
  gis_image_util.pageopen(p_heading => 'GIS Calendar', p_attrib => 'onLoad="setDate()" onBlur="window.focus()"');
  gis_image_util.pageopen(p_heading => 'GIS Calendar');
  gis_image_util.InfoHeader('GIS Calendar');
  htp.p('<FORM NAME="calControl" onSubmit="return false;">
<TABLE CELLPADDING=0 CELLSPACING=0 BORDER=0>
<TR><TD COLSPAN=7>
<CENTER>
<SELECT NAME="month" onChange="selectDate()">
   <OPTION value="JAN">January
   <OPTION value="FEB">February
   <OPTION value="MAR">March
   <OPTION value="APR">April
   <OPTION value="MAY">May
   <OPTION value="JUN">June
   <OPTION value="JUL">July
   <OPTION value="AUG">August
   <OPTION value="SEP">September
   <OPTION value="OCT">October
   <OPTION value="NOV">November
   <OPTION value="DEC">December
</SELECT>
<INPUT NAME="year" TYPE=TEXT SIZE=4 MAXLENGTH=4 onChange="selectDate()">
</CENTER>
</TD>
</TR>

<TR>
<TD COLSPAN=7>
<CENTER><INPUT 
TYPE=BUTTON NAME="previousYear" VALUE="<<"    onClick="setPreviousYear()"><INPUT 
TYPE=BUTTON NAME="previousYear" VALUE=" < "   onClick="setPreviousMonth()"><INPUT 
TYPE=BUTTON NAME="previousYear" VALUE="Today" onClick="setToday()"><INPUT 
TYPE=BUTTON NAME="previousYear" VALUE=" > "   onClick="setNextMonth()"><INPUT 
TYPE=BUTTON NAME="previousYear" VALUE=">>"    onClick="setNextYear()">
</CENTER>
</TD>
</TR>
</FORM>

<FORM NAME="calButtons">

<TR HEIGHT=10><TD></TD></TR>

<TR><TD><CENTER><FONT SIZE=-1 FACE="Arial,Helv,Helvetica"><B>Su</B></FONT></CENTER></TD>
    <TD><CENTER><FONT SIZE=-1 FACE="Arial,Helv,Helvetica"><B>Mo</B></FONT></CENTER></TD>
    <TD><CENTER><FONT SIZE=-1 FACE="Arial,Helv,Helvetica"><B>Tu</B></FONT></CENTER></TD>
    <TD><CENTER><FONT SIZE=-1 FACE="Arial,Helv,Helvetica"><B>We</B></FONT></CENTER></TD>
    <TD><CENTER><FONT SIZE=-1 FACE="Arial,Helv,Helvetica"><B>Th</B></FONT></CENTER></TD>
    <TD><CENTER><FONT SIZE=-1 FACE="Arial,Helv,Helvetica"><B>Fr</B></FONT></CENTER></TD>
    <TD><CENTER><FONT SIZE=-1 FACE="Arial,Helv,Helvetica"><B>Sa</B></FONT></CENTER></TD></TR>

<TR><TD><INPUT TYPE="button" NAME="but0"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but1"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but2"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but3"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but4"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but5"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but6"  value="     " onClick="returnDate(this.value)"></TD></TR>

<TR><TD><INPUT TYPE="button" NAME="but7"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but8"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but9"  value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but10" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but11" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but12" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but13" value="     " onClick="returnDate(this.value)"></TD></TR>

<TR><TD><INPUT TYPE="button" NAME="but14" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but15" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but16" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but17" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but18" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but19" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but20" value="     " onClick="returnDate(this.value)"></TD></TR>

<TR><TD><INPUT TYPE="button" NAME="but21" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but22" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but23" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but24" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but25" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but26" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but27" value="     " onClick="returnDate(this.value)"></TD></TR>

<TR><TD><INPUT TYPE="button" NAME="but28" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but29" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but30" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but31" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but32" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but33" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but34" value="     " onClick="returnDate(this.value)"></TD></TR>

<TR><TD><INPUT TYPE="button" NAME="but35" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but36" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but37" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but38" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but39" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but40" value="     " onClick="returnDate(this.value)"></TD>
    <TD><INPUT TYPE="button" NAME="but41" value="     " onClick="returnDate(this.value)"></TD></TR>

</TABLE>
</FORM>');
  gis_image_util.pageclose;
END show_calendar;

FUNCTION validIP(vIP VARCHAR2) RETURN BOOLEAN IS
  vCheck   gis_scanners.ip_address%TYPE;
  nLoop    NUMBER := 0;
  nPeriods NUMBER := 0;
  nNumbers NUMBER := 0;
  FUNCTION isNumber(vNum VARCHAR2) RETURN BOOLEAN IS
    nDummy NUMBER := 0;
  BEGIN
    IF vNum IS NULL THEN
      RETURN FALSE;
    ELSE
      nDummy := TO_NUMBER(vNum);
      RETURN TRUE;
    END IF;
  EXCEPTION
    WHEN OTHERS THEN
      RETURN FALSE;
  END;
BEGIN
  -- Parse string to see if it is a valid IP address
  -- Assume it must have 4 numbers, seperated by 3 periods
  IF INSTR(vIP, '.') = 0THEN
    -- Does not have any periods
    RETURN FALSE;
  ELSE
    -- Append period to use to terminate loop for last number
    vCheck := vIP || '.';
    LOOP
      -- Strip number
      IF NOT isNumber(SUBSTR(vCheck, 1, INSTR(vCheck, '.') - 1)) THEN
        RETURN FALSE;
        EXIT;
      ELSE
        nNumbers := nNumbers + 1;
        vCheck := SUBSTR(vCheck, INSTR(vCheck, '.'));
      END IF;
      -- Check for period
      IF SUBSTR(vCheck, 1, 1) = '.' THEN
        nPeriods := nPeriods + 1;
        vCheck := SUBSTR(vCheck, 2);
      END IF;
      EXIT WHEN INSTR(vCheck, '.') IS NULL;
    END LOOP;
    IF nNumbers = 4 AND
       -- Include the one we appended
       nPeriods = 4 AND
       vCheck IS NULL THEN
      RETURN TRUE;
    ELSE
      RETURN FALSE;
    END IF;

  END IF;
END validIP;

FUNCTION delete_image(p_user_id             NUMBER,
                      p_file_id             NUMBER,
                      p_document_id         NUMBER DEFAULT NULL,
                      p_primary_document_id VARCHAR2,
                      p_operation           VARCHAR2 DEFAULT 'D') RETURN BOOLEAN IS
  nOrgID      NUMBER := NULL;
  nStatusID   NUMBER := NULL;
  CURSOR cStatus IS
    SELECT rowid
    FROM   gis_doc_status
    WHERE  document_id = p_document_id
    AND    doc_status_type_id = nStatusID;
  rStatus        cStatus%ROWTYPE;
  nDocID      fnd_documents.document_id%TYPE;
  CURSOR cDocs IS
    SELECT t.document_id
    FROM   fnd_documents_tl t, fnd_documents d, fnd_document_datatypes dt
    WHERE  t.media_id = p_file_id
    AND    t.document_id = d.document_id
    AND    d.datatype_id = dt.datatype_id
    AND    dt.name = 'FILE'
    AND    NVL(dt.start_date_active, SYSDATE) <= SYSDATE
    AND    NVL(dt.end_date_active, SYSDATE) >= SYSDATE;
BEGIN
  IF p_operation = 'D' THEN
    -- Audit deletion
    -- Select statement will select all records for a primary deletion, ie. include secondary records
    -- Outer join is for new records that are NOT indexed/attached
    INSERT INTO gis_deletion_log
      (file_id,
       creation_date,
       created_by,
       last_update_date,
       last_updated_by,
       last_update_login,
       file_name,
       upload_date,
       program_name,
       program_tag,
       document_id,
       category_id,
       primary_document_id,
       doc_attribute_category,
       description,
       entity_name,
       pk1_value)
    SELECT l.file_id,
           SYSDATE,
           p_user_id,
           SYSDATE,
           p_user_id,
           NULL,
           l.file_name,
           l.upload_date,
           l.program_name,
           l.program_tag,
           d.document_id,
           d.category_id,
           NVL(v.primary_document_id, 'N') primary_document_id,
           t.doc_attribute_category,
           NVL(t.description, 'IMAGE NOT INDEXED'),
           a.entity_name,
           a.pk1_value
    FROM   fnd_lobs l, fnd_documents_tl t, fnd_documents_tl_dfv v, fnd_documents d, fnd_attached_documents a
    WHERE  l.file_id = t.media_id
    AND    t.rowid = v.rowid
    AND    t.document_id = d.document_id
    AND    d.document_id = a.document_id(+)
    AND    l.file_id = p_file_id
    AND    d.document_id = DECODE(NVL(p_primary_document_id, 'N'), 'Y', d.document_id, p_document_id);
  END IF;
  IF p_operation = 'D' THEN
    IF p_primary_document_id = 'Y' THEN
      -- Delete doc status record for primary and all secondary attachments
      DELETE
      FROM   gis_doc_status 
      WHERE  document_id IN
        (SELECT t.document_id
         FROM   fnd_documents_tl t, fnd_documents d
         WHERE  t.media_id = p_file_id
         AND    t.document_id = d.document_id
         AND    d.datatype_id = 
          (SELECT datatype_id
           FROM   fnd_document_datatypes
           WHERE  name = 'FILE'
           AND    NVL(start_date_active, SYSDATE) <= SYSDATE
           AND    NVL(end_date_active, SYSDATE) >= SYSDATE));
    ELSE
      -- Delete doc status record for secondary attachment
      DELETE
      FROM   gis_doc_status 
      WHERE  document_id = p_document_id;
    END IF;
  ELSIF p_operation = 'R' AND
        p_primary_document_id = 'Y' THEN
    -- For RESET, delete doc status record except for SCANNED for primary attachment
    DELETE
    FROM   gis_doc_status 
    WHERE  document_id = p_document_id
    AND    doc_status_type_id !=
      (SELECT doc_status_type_id
       FROM   gis_doc_status_types
       WHERE  doc_status_name = 'SCANNED');
  END IF;
  -- Delete short text if source is from GIS and GIS_MIGRATE
  -- fnd_documents_short_text.media_id has its own sequence and it NOT the same as fnd_documents.media_id
  IF p_operation = 'D' THEN
    IF p_primary_document_id = 'Y' THEN
      -- Delete all comments via media_id for primary and all secondary attachments
      DELETE
      FROM   fnd_documents_short_text
      WHERE  app_source_version IN ('GIS', 'GIS_MIGRATE')
      AND    media_id IN
        (SELECT TO_NUMBER(v.comments_id)
         FROM   fnd_documents_tl t, fnd_documents d, fnd_documents_tl_dfv v
         WHERE  t.media_id = p_file_id
         AND    v.comments_id IS NOT NULL
         AND    t.document_id = d.document_id
         AND    t.rowid = v.rowid
         AND    d.datatype_id = 
          (SELECT datatype_id
           FROM   fnd_document_datatypes
           WHERE  name = 'FILE'
           AND    NVL(start_date_active, SYSDATE) <= SYSDATE
           AND    NVL(end_date_active, SYSDATE) >= SYSDATE));
    ELSE
      -- Delete comments for secondary attachment
      DELETE
      FROM   fnd_documents_short_text
      WHERE  app_source_version IN ('GIS', 'GIS_MIGRATE')
      AND    media_id IN
        (SELECT TO_NUMBER(v.comments_id)
         FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
         WHERE  t.document_id = p_document_id
         AND    t.rowid = v.rowid
         AND    v.comments_id IS NOT NULL);
    END IF;
  ELSIF p_operation = 'R' AND
        p_primary_document_id = 'Y' THEN
    -- For RESET, delete all comments via media_id for primary attachment
      DELETE
      FROM   fnd_documents_short_text
      WHERE  app_source_version IN ('GIS', 'GIS_MIGRATE')
      AND    media_id IN
        (SELECT TO_NUMBER(v.comments_id)
         FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
         WHERE  t.document_id = p_document_id
         AND    t.rowid = v.rowid
         AND    v.comments_id IS NOT NULL);
  END IF;
  IF p_operation = 'D' AND
     p_primary_document_id = 'Y' THEN
    -- Delete image if source is from GIS and GIS_MIGRATE
    DELETE
    FROM   fnd_lobs
    WHERE  file_id = p_file_id
    AND    program_name IN ('GIS', 'GIS_MIGRATE');
  END IF;
  IF p_operation = 'D' THEN
    IF p_primary_document_id = 'Y' THEN
      -- Delete attached document records for primary and all secondary attachments    
      DELETE
      FROM   fnd_attached_documents
      WHERE  document_id IN
        (SELECT t.document_id
         FROM   fnd_documents_tl t, fnd_documents d, fnd_documents_tl_dfv v
         WHERE  t.media_id = p_file_id
         AND    t.document_id = d.document_id
         AND    t.rowid = v.rowid
         AND    d.datatype_id = 
          (SELECT datatype_id
           FROM   fnd_document_datatypes
           WHERE  name = 'FILE'
           AND    NVL(start_date_active, SYSDATE) <= SYSDATE
           AND    NVL(end_date_active, SYSDATE) >= SYSDATE));
    ELSE
      -- Delete attached document record for secondary attachment
      DELETE
      FROM   fnd_attached_documents
      WHERE  document_id = p_document_id;
    END IF;
  ELSIF p_operation = 'R' AND
        p_primary_document_id = 'Y' THEN
    -- For RESET, delete attached document records for primary attachment
      DELETE
      FROM   fnd_attached_documents
      WHERE  document_id = p_document_id;
  END IF;
  IF p_operation = 'D' THEN
    IF p_primary_document_id = 'Y' THEN
      -- Find ALL document and translation records for primary and all secondary attachments
      OPEN cDocs;
      LOOP
        FETCH cDocs INTO nDocID;
        EXIT WHEN cDocs%NOTFOUND;
        -- Delete document record
        DELETE
        FROM   fnd_documents
        WHERE  document_id = nDocID;
        -- Delete document translation record
        DELETE
        FROM   fnd_documents_tl
        WHERE  document_id = nDocID;
      END LOOP;
      CLOSE cDocs;
    ELSE
      -- Delete document detail record for secondary attachment
      DELETE
      FROM   fnd_documents
      WHERE  document_id = p_document_id;
      -- Delete document translation record for secondary attachment
      DELETE
      FROM   fnd_documents_tl
      WHERE  document_id = p_document_id;
    END IF;
  ELSIF p_operation = 'R' THEN
    -- Get org_id for scanner of document
    SELECT organization_id
    INTO   nOrgID
    FROM   fnd_documents_tl t, fnd_lobs l, gis_scanners s
    WHERE  t.document_id = p_document_id
    AND    t.media_id = l.file_id
    AND    l.program_tag = s.scanner_id;
    -- Reset document detail record
    UPDATE fnd_documents
    SET    category_id = 1,
           security_type = 1,
           security_id = nOrgID,
           publish_flag = 'N',
           usage_type = 'S'
    WHERE  document_id = p_document_id;
    -- Reset translation record
    UPDATE fnd_documents_tl
    SET    doc_attribute_category = NULL,
           doc_attribute1 = NULL,
           doc_attribute2 = NULL,
           doc_attribute3 = NULL,
           doc_attribute4 = NULL,
           doc_attribute5 = NULL,
           doc_attribute6 = 'REPROCESS',
           doc_attribute7 = NULL,
           doc_attribute8 = NULL,
           doc_attribute9 = NULL,
           doc_attribute10 = NULL,
           doc_attribute11 = NULL,
           doc_attribute12 = NULL,
           doc_attribute13 = 'Y', -- Must be primary, as only primary attachment can be reset for re-indexing
           doc_attribute14 = NULL,
           doc_attribute15 = NULL,
           short_text = NULL,
           description = NULL
    WHERE  document_id = p_document_id;
    -- Check if audit record exists for REPROCESS state
    SELECT doc_status_type_id
    INTO   nStatusID
    FROM   gis_doc_status_types
    WHERE  doc_status_name = 'REPROCESS';
   
    OPEN cStatus;
    FETCH cStatus INTO rStatus;
    IF cStatus%NOTFOUND THEN
      -- Log audit record for REPROCESS
      INSERT INTO gis_doc_status
        (document_id,
         doc_status_type_id,
         date_created,
         created_by,
         last_update_date,
         last_updated_by)
      VALUES
        (p_document_id,
         nStatusID,
         SYSDATE,
         p_user_id,
         SYSDATE,
         p_user_id);
    ELSE
      UPDATE gis_doc_status
        SET  last_update_date = SYSDATE,
             last_updated_by = p_user_id
        WHERE rowid = rStatus.rowid;
    END IF;
    CLOSE cStatus;
  END IF;    

  COMMIT;

  RETURN TRUE;
  
EXCEPTION WHEN OTHERS THEN
  htp.p('Error deleting/reseting image: ' || SQLERRM);
  ROLLBACK;
  RETURN FALSE;
END delete_image;

PROCEDURE recon_index_info(errbuf OUT VARCHAR2, retcode OUT VARCHAR2) IS
  CURSOR cRecon IS
    SELECT s.organization_id, t.document_id, t.doc_attribute_category lob
    FROM   fnd_lobs l, gis_scanners s, fnd_documents_tl t
    WHERE  l.program_name = 'GIS'
    AND    l.program_tag = s.scanner_id
    AND    l.file_id = t.media_id
and  t.document_id in (432750, 768896)
    AND    t.doc_attribute_category IN ('Agreements','Contracts','Customer',
                                        'Education Bookings','Order Management','Payables',
                                        'Projects','Receivables','Suppliers');
  rRecon cRecon%ROWTYPE;
  nFix   NUMBER := 0;
  -- Web Expenses - not required as key value is expense number only
  -- HR Assignments - will not be done - change in (maiden) name should be reflected as historical
  -- Education events - will not be done - title of courses should not change - the course description can
  -- Projects - a non-existing primary paying customer can be selected - if this changes after the project is updated
  --            to the correct primary paying customer, then the first statement will find the latest update.
  --            If there is no update (eg. historical projects) then the customer number as per preindexing is
  --            reconciled for the project.
  nDummy NUMBER := 0;
  CURSOR cPROJ IS
    SELECT 1, c.customer_name, c.customer_number
    FROM   ra_customers c, pa_projects_all p, pa_project_customers pc
    WHERE  c.customer_id = pc.customer_id
    AND    pc.project_id = p.project_id
    AND    pc.project_relationship_code = 'Primary'
    AND    p.segment1 = 
      (SELECT v.project_number
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid)
    AND    org_id = rRecon.organization_id
    UNION
    SELECT 2, c.customer_name, c.customer_number
    FROM   ra_customers c, pa_projects_all p, pa_project_customers pc
    WHERE  c.customer_id = pc.customer_id
    AND    pc.project_id = p.project_id
    AND    (p.segment1, c.customer_number) =
      (SELECT v.project_number, v.customer_number
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid)
    AND    org_id = rRecon.organization_id
    ORDER BY 1;
  CURSOR cSA IS
    SELECT c.customer_name, c.customer_number
    FROM   ra_customers c, oe_agreements_tl t, oe_agreements_b b
    WHERE  c.customer_id = b.sold_to_org_id
    AND    c.customer_id != -1
    AND    b.agreement_id = t.agreement_id
    AND    t.name =
      (SELECT v.agreement_name
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid);
  CURSOR cOKS IS
    SELECT c.customer_name, c.customer_number
    FROM   okc_rules_b b, okc_k_headers_b h, ra_customers c
    WHERE  (h.contract_number, NVL(h.contract_number_modifier, '-1')) IN
      (SELECT v.contracts_number, NVL(v.contracts_modifier, '-1')
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid)
    AND    b.jtot_object1_code = 'OKX_CUSTACCT'
    AND    c.customer_id = b.object1_id1
    AND    b.dnz_chr_id = h.id
    AND    authoring_org_id = rRecon.organization_id;
  CURSOR cRC IS
    SELECT c.customer_name, c.customer_number
    FROM   ra_customers c
    WHERE  customer_number = 
      (SELECT v.customer_number
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid);
  CURSOR cOE IS
    SELECT c.customer_name, c.customer_number
    FROM   oe_order_headers_all a, ra_customers c
    WHERE  a.sold_to_org_id = c.customer_id
    AND    a.order_number = 
      (SELECT v.oe_number
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid)
    AND    a.org_id = rRecon.organization_id;
  CURSOR cAP IS
    SELECT v.vendor_name
    FROM   ap_invoices_all a, po_vendors v
    WHERE  a.vendor_id = v.vendor_id
    AND    a.invoice_num =
      (SELECT invoice_number
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid)
    AND    a.org_id = rRecon.organization_id;
  CURSOR cAR IS
    SELECT c.customer_name, c.customer_number
    FROM   ra_customers c, ra_customer_trx_all t
    WHERE  t.sold_to_customer_id = c.customer_id
    AND    t.trx_number =
      (SELECT v.invoice_number
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid)
    AND    t.org_id = rRecon.organization_id;
  CURSOR cPO IS
    SELECT p.vendor_name
    FROM   po_vendors p
    WHERE  p.segment1 =
      (SELECT v.supplier_number
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid);
  CURSOR cEB IS
    SELECT DECODE(o.delegate_person_id,
                  NULL, c.last_name || DECODE(c.first_name, NULL, NULL, ', ' || c.first_name),
                  UPPER(p.full_name)) delegate_name
    FROM   ota_delegate_bookings o, ra_contacts c, per_people_f p
    WHERE  o.contact_id = c.contact_id(+)
    AND    o.delegate_person_id = p.person_id(+)
    AND    NVL(p.effective_start_date, SYSDATE) <= SYSDATE
    AND    NVL(p.effective_end_date, SYSDATE) >= SYSDATE
    AND    o.booking_id =
      (SELECT TO_NUMBER(v.enrollment_number)
       FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
       WHERE  t.document_id = rRecon.document_id
       AND    t.rowid = v.rowid)
    AND    o.business_group_id = rRecon.organization_id;
  -- New variables
  vNCustName ra_customers.customer_name%TYPE;
  vNCustNum  ra_customers.customer_number%TYPE;
  vNSuppName po_vendors.vendor_name%TYPE;
  vNName     per_people_f.full_name%TYPE;
  -- Old variables
  vOCustName ra_customers.customer_name%TYPE;
  vOCustNum  ra_customers.customer_number%TYPE;
  vOSuppName po_vendors.vendor_name%TYPE;
  vOName     per_people_f.full_name%TYPE;
  
  PROCEDURE check_cust_fields IS
  BEGIN
    SELECT customer_name, customer_number
    INTO   vOCustName, vOCustNum
    FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
    WHERE  t.rowid = v.rowid
    AND    t.document_id = rRecon.document_id;
    IF vNCustName != NVL(vOCustName, '_NULL_') OR
       --  Contracts and Receivables do not have a customer number flex field !!!
       (vNCustNum != NVL(vOCustNum, '_NULL_') AND rRecon.lob NOT IN ('Contracts', 'Receivables')) THEN
      nFix := nFix + 1;
      IF rRecon.lob = 'Agreements' THEN
        UPDATE fnd_documents_tl
        SET    doc_attribute3 = vNCustName
        WHERE  document_id = rRecon.document_id;
      ELSIF rRecon.lob IN ('Contracts', 'Customer', 'Order Management', 'Receivables') THEN
        UPDATE fnd_documents_tl
        SET    doc_attribute1 = vNCustName
        WHERE  document_id = rRecon.document_id;
      ELSIF rRecon.lob = 'Projects' THEN
        -- Projects can be reassigned to a new primary paying customer
        UPDATE fnd_documents_tl
        SET    doc_attribute1 = vNCustName,
               doc_attribute2 = vNCustNum
        WHERE  document_id = rRecon.document_id;
      END IF;    
      -- Write what was updated
      fnd_file.new_line(fnd_file.output, 1);
      fnd_file.put_line(fnd_file.output, 'LOB             : ' || rRecon.lob);
      fnd_file.put_line(fnd_file.output, 'document_id     : ' || TO_CHAR(rRecon.document_id));
      IF rRecon.lob = 'Projects' THEN
        fnd_file.put_line(fnd_file.output, 'customer_number : ' || vOCustNum || ' => ' || vNCustNum);
      END IF;
      fnd_file.put_line(fnd_file.output, 'customer_name   : ' || vOCustName || ' => ' || vNCustName);
    END IF;
  END check_cust_fields;
  PROCEDURE check_vendor_fields IS
  BEGIN
    SELECT supplier_name
    INTO   vOSuppName
    FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
    WHERE  t.rowid = v.rowid
    AND    t.document_id = rRecon.document_id;
    IF vNSuppName != NVL(vOSuppName, '_NULL_') THEN
      nFix := nFix + 1;
      -- Payables + Suppliers has doc_attribute1 as supplier_name
      UPDATE fnd_documents_tl
      SET    doc_attribute1 = vNSuppName
      WHERE  document_id = rRecon.document_id;
      -- Write what was updated
      fnd_file.new_line(fnd_file.output, 1);
      fnd_file.put_line(fnd_file.output, 'LOB             : ' || rRecon.lob);
      fnd_file.put_line(fnd_file.output, 'document_id     : ' || TO_CHAR(rRecon.document_id));
      fnd_file.put_line(fnd_file.output, 'supplier_name   : ' || vOSuppName || ' => ' || vNSuppName);
    END IF;
  END check_vendor_fields;
  PROCEDURE check_delegate_fields IS
  BEGIN
    SELECT delegate_name
    INTO   vOName
    FROM   fnd_documents_tl t, fnd_documents_tl_dfv v
    WHERE  t.rowid = v.rowid
    AND    t.document_id = rRecon.document_id;
    IF vNName != NVL(vOName, '_NULL_') THEN
      nFix := nFix + 1;
      -- Education Bookings has doc_attribute3 as delegate_name
      UPDATE fnd_documents_tl
      SET    doc_attribute3 = vNName
      WHERE  document_id = rRecon.document_id;
      -- Write what was updated
      fnd_file.new_line(fnd_file.output, 1);
      fnd_file.put_line(fnd_file.output, 'LOB             : ' || rRecon.lob);
      fnd_file.put_line(fnd_file.output, 'document_id     : ' || TO_CHAR(rRecon.document_id));
      fnd_file.put_line(fnd_file.output, 'delegate_name   : ' || vOName || ' => ' || vNName);
    END IF;
  END check_delegate_fields;

BEGIN
  -- Log header
  fnd_file.put_line(fnd_file.log, 'Start reconciliation of Global Imaging System index information.');
  fnd_file.put_line(fnd_file.log, TO_CHAR(SYSDATE, 'DD-MON-YYYY HH24:MI:SS'));

  -- Output header
  fnd_file.put_line(fnd_file.output, 'Reconciliation Report Of Global Imaging System Index Information @ ' || TO_CHAR(SYSDATE, 'DD-MON-YYYY HH24:MI:SS'));
  fnd_file.put_line(fnd_file.output, '---------------------------------------------------------------------------------------');
  fnd_file.new_line(fnd_file.output, 1);

  OPEN cRecon;
  LOOP
    vNCustName := NULL;
    vNCustNum := NULL;
    vNSuppName := NULL;
    vNName := NULL;
    vOCustName := NULL;
    vOCustNum := NULL;
    vOSuppName := NULL;
    vOName := NULL;
    FETCH cRecon INTO rRecon;
    EXIT WHEN cRecon%NOTFOUND;
    IF rRecon.lob = 'Agreements' THEN
      OPEN cSA;
      FETCH cSA INTO vNCustName, vNCustNum;
      IF cSA%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Agreements for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_cust_fields;
      END IF;
      CLOSE cSA;
    ELSIF rRecon.lob = 'Projects' THEN
      OPEN cPROJ;
      FETCH cPROJ INTO nDummy, vNCustName, vNCustNum;
      IF cPROJ%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Projects for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_cust_fields;
      END IF;
      CLOSE cPROJ;
    ELSIF rRecon.lob = 'Contracts' THEN
      OPEN cOKS;
      FETCH cOKS INTO vNCustName, vNCustNum;
      IF cOKS%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Contract Services for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_cust_fields;
      END IF;
      CLOSE cOKS;
    ELSIF rRecon.lob = 'Customer' THEN
      OPEN cRC;
      FETCH cRC INTO vNCustName, vNCustNum;
      IF cRC%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Customer for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_cust_fields;
      END IF;
      CLOSE cRC;
    ELSIF rRecon.lob = 'Order Management' THEN
      OPEN cOE;
      FETCH cOE INTO vNCustName, vNCustNum;
      IF cOE%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Order for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_cust_fields;
      END IF;
      CLOSE cOE;
    ELSIF rRecon.lob = 'Receivables' THEN
      OPEN cAR;
      FETCH cAR INTO vNCustName, vNCustNum;
      IF cAR%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Receivables for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_cust_fields;
      END IF;
      CLOSE cAR;
    ELSIF rRecon.lob = 'Payables' THEN
      OPEN cAP;
      FETCH cAP INTO vNSuppName;
      IF cAP%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Payables for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_vendor_fields;
      END IF;
      CLOSE cAP;
    ELSIF rRecon.lob = 'Suppliers' THEN
      OPEN cPO;
      FETCH cPO INTO vNSuppName;
      IF cPO%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Purchasing Supplier for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_vendor_fields;
      END IF;
      CLOSE cPO;
    ELSIF rRecon.lob = 'Education Bookings' THEN
      OPEN cEB;
      FETCH cEB INTO vNName;
      IF cEB%NOTFOUND THEN
        fnd_file.new_line(fnd_file.log, 1);
        fnd_file.put_line(fnd_file.log, 'Error reconciling Education Booking Delegate for document_id = ' || TO_CHAR(rRecon.document_id));
      ELSE
        check_delegate_fields;
      END IF;
      CLOSE cEB;
    END IF;
  END LOOP;
  CLOSE cRecon;

  -- Output trailer
  fnd_file.new_line(fnd_file.output, 1);
  IF nFix = 0 THEN
    fnd_file.put_line(fnd_file.output, '0 records update - no index fields out of synch.');
  ELSE
    fnd_file.put_line(fnd_file.output, TO_CHAR(nFix) || ' record(s) updated.');
  END IF;

  -- Log trailer
  fnd_file.new_line(fnd_file.log, 1);
  fnd_file.put_line(fnd_file.log, 'Completed reconciliation of Global Imaging System index information.');
  fnd_file.put_line(fnd_file.log, TO_CHAR(SYSDATE, 'DD-MON-YYYY HH24:MI:SS'));

  retcode := '0';   -- (successful completion)
  errbuf  := '';
EXCEPTION WHEN OTHERS THEN
  retcode := '2';  -- (error)
  fnd_file.new_line(fnd_file.log, 1);
  fnd_file.put_line(fnd_file.log, 'Reconciliation of Global Imaging System index information error:');
  fnd_file.put_line(fnd_file.log, TO_CHAR(SYSDATE, 'DD-MON-YYYY HH24:MI:SS'));
  fnd_file.put_line(fnd_file.log, SQLERRM);
  fnd_message.retrieve(errbuf);
END recon_index_info;

END gis_image_util;
/
