CREATE OR REPLACE
PACKAGE BODY apps.gis_metrics_report IS

PROCEDURE show_fields(p_user_id      NUMBER,
                      p_context      VARCHAR2 DEFAULT NULL,
                      p_doc_type     VARCHAR2 DEFAULT NULL,
                      p_start_date   DATE     DEFAULT NULL,
                      p_end_date     DATE     DEFAULT NULL,
                      p_org_id       NUMBER   DEFAULT NULL) IS
  vCheck   VARCHAR2(240) := NULL;
  CURSOR cCheckUser IS
    SELECT resp.responsibility_key
    FROM   fnd_user usr,
           fnd_user_resp_groups usrep,
           fnd_responsibility resp
    WHERE  usr.user_id = p_user_id
    AND    usr.user_id = usrep.user_id
    AND    usrep.responsibility_id = resp.responsibility_id
    AND    usrep.responsibility_application_id = resp.application_id
    AND    NVL(usrep.end_date, SYSDATE + 1) > SYSDATE
    AND    NVL(usr.end_date, SYSDATE + 1) > SYSDATE
    AND    resp.responsibility_key = 'GIS_05_REPORTS';
  CURSOR cShowOrg IS    
  SELECT DISTINCT org.name, org.organization_id
  FROM   FND_DESCR_FLEX_CONTEXTS_VL con,
         fnd_user_resp_groups usrep,
         fnd_application_tl app,
         fnd_responsibility_tl resp,
         fnd_user usr,
         fnd_profile_option_values optval,
         fnd_profile_options opt,
         hr_operating_units org
  WHERE  usr.user_id = p_user_id
  AND    usr.user_id = usrep.user_id
  AND    nvl(usrep.end_date,sysdate+1) > sysdate
  AND    usrep.responsibility_application_id = app.application_id
  AND    usrep.responsibility_id = resp.responsibility_id
  AND    usrep.responsibility_application_id = resp.application_id
  AND    usr.user_id = usrep.user_id
  AND    con.descriptive_flexfield_name = 'ATCHMT_DOCUMENT_FLEX'
  AND    descriptive_flex_context_code != 'Global Data Elements'
  AND    app.application_name = con.descriptive_flex_context_name
  AND    usrep.responsibility_id = optval.level_value
  AND    optval.profile_option_id = opt.profile_option_id
  AND    optval.application_id =  opt.application_id
  AND    opt.profile_option_name = 'ORG_ID'
  AND    org.organization_id = TO_NUMBER(optval.profile_option_value)
  ORDER BY org.name;
  rShowOrg cShowOrg%ROWTYPE;
  CURSOR cDocContext IS
  SELECT DISTINCT con.descriptive_flex_context_code, con.description
  FROM   FND_DESCR_FLEX_CONTEXTS_VL con,
         fnd_user_resp_groups usrep,
         fnd_application_tl app,
         fnd_responsibility_tl resp,
         fnd_user usr,
         fnd_profile_option_values optval,
         fnd_profile_options opt
  WHERE  usr.user_id = p_user_id
  AND    usr.user_id = usrep.user_id
  AND    nvl(usrep.end_date,sysdate+1) > sysdate
  AND    usrep.responsibility_application_id = app.application_id
  AND    usrep.responsibility_id = resp.responsibility_id
  AND    usrep.responsibility_application_id = resp.application_id
  AND    usr.user_id = usrep.user_id
  AND    con.descriptive_flexfield_name = 'ATCHMT_DOCUMENT_FLEX'
  AND    descriptive_flex_context_code != 'Global Data Elements'
  AND    app.application_name = con.descriptive_flex_context_name
  AND    usrep.responsibility_id = optval.level_value
  AND    optval.profile_option_id = opt.profile_option_id
  AND    optval.application_id =  opt.application_id
  AND    opt.profile_option_name = 'ORG_ID'
  AND    optval.profile_option_value = p_org_id
  ORDER BY con.description;
  rDocContext cDocContext%ROWTYPE;
  CURSOR cDocTypes IS
    SELECT tl.category_id, SUBSTR(tl.user_name, instr(tl.user_name, 'GIS - ') + 6) user_name
    FROM   fnd_document_categories_tl  tl,
           fnd_document_categories cat
    WHERE  tl.category_id = cat.category_id
    AND    cat.attribute_category = 'GIS'
    AND    cat.attribute1 = UPPER(p_context)
    AND    NVL(cat.start_date_active,SYSDATE - 1) <= SYSDATE
    AND    NVL(cat.end_date_active,SYSDATE + 1) >= SYSDATE
    ORDER BY tl.user_name;
  rDocTypes  cDocTypes%ROWTYPE;
BEGIN
  -- Check if user has access to pkg
  OPEN cCheckUser;
  FETCH cCheckUser INTO vCheck;
  IF cCheckUser%NOTFOUND THEN
    vCheck := NULL;
  END IF;
  CLOSE cCheckUser;
  IF vCheck IS NOT NULL THEN
    gis_image_util.pageopen(p_heading => 'GIS - Metrics Report');
    gis_image_util.InfoHeader('Enter Metrics Report Parameters');
    htp.p('<SCRIPT language="JavaScript">
<!--BEGIN Script
var listURL = ""
function selectedOrg()
{
  var p_org

  p_org = document.show_fields.p_org_id.options[document.show_fields.p_org_id.selectedIndex].value
  document.location = "gis_metrics_report.show_fields?p_user_id=' || p_user_id || '&p_org_id=" + p_org
}
function selectedLOB()
{
  var p_org
  var p_lob

  p_org = document.show_fields.p_org_id.options[document.show_fields.p_org_id.selectedIndex].value
  p_lob = document.show_fields.p_context.options[document.show_fields.p_context.selectedIndex].value
  while (p_lob.search(" ") > 0)
  {
    p_lob = p_lob.replace(" ", "+")
  }
  document.location = "gis_metrics_report.show_fields?p_user_id=' || p_user_id || '&p_context=" + p_lob + "&p_org_id=" + p_org
}
function reportInfo(p_output)
{
  var nullError
  var listURL = ""
  
  nullError = ""
  if ((document.show_fields.p_start_date.value == "") && (nullError == ""))
  {
    alert("Start date required")
    nullError = "1"
    document.show_fields.p_start_date.focus()
  }
  if ((document.show_fields.p_end_date.value == "") && (nullError == ""))
  {
    alert("End date required")
    nullError = "1"
    document.show_fields.p_end_date.focus()
  }
  if (nullError == "")
  {
    listURL = "gis_metrics_report.report_info?p_user_id=' || p_user_id || '&p_context=' || REPLACE(p_context, ' ', '+') || '&p_doc_type=' || REPLACE(p_doc_type, ' ', '+') || '&p_start_date=' || p_start_date || '&p_end_date=' || p_end_date || '&p_org_id=' || p_org_id || '&p_output=' || '" + p_output
    viewimage('''', '''', listURL)
  }
}
//-->
</SCRIPT>');
    htp.formOpen('gis_metrics_report.report_info', 'POST',cattributes=>'NAME="show_fields"');
    htp.p('<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="1">');
    -- Show Org
    htp.p('  <TR>');
    htp.p('    <TD ALIGN="RIGHT" VALIGN="MIDDLE"><SPAN CLASS="mediumfont">Organization</SPAN>	</TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE">');
    htp.formSelectOpen(cname=>'p_org_id',nsize=>'1', cattributes=>'onChange="selectedOrg()"');	
    htp.formSelectOption('Select An Organization', CATTRIBUTES=>'value=""');
    OPEN cShowOrg;
    LOOP
      FETCH cShowOrg INTO rShowOrg;
      EXIT WHEN cShowOrg%NOTFOUND;
      IF rShowOrg.organization_id = NVL(p_org_id, -999) THEN
        htp.formSelectOption(rShowOrg.name, CATTRIBUTES=>'SELECTED value="' || TO_CHAR(rShowOrg.organization_id) || '"');
      ELSE
        htp.formSelectOption(rShowOrg.name, CATTRIBUTES=>'value="' ||	TO_CHAR(rShowOrg.organization_id) || '"');
      END IF;
    END LOOP;
    CLOSE cShowOrg;
    htp.formSelectClose;
    htp.p('    </TD>');
    htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
    htp.p('  </TR>');
    IF p_org_id IS NOT NULL THEN
      -- Show LOB
      htp.p('  <TR>');
      htp.p('    <TD WIDTH="1%"  ALIGN="RIGHT" VALIGN="MIDDLE"><SPAN CLASS="mediumfont">LOB</SPAN></TD>');
      htp.p('    <TD WIDTH="98%" ALIGN="LEFT" VALIGN="MIDDLE">');
      htp.formSelectOpen(cname=>'p_context',nsize=>'1', cattributes=>'onChange="selectedLOB()"');	
      htp.formSelectOption('Select An LOB', CATTRIBUTES=>'value=""');
      IF p_org_id IS NOT NULL THEN
        OPEN cDocContext;
        LOOP
          FETCH cDocContext INTO rDocContext;
          EXIT WHEN cDocContext%NOTFOUND;
          IF rDocContext.description = NVL(p_context, 'NULL') THEN
            htp.formSelectOption(rDocContext.description, CATTRIBUTES=>'SELECTED value="' ||	
                                 rDocContext.descriptive_flex_context_code || '"');
          ELSE
            htp.formSelectOption(rDocContext.description, CATTRIBUTES=>'value="' ||	
                                 rDocContext.descriptive_flex_context_code || '"');
          END IF;
        END LOOP;
        CLOSE cDocContext;
      END IF;
      htp.formSelectClose;
      htp.p('    </TD>');
      htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
      htp.p('  </TR>');
    END IF;
    IF p_context IS NOT NULL THEN
      -- Show doc types
      htp.p('  <TR>');
      htp.p('    <TD WIDTH="1%"  ALIGN="RIGHT" VALIGN="MIDDLE"><SPAN CLASS="mediumfont">Doc Type</SPAN></TD>');
      htp.p('    <TD WIDTH="98%" ALIGN="LEFT" VALIGN="MIDDLE">');
      htp.formSelectOpen(cname=>'p_doc_type',nsize=>'1');	  
      IF p_context IS NULL THEN
        htp.formSelectOption(NULL, CATTRIBUTES=>'value=""');
      ELSE
        -- Add All option to top of list
        htp.formSelectOption('All', CATTRIBUTES=>'value=""');
        OPEN cDocTypes;
        LOOP
          FETCH cDocTypes INTO rDocTypes;
          EXIT WHEN cDocTypes%NOTFOUND;
          htp.formSelectOption(rDocTypes.user_name, CATTRIBUTES=>'value="' ||	
                               rDocTypes.user_name || '"');
        END LOOP;
        CLOSE cDocTypes;
      END IF;
      htp.formSelectClose;
      htp.p('    </TD>');
      htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
      htp.p('  </TR>');
      -- Show start and end date
      htp.p('  <TR>');
      htp.p('    <TD WIDTH="1%"  ALIGN="RIGHT" VALIGN="MIDDLE"><SPAN CLASS="mediumfont">Start Date (DD-MON-YYYY)</SPAN></TD>');
      htp.p('    <TD ALIGN="LEFT"><INPUT type="text" name="p_start_date" size="22" maxlength="100"><A HREF="#" onClick="window.dateField = document.show_fields.p_start_date;calendar = window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=180,HEIGHT=300,RESIZABLE=0'')"><IMG SRC="' || C_IMG_URL || 'b_cal.gif" BORDER="0" ALT="Next" ALIGN="TOP"></A></TD>');
      htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
      htp.p('  </TR>');
      htp.p('  <TR>');
      htp.p('    <TD WIDTH="1%"  ALIGN="RIGHT" VALIGN="MIDDLE"><SPAN CLASS="mediumfont">End Date (DD-MON-YYYY)</SPAN></TD>');
      htp.p('    <TD ALIGN="LEFT"><INPUT type="text" name="p_end_date" size="22" maxlength="100"><A HREF="#" onClick="window.dateField = document.show_fields.p_end_date;calendar = window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=180,HEIGHT=300'')"><IMG SRC="' || C_IMG_URL || 'b_cal.gif" BORDER="0" ALT="Next" ALIGN="TOP"></A></TD>');
      htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
      htp.p('  </TR>');
      htp.p('  <TR>');
      htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
      htp.p('    <TD WIDTH="98%" ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
      htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
      htp.p('  </TR>');
    END IF;
    htp.p('  <TR>');
    htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
    IF p_org_id IS NOT NULL AND
       p_context IS NOT NULL THEN
      htp.p('    <TD WIDTH="98%" ALIGN="CENTER"><A HREF="Javascript:reportInfo(''HTML'')" onMouseOver="window.status=''Next''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || C_IMG_URL || 'b_report_l.gif" BORDER="0" ALT="Next" ALIGN="TOP"></A><A HREF="Javascript:reportInfo(''CSV'')" onMouseOver="window.status=''Next''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || C_IMG_URL || 'b_xlsexp_r.gif" BORDER="0" ALT="Next" ALIGN="TOP"></A></TD>');
    ELSE
      htp.p('    <TD WIDTH="98%" ALIGN="CENTER"><A HREF="Javascript:back()" onMouseOver="window.status=''Next''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || C_IMG_URL || 'b_back_m.gif" BORDER="0" ALT="Back" ALIGN="TOP"></A></TD>');
    END IF;
    htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
    htp.p('  </TR>');
    htp.p('</TABLE>');
    htp.formHidden('p_user_id', p_user_id);
    htp.formclose;
  ELSE
    gis_image_util.pageopen(p_heading => 'GIS - Metric Report');
    gis_image_util.InfoHeader('Access Failure');
    htp.br;
    htp.p('You do not have access to the GIS - Metrics Report.');
  END IF;
  gis_image_util.pageclose;
END show_fields;

PROCEDURE report_info(p_user_id      NUMBER,
                      p_context      VARCHAR2 DEFAULT NULL,
                      p_doc_type     VARCHAR2 DEFAULT NULL,
                      p_start_date   DATE     DEFAULT NULL,
                      p_end_date     DATE     DEFAULT NULL,
                      p_org_id       NUMBER   DEFAULT NULL,
                      p_output       VARCHAR2 DEFAULT 'HTML') IS

  CURSOR cResults IS
    SELECT document_id,
           lob,
           document_type,
           license_value,
           order_value,
           create_date,
           create_by,
           pending_date,
           pending_by,
           preindex_date,
           preindex_by,
           processed_date,
           processed_by,
           rejected_date,
           rejected_by,
           completed_date,
           completed_by,
           reprocessing_date,
           reprocessing_by
    FROM   gis_metrics_report_v
    WHERE  organization_id = p_org_id
    AND    lob = p_context
    AND    document_type = NVL(p_doc_type, document_type)
    AND    TO_DATE(create_date, 'DD-MON-YYYY HH24:MI:SS') >= NVL(TRUNC(TO_DATE(p_start_date, 'DD-MON-YYYY')), TO_DATE(create_date, 'DD-MON-YYYY HH24:MI:SS'))
    AND    TO_DATE(create_date, 'DD-MON-YYYY HH24:MI:SS') <= NVL(TRUNC(TO_DATE(p_end_date + 1, 'DD-MON-YYYY')), TO_DATE(create_date, 'DD-MON-YYYY HH24:MI:SS'))
    ORDER BY document_type, create_date;
  rResults  cResults%ROWTYPE;
  nResult   NUMBER := 0;
BEGIN
  IF p_output = 'CSV' THEN
    -- MIME header to export to excel
    owa_util.mime_header( ccontent_type=> 'application/octet-stream' , bclose_header=> FALSE );
    htp.p( 'Content-Disposition: filename=gis_' || LOWER(REPLACE(p_context, ' ', '_')) || '_' || TO_CHAR( SYSDATE, 'YYYYMONDDHH24MI' ) || '.csv' );
    owa_util.mime_header( ccontent_type=> 'application/octet-stream' , bclose_header=>TRUE);
    -- Output headings
    htp.prn( '"LOB"' );
    htp.prn( ',"Doc Type"' );
    IF p_context = 'Order Management' THEN
      htp.prn( ',"Lic Val"' );
      htp.prn( ',"Ord Val"' );
    END IF;
    htp.prn( ',"Created"' );
    IF p_context = 'Order Management' THEN
      htp.prn( ',"Pending"' );
    END IF;      
    htp.prn( ',"PreIndexed"' );
    htp.prn( ',"Processed"' );
    htp.prn( ',"Rejected"' );
    htp.prn( ',"Completed"' );
    htp.prn( ',"Reprocessing"' );
    htp.prn( ',');
    htp.p; 
  ELSE
    gis_image_util.pageopen(p_heading => 'GIS - Metrics Report Results');
    gis_image_util.InfoHeader('Metrics Report Results');
    htp.p('<TABLE WIDTH="100%" BORDER="1" CELLSPACING="0" CELLPADDING="1">');
    -- Output headings
    htp.p('  <TR>' );
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>LOB</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Doc Type</FONT></TD>');
    IF p_context = 'Order Management' THEN
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Lic Val</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Ord Val</FONT></TD>');
    END IF;
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Created</FONT></TD>');
    IF p_context = 'Order Management' THEN
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Pending</FONT></TD>');
    END IF;
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>PreIndexed</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Processed</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Rejected</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Completed</FONT></TD>');
    htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>Reprocessing</FONT></TD>');
    htp.p('  </TR>' );
  END IF;
  OPEN cResults;
  LOOP
    FETCH cResults INTO rResults;
    EXIT WHEN cResults%NOTFOUND;
    nResult := nResult + 1;
    /* Show metrics */
    IF p_output = 'CSV' THEN
      htp.prn( '"'||rResults.lob||'"');
      htp.prn( ',"'||rResults.document_type||'"');
      IF p_context = 'Order Management' THEN
        htp.prn( ',"'||rResults.license_value||'"');
        htp.prn( ',"'||rResults.order_value||'"');
      END IF;
      htp.prn( ',"'||rResults.create_date||'"');
      IF p_context = 'Order Management' THEN
        htp.prn( ',"'||rResults.pending_date||'"');
      END IF;
      htp.prn( ',"'||rResults.preindex_date||'"');
      htp.prn( ',"'||rResults.processed_date||'"');
      htp.prn( ',"'||rResults.rejected_date||'"');
      htp.prn( ',"'||rResults.completed_date||'"');
      htp.prn( ',"'||rResults.reprocessing_date||'"');
      htp.prn( ',');
      htp.p; 
    ELSE					
      htp.p('  <TR>' );
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || rResults.lob || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || rResults.document_type || '</FONT></TD>');
      IF p_context = 'Order Management' THEN
        htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || rResults.license_value || '</FONT></TD>');
        htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || rResults.order_value || '</FONT></TD>');
      END IF;
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || NVL(rResults.create_date, 'N/A') || '</FONT></TD>');
      IF p_context = 'Order Management' THEN
        htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || NVL(rResults.pending_date, 'N/A') || '</FONT></TD>');
      END IF;
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || NVL(rResults.preindex_date, 'N/A') || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || NVL(rResults.processed_date, 'N/A') || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || NVL(rResults.rejected_date, 'N/A') || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || NVL(rResults.completed_date, 'N/A') || '</FONT></TD>');
      htp.p('    <TD ALIGN="LEFT" VALIGN="MIDDLE"><FONT SIZE=2>' || NVL(rResults.reprocessing_date, 'N/A') || '</FONT></TD>');
      htp.p('  </TR>');
    END IF;
  END LOOP;
  CLOSE cResults;
  IF p_output = 'HTML' THEN
    IF nResult = 0 THEN
      htp.p('  <TR>');
      htp.p('    <TD COLSPAN=11 ALIGN="CENTER" VALIGN="MIDDLE"><FONT SIZE=2>No Images Found</FONT></TD>');
      htp.p('  </TR>');
    END IF;
    htp.p('</TABLE>');    
    htp.br;
    htp.p('<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="1">');
    htp.p('  <TR>');
    htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
    htp.p('    <TD WIDTH="98%" ALIGN="CENTER"><A HREF="Javascript:back()" onMouseOver="window.status=''Back''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="' || C_IMG_URL || 'b_back_m.gif" BORDER="0" ALT="Back" ALIGN="TOP"></A></TD>');
    htp.p('    <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="' || C_IMG_URL || 'empty.gif"></TD>');
    htp.p('  </TR>');
    htp.p('</TABLE>');
    gis_image_util.pageclose;
  END IF;
END report_info;

END gis_metrics_report;
/

