CREATE OR REPLACE PACKAGE BODY gis_migrate_user AS
/* Target       : This package assign responsibilities an specific user
Made by      : Fernando Gonzalez - IT ERP Senior Consultant(Imaging Team)
Date         : 08/02/2001.
Modified by  : Fernando Gonzalez - IT ERP Senior Consultant(Imaging Team)
Date         : 08/02/2001. 
/*========================================== Procedures =======================*/
FUNCTION get_user_id(p_user_name VARCHAR2) RETURN NUMBER IS 

n_user_id NUMBER;

BEGIN
  SELECT user_id
  INTO n_user_id
  FROM fnd_user
  WHERE user_name = p_user_name
  AND end_date IS NULL;
  RETURN n_user_id;

  EXCEPTION
  WHEN OTHERS
  THEN
  	RETURN 0;  
END get_user_id; 

FUNCTION get_application_id( p_application_short_name VARCHAR2) RETURN NUMBER IS

n_app_id NUMBER;

BEGIN
  SELECT application_id
  INTO n_app_id
  FROM fnd_application
  WHERE application_short_name = p_application_short_name;     
  RETURN n_app_id;

  EXCEPTION
  WHEN OTHERS
  THEN
  	RETURN 0;    
END get_application_id;

FUNCTION get_responsibility_id(p_responsibility_name VARCHAR2) RETURN NUMBER IS 

n_resp_id NUMBER;

BEGIN                                
  SELECT responsibility_id
  INTO n_resp_id
  FROM fnd_responsibility
  WHERE responsibility_key = p_responsibility_name;
  RETURN n_resp_id;

   EXCEPTION
  WHEN OTHERS
  THEN
  	RETURN 0;  
END get_responsibility_id;

FUNCTION user_has_access( p_user_id NUMBER, p_application_id NUMBER) RETURN BOOLEAN IS

CURSOR cur_countryListCount( f_userId NUMBER, f_appId NUMBER) IS
SELECT DISTINCT
	count(hr.name) AS orgCount
FROM
    hr_organization_units hr,
	fnd_application_tl app,
	fnd_responsibility_tl resp,
	fnd_profile_option_values optval,
	fnd_profile_options opt,
	fnd_user_resp_groups usrep,
	fnd_user usr
WHERE
	usr.user_id = f_userId
AND
	usrep.responsibility_application_id = f_appId
AND
	usr.user_id = usrep.user_id
AND
	nvl(usrep.end_date,SYSDATE+1) > SYSDATE
AND
	usrep.responsibility_application_id = app.application_id
AND
 	usrep.responsibility_id = resp.responsibility_id
AND
	usrep.responsibility_application_id = resp.application_id
AND
	usr.user_id = usrep.user_id
AND
	usrep.responsibility_id = optval.level_value
AND
	optval.profile_option_id = opt.profile_option_id
AND
	optval.application_id =  opt.application_id
AND
	opt.profile_option_name = 'ORG_ID'
AND
	optval.profile_option_value = hr.organization_id;

row_countryListCount cur_countryListCount%ROWTYPE;
b_returnValue BOOLEAN;
 	
BEGIN
	-- does the user already have access to this application?
		IF NOT cur_countryListCount%ISOPEN
		THEN
			OPEN cur_countryListCount(p_user_id, p_application_id);
		END IF;
		FETCH cur_countryListCount INTO row_countryListCount;
		IF row_countryListCount.orgCount < 1
		THEN
			b_returnValue := FALSE;
		ELSE
			b_returnValue := TRUE;
		END IF;
		CLOSE cur_countryListCount;
		
		RETURN b_returnValue;
  EXCEPTION
  WHEN OTHERS
  THEN
  	RETURN TRUE;  		
END user_has_access;

PROCEDURE insert_responsibility(p_user_name VARCHAR2
								,p_responsibility_name VARCHAR2
                                , p_application_short_name VARCHAR2) IS
                                
n_userId NUMBER := get_user_id( p_user_name); 
n_respId NUMBER := get_responsibility_id( p_responsibility_name);
n_appId NUMBER :=get_application_id( p_application_short_name);

BEGIN
--dbms_output.put_line(n_userId);
--dbms_output.put_line(n_respId);
--dbms_output.put_line(n_appId);
	IF n_userId = 0 OR n_respId = 0 OR n_appId = 0 
	THEN
		NULL;
	ELSE
	  IF NOT (user_has_access(n_userId, n_appId))
	  THEN
		  INSERT INTO fnd_user_resp_groups
		    (USER_ID
		    , RESPONSIBILITY_ID
		    , RESPONSIBILITY_APPLICATION_ID 
		    , SECURITY_GROUP_ID
		    , START_DATE
		    , END_DATE
		    , DESCRIPTION
		    , CREATED_BY
		    , CREATION_DATE
		    , LAST_UPDATED_BY
		    , LAST_UPDATE_DATE
		    , LAST_UPDATE_LOGIN)
		  SELECT
		     n_userId
		 	 ,n_respId
			 ,n_appId
		     ,0
		     , to_date('01-01-2001','DD-MM-YYYY')
		     , NULL
		     , NULL
		     , 0
		     , to_date('01-01-2001','DD-MM-YYYY')
		     , 0
		     , to_date('01-01-2001','DD-MM-YYYY')
		     , NULL
		     FROM DUAL;
		  	COMMIT; 
		END IF;
	END IF;
EXCEPTION
	WHEN OTHERS
	THEN
		dbms_output.put_line( 'Inserting record for ' || p_user_name || ' caused an error');    
END insert_responsibility;
END gis_migrate_user;
/
