CREATE OR REPLACE
PACKAGE BODY apps.gis_process_image 
IS
-- ============================================================================
--
--   NAME
--      gis_process_image_pkb.sql
--
--   DESCRIPTION
--      This script is used to create the gis_process_image package body
--      It controls the document processing screens of GIS 
--      
--   HISTORY
--      10/08/2000 David Gough In Development
--	    19/04/2001 David Gough Post patch 6 development
--						 -- corrected some navigation and email problems
--							when rejecting a document
--		24-04-2001 David Gough Business group id added to list documents
--								function for education documents
--		25-05-2001 David Gough TYPE anchors added to variables to prevent
--								incorrect datatype errors
--								This has solved problems with the reject
--								document screen
--		07/06/2001 David Gough Document_id added to call ImageDisplay
--								to make sure the correct record is
--								being viewed
--		11/06/2001 David Gough  Show processing list query modified so that it
--								does not use the view fnd_documents_vl which
--								now filters for secure documents. The secure 
--								document viewing functionality also added
--								Problem with call to checkOutUser and chechInUser
--								corrected
--		14/06/2001 David Gough  URL error on back button when rejecting an image
--								corrected by putting a replace statement around
--								p_context
--		04/07/2001 David Gough  Refresh modified to work with IE 5.5
--
-- ============================================================================
PROCEDURE processImage( p_document VARCHAR2 DEFAULT NULL
                        , p_context VARCHAR2 DEFAULT NULL
                        , p_age VARCHAR2 DEFAULT '0'
                        ,p_order VARCHAR2 DEFAULT '1'
                        ,p_org_selected VARCHAR2 DEFAULT '0'
                        ,p_org_id VARCHAR2 DEFAULT '0'
                        ,p_myList VARCHAR2 DEFAULT 'No'
                        ,p_refresh_rate NUMBER DEFAULT 600000
                        ,p_userId VARCHAR2 DEFAULT NULL
                        ,p_respId VARCHAR2 DEFAULT NULL)
IS

l_context fnd_documents_tl.doc_attribute_category%TYPE := replace(p_context,'+',' ');
p_age_low NUMBER := 0;
p_age_high NUMBER := 365;
p_selected NUMBER NULL;

BEGIN
	gis_image_util.pageopen(p_heading=>'Global Imaging System v2',p_procedure=>'gis_process_image.processImage', 
										p_attrib => 'onLoad="reloadFrame(' || TO_CHAR(p_refresh_rate) || ')"');
-- check the current user session is valid
	IF icx_sec.validateSession 
	THEN
		htp.formOpen('gis_search.QueryOptions', 'POST',cattributes=>'NAME="ProcessForm"'); 
		htp.formHidden( 'p_context',p_context);
		htp.formHidden('p_refresh_rate', p_refresh_rate);
		htp.formHidden('p_userId', p_userId);
		htp.formHidden('p_respId', p_respId);
	--	htp.formHidden( 'p_org', p_org);
		gis_image_util.infoHeader( l_context || ' Process List'
		                           ,'processing2.gif','1,'||p_userId||','||p_context||',' -- passsed as attributes
		                           ,'b_refresh.gif'
		                           ,'Refresh Process List'
		                           ,'refresh_list('||p_userId||','||p_respId||')'); 
		IF p_age = 0
		THEN
			p_age_low := 0;
			p_age_high := 365;  -- only show the last years worth of unprocessed documents
			p_selected := 0;
		ELSIF p_age = 1
		THEN
			p_age_low := 0;
			p_age_high := 1;
			p_selected := 1;
		ELSIF p_age = 7
		THEN
			p_age_low := 2;
			p_age_high := 7;
			p_selected := 2;
		ELSIF p_age = 8
		THEN
			p_age_low := 7;
			p_age_high := 365;
			p_selected := 3;
		END IF; 
		htp.formHidden( 'p_age_low', p_age_low);
		htp.formHidden( 'p_age_high', p_age_high);
		showProcessingList( p_context=>l_context
							,p_age_low=>p_age_low
							,p_age_high=>p_age_high
							,p_userId=>p_userId
							,p_order=>p_order
							,p_org_selected=>p_org_selected
							,p_org_id=>p_org_id
							,p_myList=>p_myList
							,p_respId=>p_respId);
		htp.formClose;

	-- make sure the correct lov values are selected for what is being displayed
		IF p_selected IS NOT NULL
		THEN
		htp.p( '<SCRIPT LANGUAGE="javascript">' );
		htp.p('  parent.SelectFrame.document.ProcessForm.p_age.options['|| p_selected ||'].selected = 1;'); 
		htp.p('  parent.SelectFrame.document.ProcessForm.p_order.options['|| (p_order-1) ||'].selected = 1;');	
   --		htp.p('  parent.SelectFrame.document.ProcessForm.p_org.options['|| (p_org_selected) ||'].selected = 1;');
		IF p_myList = 'Yes'
		THEN
			htp.p('  parent.SelectFrame.document.ProcessForm.myList.checked = "1";');
		END IF;			
		htp.p( '</SCRIPT>'); 
		END IF;
	ELSE
		htp.p(' Current user session is invalid or has expired');		
	END IF;
	gis_image_util.pageclose; 
END processImage;

PROCEDURE showProcessingList( p_context VARCHAR2 DEFAULT NULL
                              , p_userId VARCHAR2 DEFAULT NULL
                              , p_age_low NUMBER
                              , p_age_high NUMBER
                              ,p_order NUMBER DEFAULT 1
                              ,p_org_selected VARCHAR2 DEFAULT '0'
                              ,p_org_id VARCHAR2 DEFAULT '0'
                              ,p_myList VARCHAR2 DEFAULT 'No'
                              ,p_respId VARCHAR2)
IS

l_url gis_search.stdVarchar;
l_hrefColor VARCHAR2(15);
l_context fnd_documents_tl.doc_attribute_category%TYPE := REPLACE(p_context,'+',' ');
l_flagUrl gis_search.stdVarchar;
l_docRef gis_search.minVarchar;
cid INTEGER;
sqlSource gis_search.LargeVarchar;
l_col_1 gis_search.stdVarchar;
l_col_2 gis_search.stdVarchar;
l_col_3 NUMBER;
l_col_4 gis_search.stdVarchar;
l_col_5 gis_search.stdVarchar;
l_col_6 NUMBER;
l_col_7 gis_search.stdVarchar;
l_col_8 NUMBER;
l_col_9 gis_search.stdVarchar;
l_col_10 gis_search.stdVarchar;
l_col_11 gis_search.stdVarchar;
l_col_12 gis_search.stdVarchar;
l_col_13 gis_search.stdVarchar;
rowCount NUMBER;
l_orgList  gis_search.org_array:= gis_search.org_array();
x gis_search.stdVarchar;
l_orgId gis_search.idNumber;
l_secure gis_search.stdVarchar;

BEGIN
	-- processing list should be limited
	-- by org and responsibilities
	BEGIN	
		sqlSource :=  	' SELECT '||
					  	' doc.description '||
					  	' ,org.name org '||
						' ,NVL(docs.security_id,1) security_id '||
						' ,cat.name document '||
						' ,DECODE(ROUND(sysdate - to_date(doc_attribute7, ''DD:MON:YYYY'')),0,''New'', '||
						'      to_char(ROUND(sysdate - to_date(doc_attribute7, ''DD:MON:YYYY'')))) age '||
						' ,doc.media_id '||
						' ,doc.doc_attribute5 '||
						' ,doc.document_id '||
						' ,doc.doc_attribute15 lock_user_id '||
						' ,usr.user_name '||
						',doc.doc_attribute6 doc_status ' ||
						',(ROUND(sysdate - to_date(doc_attribute7, ''DD:MON:YYYY''))) num_age '||
						' ,substr(cat.user_name,7) user_name '||
						' ,org.organization_id '||
						' ,NVL(cats.attribute2,''OPEN'') secure '||
						' FROM fnd_document_categories cats '|| 
						' ,fnd_document_categories_tl cat '||
						' ,fnd_user usr '||
						' ,hr_operating_units org '||
						' ,fnd_documents docs '||
						' ,fnd_documents_tl doc '||
						' WHERE doc.document_id = docs.document_id ' || 
						' AND doc.language = userenv(''LANG'') '||
						' AND cat.category_id = docs.category_id  AND docs.datatype_id = 6 '||
						' AND cat.language = userenv(''LANG'') '||
						' AND cat.category_id = cats.category_id '||
						' AND doc.doc_attribute_category = '''|| p_context ||''''||
						' AND (doc.doc_attribute6 = ''PRE-INDEXED''  OR doc.doc_attribute6 = ''PENDING'') '||
						' AND doc.doc_attribute15 = usr.user_id(+) '||
						' AND ROUND(sysdate - to_date(doc_attribute7, ''DD:MON:YYYY'')) between '|| p_age_low ||' AND '|| p_age_high;
	
	-- build the filter depending on the details entered				 
		IF p_context = 'Customer' OR p_context = 'Payables' OR p_context = 'Receivables' 
		THEN
			sqlSource := sqlSource ||	' AND ((docs.security_id = org.set_of_books_id AND docs.security_type = 2) '||
												'OR ( docs.security_type = 4 AND docs.PUBLISH_FLAG = ''Y'')) ';
		ELSIF  p_context = 'Education Events' OR p_context = 'Education Bookings'
		THEN
				sqlSource := sqlSource ||	' AND ((docs.security_id = org.business_group_id AND docs.security_type = 3) '||
												'OR ( docs.security_type = 4 AND docs.PUBLISH_FLAG = ''Y'')) ';	
		ELSE 
			sqlSource := sqlSource ||	' AND ((docs.security_id = org.organization_id AND docs.security_type = 1) '||
												'OR ( docs.security_type = 4 AND docs.PUBLISH_FLAG = ''Y'')) ';	
		END IF;
							
		IF p_org_selected != '0'
		THEN
			sqlSource := sqlSource || ' AND org.organization_id = ' || p_org_id;
		ELSE
			l_orgList := gis_search.getOrgList( p_userId, p_context);
			sqlSource := sqlSource || ' AND org.organization_id  IN (';
			FOR i IN 1..l_orgList.last
			LOOP
				IF i != 1
				THEN
					sqlSource := sqlSource ||	',';
				END IF;
				sqlSource := sqlSource || l_orgList(i);
			END LOOP;
			sqlSource := sqlSource || ') ';
		END IF;
		
		IF p_myList = 'Yes'
		THEN
			sqlSource := sqlSource || ' AND doc.doc_attribute15 = '|| p_userId;
		END IF;		
			
	 	sqlSource := sqlSource ||' ORDER BY ';				
		IF p_order = 1
		THEN
			 sqlSource := sqlSource ||  'num_age asc';
		ELSIF p_order = 2
		THEN
			 sqlSource := sqlSource ||  'num_age desc';	
		ELSIF p_order = 3
		THEN
			 sqlSource := sqlSource ||  'document'; 
	    ELSIF p_order = 4
	    THEN
			 sqlSource := sqlSource ||  'description';
		ELSE
			 sqlSource := sqlSource ||  'num_age asc';
		END IF;
	
		cid := dbms_sql.open_cursor;
		dbms_sql.parse( cid, sqlSource, dbms_sql.v7);
--	htp.p( sqlSource);
	dbms_sql.define_column( cid, 1, l_col_1,50 ); 
	dbms_sql.define_column( cid, 2, l_col_2,50 ); 
	dbms_sql.define_column( cid, 3, l_col_3); 
	dbms_sql.define_column( cid, 4, l_col_4,50 ); 
	dbms_sql.define_column( cid, 5, l_col_5,50 ); 
	dbms_sql.define_column( cid, 6, l_col_6); 
	dbms_sql.define_column( cid, 7, l_col_7,50 ); 
	dbms_sql.define_column( cid, 8, l_col_8); 
	dbms_sql.define_column( cid, 9, l_col_9,50); 
	dbms_sql.define_column( cid, 10, l_col_10 ,50); 
	dbms_sql.define_column( cid, 11, l_col_11 ,25);
	dbms_sql.define_column( cid, 12, l_col_12 ,25); 
	dbms_sql.define_column( cid, 13, l_col_13 ,40); 
	dbms_sql.define_column( cid, 14, l_orgId); 
	dbms_sql.define_column( cid, 15, l_secure, 255);
				
	rowCount := dbms_sql.execute_and_fetch( cid);
	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	IF rowCount != 1
	THEN
		htp.br;
		htp.br;
		htp.p('<TR><TD ALIGN="RIGHT"><IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif"></TD>');
		htp.p('<TD ALIGN="LEFT"><FONT size=''5''><B>No Records Found</B></FONT></TD></TR>');
	ELSE
 	    htp.p('		<TR BGCOLOR="#C9C9C9">');
--		IF p_super_user
--		THEN
			htp.p('     	<TD><FONT color="#C9C9C9">A</FONT></TD>');
--		END IF;
	   		
		htp.p('			<TD><FONT color=BLACK SIZE=2><B>Description</B></TD>');
		htp.p('			<TD ALIGN="CENTER"><FONT color=BLACK SIZE=2><B>Org</B></TD>');
		htp.p('			<TD ALIGN="CENTER"><FONT color=BLACK SIZE=2><B>Age</B></TD>');
		htp.p('			<TD><FONT color=BLACK SIZE=2><B>Doc Type</B></TD>');		
		htp.p('			<TD><FONT color=BLACK SIZE=2><B>In/Out</B></TD>');
        htp.p('		</FONT></TR>');
		WHILE rowCount = 1 
		LOOP		
			dbms_sql.column_value( cid, 1, l_col_1);
			dbms_sql.column_value( cid, 2, l_col_2);
			dbms_sql.column_value( cid, 3, l_col_3);
			dbms_sql.column_value( cid, 4, l_col_4);
			dbms_sql.column_value( cid, 5, l_col_5);
			dbms_sql.column_value( cid, 6, l_col_6);
			dbms_sql.column_value( cid, 7, l_col_7);
			dbms_sql.column_value( cid, 8, l_col_8);
			dbms_sql.column_value( cid, 9, l_col_9);
			dbms_sql.column_value( cid, 10, l_col_10);
			dbms_sql.column_value( cid, 11, l_col_11);
			dbms_sql.column_value( cid, 12, l_col_12);
			dbms_sql.column_value( cid, 13, l_col_13);
			dbms_sql.column_value( cid, 14, l_orgId);
			dbms_sql.column_value( cid, 15, l_secure);
			l_col_1 := REPLACE( l_col_1,'''',' ');
		-- get the access code and url to view the image through fnd_gfm
			l_url := fnd_gfm.construct_download_url( gis_image_util.get_pack_url,l_col_6);
		-- check for comments
			IF l_col_7 IS NOT NULL
			THEN
				l_hrefColor := gis_image_util.c_comments_yes;
			ELSE                                   
				l_hrefColor := gis_image_util.c_comments_no;           
			END IF;
		-- set the url for the required flag
			l_flagUrl := gis_image_util.c_flags_url || 'f_' || l_col_3 ||'.gif';						
        	htp.p('		<TR>');
	--		IF p_super_user
	--		THEN 
				IF (l_col_9 IS NULL AND l_col_11 != 'PENDING')
		    	THEN
		    	 	l_docRef := l_col_8; 
		    	 	htp.p('	<TD ALIGN="CENTER"><INPUT TYPE="checkbox" NAME="docList" VALUE="'||l_docRef||'"></TD>');
		    	ELSE
		    		htp.p(' <TD></TD>');--l_docRef := 0;	
		    	END IF;
		
	--		END IF;
			IF l_secure = 'OPEN' OR gis_search.viewSecureDocument( p_userId, l_orgId, p_context)
			THEN
				htp.p('			<TD><A HREF="JavaScript:searchimage('''||gis_image_util.c_pack_url);
				htp.p(				'gis_search.ImageDetails?p_file_id='||l_col_6||'&p_document_id='||l_col_8||'&p_context=');
				htp.p(				REPLACE(p_context,' ','+')||'&p_navTo=userList&p_userId='||p_userId||'&p_respId='||p_respId||''','''||l_url||''')" onMouseOver="window.status=''View Image''; ');
				htp.p('	   			return true" onMouseOut="window.status='' ''; return true"><FONT COLOR="'||l_hrefColor||'" SIZE="2">');
				htp.p(			 	l_col_1 ||' </FONT></A></TD>');
			ELSE
				htp.p('			<TD><FONT COLOR="'||l_hrefColor||'" SIZE="2">'||l_col_1 ||' </FONT></A></TD>');			
			END IF;
			htp.p(' 		<TD ALIGN="CENTER" VALIGN="MIDDLE" '||gis_image_util.c_background_color||'><IMG SRC= "'||l_flagUrl);
			htp.p(				'"  ALIGN="CENTRE" ALT="'||l_col_2||'"></TD>');	
			htp.p('			<TD ALIGN="CENTER"><FONT color=WHITE SIZE=2><B>'||l_col_5||'</FONT></B></TD>');
			htp.p(' 	    <TD ALIGN="CENTER" VALIGN="MIDDLE"><A HREF=JavaScript:alert('''||REPLACE(l_col_13,' ','_')||''')><FONT COLOR="WHITE" SIZE="1">' || l_col_4 ||' </FONT></A></TD>');
--			htp.p('			<TD><FONT color=WHITE SIZE=2>'||l_col_4||'</FONT></TD>'); 
			-- check to see if document is checked out
			IF l_col_9 IS NULL
			THEN
				IF l_col_11 = 'PENDING'
				THEN
					htp.p(' <TD><FONT COLOR="BLACK">Pending</FONT></TD>');
				ELSE
		  			htp.p( '    <TD ALIGN="CENTER" WIDTH="1%"><A HREF="gis_checkout_Image.checkoutImage?p_document_id='
		  		         		       ||l_col_8||'&p_user_id='||p_userId||
			  						   '&p_context='||replace(p_context,' ','+')||'&p_respId='||p_respId||'" TARGET="QueryFrame"' ||
	                                   'onMouseOver="window.status=''Check out ' || LOWER( l_col_4 ) || ' (' 
	                                   || l_col_1 || ')''; return true" ' ||
	                                   'onMouseOut="window.status=''''; return true"> ' ||
	                                   '<IMG SRC="'|| gis_image_util.c_image_url||'b_checkout.gif" BORDER="0" ALT="Check out ' || 
	                                   LOWER( l_col_4 ) || ' (' || l_col_1 || ')"></A></TD>' );		
	            END IF;
	            htp.p('		</TR>'); 
            ELSE
            	IF l_col_9 = p_userId
            	THEN
		  			htp.p( '    <TD ALIGN="CENTER" WIDTH="1%"><A HREF="gis_checkout_Image.checkinImage?p_document_id='
		  		         		       ||l_col_8||'&p_user_id='||p_userId||
		  		         		       '&p_context='||replace(p_context,' ','+')||'&p_respId='||p_respId||'" TARGET="QueryFrame"' ||
	                                   'onMouseOver="window.status=''Check in ' || LOWER( l_col_4 ) || ' (' 
	                                   || l_col_1 || ')''; return true" ' ||
	                                   'onMouseOut="window.status=''''; return true"> ' ||
	                                   '<IMG SRC="'|| gis_image_util.c_image_url||'b_outchecked.gif" BORDER="0" ALT="Check in ' || 
	                                   LOWER( l_col_4 ) || ' (' || l_col_1 || ')"></A></TD>' );		
	            	htp.p('		</TR>');
            	ELSE
		  			htp.p( '    <TD ALIGN="CENTER" WIDTH="1%"><A HREF="gis_checkout_Image.checkinImage?p_document_id='
		  		         		       ||l_col_8||'&p_user_id='||p_userId||
		  		         		       '&p_context='||p_context||'&p_respId='||p_respId||'" TARGET="QueryFrame"' ||
	                                   'onMouseOver="window.status=''This ' || l_col_4 || 
	                                   ' document is already checked out to '|| l_col_10||'''; return true" ' ||
	                                   'onMouseOut="window.status=''''; return true"> ' ||
	                                   '<IMG SRC="'|| gis_image_util.c_image_url||'b_outchecked.gif" BORDER="0" ALT="This ' || l_col_4 || 
	                                   ' document is already checked out to '|| l_col_10|| '"></A></TD>' );		
	            	htp.p('		</TR>');
				END IF;            	             	
            END IF;				
			rowCount := dbms_sql.fetch_rows( cid);
		END LOOP;
		dbms_sql.close_cursor( cid);		                                                      
	END IF; 
	htp.p('	 </TABLE>');

	EXCEPTION
	WHEN OTHERS
	THEN
	null;
		x := gis_search.showErr( sqlSource, ' gis_process_image.showProcessingList');
	END;
END showProcessingList; 

PROCEDURE imageProcessed( p_docid VARCHAR2
							,p_userId VARCHAR2 DEFAULT '1'
							,p_context VARCHAR2
							,p_respId VARCHAR2
							,p_navTo VARCHAR2 DEFAULT NULL) 
IS

l_processedStatus NUMBER;

BEGIN
	UPDATE fnd_documents_tl
	SET doc_attribute6 = 'PROCESSED'
		,doc_attribute7 = TO_CHAR(SYSDATE, 'DD-MON-YYYY') 
		,doc_attribute8 = p_userId
		,doc_attribute15 = NULL
		,last_updated_by = p_userId
		,last_update_date = SYSDATE
	WHERE document_id = p_docid;

	SELECT doc_status_type_id
	INTO l_processedStatus
	FROM gis_doc_status_types
	WHERE doc_status_name = 'PROCESSED';
	
	INSERT INTO gis_doc_status(	document_id
								,doc_status_type_id
								,date_created
								,created_by
								,last_update_date
								,last_updated_by)

	VALUES ( 	p_docid
				,l_processedStatus     --  will depened on document context ie non attached docs
					   --  should be 5 'compleated'
				,sysdate
				,p_userId
				,sysdate
				,p_userId);
	COMMIT;	
	gis_image_util.pageopen(p_heading=>'Global Imaging System v2',p_procedure=>'gis_process_image.imageProcessed');
	gis_image_util.infoHeader( 'Image Processed','processing2.gif');
	htp.br;
	htp.br; 
	htp.p('  <TABLE WIDTH="80%" ALIGN="CENTER" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('		<TR>');	
    htp.p('    		<TD VALIGN="TOP" ALIGN="CENTER"><IMG SRC="'||gis_image_util.c_image_url||'i_note.gif" ALT="Note"></TD>' );
	htp.p('			<TD><B> Document has been marked as processed </B></TD>');
	htp.p('		</TR>');
	htp.p('	</TABLE>'); 
-- refresh frames if required 
	IF (gis_image_util.userAccessRights( p_userId ,p_respId)) = 'Process User'
	THEN
		gis_checkout_image.refreshList( p_context,p_userId ,p_respId);
	ELSE  -- inquiry user screen
		htp.p( '<SCRIPT LANGUAGE="javascript">' );
	   	htp.p( 'parent.ViewingFrame.document.location="gis_image_util.ViewingFrame?p_userType=Inquiry User"');
		htp.p( '</SCRIPT>'); 		
	END IF;
-- where to go after marking document as processed
	IF p_navTo IS NULL
	THEN  
		gis_checkout_image.refreshList( p_context, p_userId, p_respId);
		htp.p( '<SCRIPT LANGUAGE="javascript">' );
	   	htp.p( 'parent.QueryFrame.document.location="gis_checkout_image.checkOutUsers?p_context='||REPLACE(p_context,' ','+')||
	   				'&p_orgId=&p_userId='||p_userId||'&p_respId='||p_respId||'"' );
		htp.p( '</SCRIPT>'); 
	ELSE
		gis_checkout_image.refreshList( p_context, p_userId, p_respId);
		htp.p( '<SCRIPT LANGUAGE="javascript">' );
	   	htp.p( 'parent.QueryFrame.document.location="'||REPLACE(REPLACE(p_navTo,'~','&'),' ','+')||'"' );
		htp.p( '</SCRIPT>'); 
	END IF;
	gis_image_util.pageclose;
END imageProcessed;

PROCEDURE refreshInterval IS

BEGIN
	htp.formOpen('POST',ctarget=>'',cattributes=>'NAME="refreshIntForm"');
	gis_image_util.pageopen(p_heading=>'Global Imaging System v2',p_procedure=>'gis_process_image.refreshInterval');
	gis_image_util.infoHeader( 'Select Default Refresh','processing2.gif'); 
	htp.br;
	htp.br;
	htp.p('<TABLE WIDTH="80%" ALIGN="CENTER" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('<TR><TD>Refresh Rate</TD>');
   	htp.p('<TD><FONT SIZE="2"><SELECT NAME="p_refresh_rate" SIZE="1">');
	htp.p('<OPTION SELECTED value="300000">Refresh every 5 min');
	htp.p('<OPTION value="600000">Refresh every 10 min');
	htp.p('<OPTION value="900000">Refresh every 15 min');
	htp.p('<OPTION value="1200000">Refresh every 20 min');
	htp.p('<OPTION value="1800000">Refresh every 30 min');
	htp.p('</SELECT></FONT></TD>');  
	htp.p('</TR>');
	htp.p('</TABLE>');
	htp.formClose;
	gis_image_util.pageclose; 
END refreshInterval; 


PROCEDURE rejectImage( 	p_docid    VARCHAR2
						,p_context VARCHAR2
						,p_userId  VARCHAR2
						,p_respId  VARCHAR2
						,p_navTo   VARCHAR2 DEFAULT NULL)
IS

  l_comments             fnd_documents_short_text.short_text%TYPE;
  l_desc                 fnd_documents_tl.description%TYPE;
  l_count                NUMBER := 0;
  l_fileId               fnd_lobs.file_id%TYPE := 0;
  l_docType              gis_search.stdVarchar;
  l_scannerDesc          gis_scanners.description%TYPE;
  l_commentsFound        BOOLEAN := TRUE;
  l_userEmailAddress     gis_search.stdVarchar;
  l_indexerEmailAddress  gis_search.stdVarchar;
  l_rejectedStatus       NUMBER;
  l_preindexedStatus     NUMBER;
  bMailButton 			 BOOLEAN := TRUE;

BEGIN
	gis_image_util.pageopen(p_heading=>'Global Imaging System v2',p_procedure=>'gis_process_image.rejectImage');
	gis_image_util.infoHeader( 'Document Rejected','processing2.gif');
	BEGIN
	-- get the comments to mail to the scan operator
	-- operation should fail if there are none
		SELECT text.short_text
			   ,tl.description
			   ,tl.media_id
			   ,tl.doc_attribute_category || ' - ' || SUBSTR(ct.user_name, 7)
			   ,s.description || ' (' || s.scanner_id || ')'
		INTO l_comments
		     ,l_desc
		     ,l_fileId
		     ,l_docType
             ,l_scannerDesc
		FROM fnd_documents_tl tl,
			 fnd_documents_short_text text,
			 fnd_lobs l,
			 gis_scanners s,
			 fnd_documents d,
			 fnd_document_categories_tl ct
		WHERE tl.document_id = p_docid
		AND   tl.doc_attribute5 = text.media_id
		AND   tl.media_id = l.file_id
		AND   l.program_tag = s.scanner_id
		AND   tl.document_id = d.document_id
		AND   d.category_id = ct.category_id;
	EXCEPTION
		WHEN NO_DATA_FOUND
		THEN
			l_commentsFound := FALSE;
	END;
	
	IF l_commentsFound
	THEN
		UPDATE fnd_documents_tl
		SET doc_attribute6 = 'REJECTED'
			,doc_attribute7 = TO_CHAR(SYSDATE, 'DD-MON-YYYY')
			,doc_attribute8 = p_userId
			,doc_attribute15 = NULL
			,last_updated_by = p_userId
			,last_update_date = SYSDATE
		WHERE document_id = p_docid;

		SELECT doc_status_type_id
		INTO l_rejectedStatus
		FROM gis_doc_status_types
		WHERE doc_status_name = 'REJECTED';
		
	-- this is to allow a document to be rejected more than once
	-- and maintain the dos_status table correctly
		SELECT count(*)
		INTO l_count
		FROM gis_doc_status
		WHERE doc_status_type_id = l_rejectedStatus
		AND document_id = p_docid;
		
		IF l_count >=1
		THEN
			UPDATE	gis_doc_status
			SET last_update_date = sysdate,
			last_updated_by = p_userId
			WHERE doc_status_type_id = l_rejectedStatus
			AND document_id = p_docid;
		ELSE
			INSERT INTO gis_doc_status(	document_id
										,doc_status_type_id
										,date_created
										,created_by
										,last_update_date
										,last_updated_by)
		
		
			VALUES ( 	p_docid
						,l_rejectedStatus     --  will depened on document context ie non attached docs
							   --  should be 5 'compleated'
						,sysdate
						,p_userId
						,sysdate
						,p_userId);
		END IF;
		COMMIT;	
		
		-- catch no_data_found error
	    BEGIN
            SELECT pf.email_address 
            INTO l_userEmailAddress
            FROM fnd_user usr
 	    	   	,per_people_f pf
            WHERE usr.user_id = p_userId
            AND   usr.employee_id = pf.person_id
            AND   pf.effective_end_date > SYSDATE
            AND   pf.effective_start_date < SYSDATE;
		EXCEPTION
			WHEN no_data_found
			THEN
				htp.p('  <TABLE WIDTH="80%" ALIGN="CENTER" BORDER="0" CELLSPACING="0" CELLPADDING="2">
							<TR><TD><IMG SRC="'||gis_image_util.c_image_url||'empty.gif" ALT="Note"></TD>
										<TD><P>Note: User has no email address defined</P></TD></TR></TABLE>');
			END;		

        -- Modified: Patrick Low 15/03/2001
        --           Should be preindexed status to email user who preindexed the document
		SELECT doc_status_type_id
		INTO l_preindexedStatus
		FROM gis_doc_status_types
		WHERE doc_status_name = 'PRE-INDEXED';
		
	    BEGIN
        -- Modified: Patrick Low 15/03/2001
        --           Get email address from per_people_f - fnd_user does not always have an email address
        --           New email address will be recorded in per_people_f in future
            SELECT pf.email_address 
            INTO l_indexerEmailAddress
            FROM fnd_user usr
               	,gis_doc_status sta
	    	   	,per_people_f pf
            WHERE sta.document_id = p_docid
            AND   sta.doc_status_type_id = l_preindexedStatus
            AND   sta.created_by = usr.user_id
            AND   usr.employee_id = pf.person_id
            AND   pf.effective_end_date > SYSDATE
            AND   pf.effective_start_date < SYSDATE;
		EXCEPTION
			WHEN no_data_found
			THEN
				htp.p('  <TABLE WIDTH="80%" ALIGN="CENTER" BORDER="0" CELLSPACING="0" CELLPADDING="2">
							<TR><TD><IMG SRC="'||gis_image_util.c_image_url||'empty.gif" ALT="Note"></TD>
										<TD><P>Note: Pre-indexer has no email address defined</P></TD></TR></TABLE>');
				bMailButton := FALSE;
			END;	
			
		-- l_indexerEmailAddress:= 'david.gough@oracle.com'; -- used for testing
		htp.br; 
		htp.p('<FORM NAME="mailcomments" ACTION="mailto:'||l_indexerEmailAddress||'?SUBJECT=Rejected Image For ' || l_docType ||'&cc='||l_userEmailAddress||'" METHOD="post"
							ENCTYPE="text/plain">');
		
	--	htp.p('<FORM ACTION="gis_search.QueryIndex" METHOD="POST" TARGET="ViewingFrame" NAME="test">');
		htp.formHidden('The following document has been rejected from the Global Imaging System.' || CHR(10) || CHR(10) || 'Processing Queue ', ' ' || l_scannerDesc);
		htp.formHidden('File ID ', ' ' || l_fileId);
		htp.formHidden('Document Type ', ' '||l_docType);
		htp.formHidden('Description ',' '||l_desc || CHR(10) || CHR(10) ||
		                                'COMMENTS LOG' || CHR(10) || CHR(10) ||
		                                replace(replace(replace(l_comments,'<'),'>'),'"')  || CHR(10) || CHR(10) ||
                                        'Check your scan operator queue for REJECTED documents.');
		
		htp.p('  <TABLE WIDTH="80%" ALIGN="CENTER" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
		htp.p('		<TR>');	
	    htp.p('    		<TD VALIGN="TOP" ALIGN="CENTER"><IMG SRC="'||gis_image_util.c_image_url||'i_note.gif" ALT="Note"></TD>' );
		htp.p('			<TD><B>Document has been rejected. It can be viewed from the appropriate index queue</B></TD>');
		htp.p('		</TR>');
		htp.p('		<TR>');
	    htp.p('    		<TD VALIGN="TOP" ALIGN="CENTER"><IMG SRC="'||gis_image_util.c_image_url||'empty.gif"></TD>' );
		htp.p('		</TR>');
		IF 	bMailButton
		THEN
			HTP.P('		<TR>');
		    HTP.P('    		<TD VALIGN="TOP" ALIGN="CENTER"><IMG SRC="'||GIS_IMAGE_UTIL.C_IMAGE_URL||'empty.gif"></TD>' );
			HTP.P('			<TD><B>CLICK ON MAIL BUTTON BELOW TO INFORM SCAN OPERATOR</B></TD>');
			HTP.P('		<TR>');
			HTP.P('		</TR>');
		END IF;
		htp.p('	</TABLE>');
		htp.br;
		IF 	bMailButton
		THEN
			htp.p('  <TABLE WIDTH="80%" ALIGN="CENTER" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
			htp.p('		<TR>');	
		    htp.p('    		<TD VALIGN="TOP" ALIGN="CENTER"><INPUT TYPE="submit" VALUE="Mail :'||l_indexerEmailAddress||'"></TD>');
			htp.p('		</TR>');    
			htp.p('	</TABLE>');
			htp.br;
		END IF;
		htp.p('  <TABLE WIDTH="80%" ALIGN="CENTER" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
		htp.p('		<TR>');	

--  if this document was rejected from the process screens refresh the the process list
--  p_navTo will contain 'userList' when navigating from the process screens
		IF instr(p_navTo,'userList') > 0
		THEN 
			gis_checkout_image.refreshList( p_context, p_userId, p_respId);
-- format back button url to return to the user list screen
	    	htp.p('    		<TD VALIGN="TOP" ALIGN="CENTER"><A HREF="'||gis_image_util.c_pack_url||'gis_checkout_image.checkOutUsers?p_context='||REPLACE(p_context,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId||'"><IMG SRC="'||gis_image_util.c_image_url||'b_back_m.gif" BORDER="0" ALT="Back"></A></TD>' );		
		ELSE
-- format back button url to return to the image details screen
	    	htp.p('    		<TD VALIGN="TOP" ALIGN="CENTER"><A HREF="'||REPLACE(REPLACE(p_navTo,'~','&'),' ','+')||'"><IMG SRC="'||gis_image_util.c_image_url||'b_back_m.gif" BORDER="0" ALT="Back"></A></TD>' );
		END IF;
		htp.p('		</TR>');
		htp.p('	</TABLE>'); 
	    htp.p('</FORM>');
	ELSE -- no comments found
	   	htp.p( gis_search.js( 'alert("No Comments Found - Operation canceled");parent.QueryFrame.back(); ' ));
	END IF;
	gis_image_util.pageclose;
EXCEPTION
	WHEN OTHERS
	THEN
		htp.p(gis_search.showErr( null,'gis_process.rejectImage'));
		ROLLBACK;
END rejectImage;
 
END gis_process_image;
/
