CREATE OR REPLACE
PACKAGE BODY apps.GIS_REPORT_PKG AS     
                                        
/*-------------------------------------------------------------------------+    
 | PUBLIC FUNCTION(s)                                                      |    
 | DESCRIPTION                                                             |    
 |    FUNCTIONs designed to track documents across the status life-cycle   |    
 |    in GIS 11i.                                                          |    
 |    These FUNCTIONs are designed to be called in-line to create a Report |    
 |    using Discoverer.                                                    |    
 |                                                                         |    
 | EXAMPLE:                                                                |    

   SELECT
         document_id "Image No."
	,GIS_REPORT_PKG.doctype(document_id) "Document Type"
	,GIS_REPORT_PKG.lic_ord_value(document_id,'LICENSE') "License Value"
	,GIS_REPORT_PKG.lic_ord_value(document_id,'ORDER') "Order Value"
	,TO_DATE(GIS_REPORT_PKG.namedate(document_id, 'DATE', 1)) "Created Date"
	,GIS_REPORT_PKG.namedate(document_id, 'BYWHOM', 1) "Created By"
	,TO_DATE(GIS_REPORT_PKG.namedate(document_id, 'DATE', 2)) "Pending Date"
	,GIS_REPORT_PKG.namedate(document_id, 'BYWHOM', 2) "Pending By"
	,TO_DATE(GIS_REPORT_PKG.namedate(document_id, 'DATE', 3)) "Pre-Indexed Date"
	,GIS_REPORT_PKG.namedate(document_id, 'BYWHOM', 3) "Pre-Indexed By"
	,TO_DATE(GIS_REPORT_PKG.namedate(document_id, 'DATE', 4)) "Processed Date"
	,GIS_REPORT_PKG.namedate(document_id, 'BYWHOM', 4) "Processed By"
	,TO_DATE(GIS_REPORT_PKG.namedate(document_id, 'DATE', 5)) "Rejected Date"
	,GIS_REPORT_PKG.namedate(document_id, 'BYWHOM', 5) "Rejected By"
	,TO_DATE(GIS_REPORT_PKG.namedate(document_id, 'DATE', 6)) "Completed Date"
	,GIS_REPORT_PKG.namedate(document_id, 'BYWHOM', 6) "Completed By"
	,TO_DATE(GIS_REPORT_PKG.namedate(document_id, 'DATE', 7)) "Flagged for Reprocessing Date"
	,GIS_REPORT_PKG.namedate(document_id, 'BYWHOM', 7) "Flagged for Reprocessing By"
	FROM  gis_doc_status
	GROUP BY document_id;

 | MODIFICATION HISTORY                                                    |
 |    20-FEB-2001          Dave A. Anselmi  Function(s) Created.           |
 |                                                                         |
 +-------------------------------------------------------------------------*/


FUNCTION doctype(fileid IN NUMBER) RETURN VARCHAR2 IS

   rvalue  fnd_document_categories_tl.user_name%TYPE;

BEGIN
   SELECT user_name INTO rvalue FROM fnd_document_categories_tl
   WHERE  category_id = (
         SELECT category_id FROM fnd_documents
         WHERE  document_id = fileid
   );
                                        
   --truncate if first 6 char's are 'GIS - '                                    
   IF SUBSTR(rvalue,1,6) = 'GIS - '
   THEN rvalue := SUBSTR(rvalue,7);
   END IF;

   RETURN  rvalue;

EXCEPTION
  WHEN OTHERS THEN
    RETURN NULL;

END  doctype;


FUNCTION namedate(fileid IN NUMBER, flag IN VARCHAR2, status IN NUMBER) RETURN VARCHAR2 IS

   rvalue         fnd_user.user_name%TYPE;
   d_datecreate   gis_doc_status.date_created%TYPE;                             
   n_createby     gis_doc_status.created_by%TYPE;                               

BEGIN                                   
   SELECT  date_created, created_by
   INTO    d_datecreate, n_createby
   FROM    gis_doc_status
   WHERE   document_id = fileid
   AND     doc_status_type_id = status;

   IF flag = 'DATE' THEN
     IF d_datecreate IS NULL THEN
       RETURN d_datecreate;
     ELSE
       RETURN TO_CHAR(d_datecreate, 'DD-MON-YYYY HH24:MI:SS');
     END IF;
   ELSE
     IF flag = 'BYWHOM' THEN
       RETURN username(n_createby);                                       
     ELSE
       RETURN NULL;
     END IF;
   END IF;

EXCEPTION
  WHEN OTHERS THEN
    RETURN NULL;

END  namedate;


FUNCTION username(userid IN NUMBER) RETURN VARCHAR2 IS

   rvalue fnd_user.user_name%TYPE;      

BEGIN                                   
  SELECT user_name
  INTO rvalue
  FROM fnd_user
  WHERE user_id = userid;

  RETURN  rvalue;

EXCEPTION
  WHEN OTHERS THEN
    RETURN NULL;

END  username;


FUNCTION lic_ord_value(fileid IN NUMBER, flag IN VARCHAR2) RETURN VARCHAR2 IS

   licval fnd_documents_tl_dfv.license_value%TYPE;
   ordval fnd_documents_tl_dfv.order_value%TYPE;

BEGIN                                   

  SELECT v.license_value, v.order_value
  --, v.index_status_id
  INTO   licval, ordval
  FROM   fnd_documents_tl t, fnd_documents d, fnd_documents_tl_dfv v
  WHERE  d.document_id = fileid
  AND    t.document_id = d.document_id
  AND    d.datatype_id =
    (SELECT datatype_id
     FROM   fnd_document_datatypes
     WHERE  name = 'FILE'
     AND    NVL(start_date_active, SYSDATE) <= SYSDATE
     AND    NVL(end_date_active, SYSDATE) >= SYSDATE)
  AND    t.rowid = v.rowid;

  IF flag = 'LICENSE'
  THEN RETURN licval;
  ELSE  IF flag = 'ORDER'
        THEN RETURN ordval;
        ELSE RETURN NULL;
        END IF;
  END IF;

EXCEPTION
  WHEN OTHERS THEN
    RETURN NULL;

END  lic_ord_value;

END  GIS_REPORT_PKG;
/

