CREATE OR REPLACE
PACKAGE BODY apps.gis_search AS
-- ============================================================================
--
--   NAME
--      gis_search_pkb.sql
--
--   DESCRIPTION
--      This script is used to create the gis_search package body
--      It controls the web inquiry screens of GIS 
--      
--   HISTORY
--      10/08/2000 David Gough In Development
--	    17/04/2001 David Gough Post patch 6 development
--					Altered ImageDetails procedure to prevent
--					modify button from being displayied when user does not
--					have the process user responsibility.
--					User session is now validated in various procedures
--					Date format validation added to query screens
--					Date query options updated
--		10/05/2001  David Gough HR Assignment query context added
--		16/05/2001  David Gough Query performance changes in QueryActions
--				    onMouseOver function added
--					ValidValue functon added
--					js function added
--					autoCommit added
--					std error window code added
--					secure document details added
--	 	23/05/2001  ViewSecureDocument added
--					Where possible checks for secure document
--					should go to the documant category
--					and not the attached document record
--					This is because there is currently no process
--					for updating the secure document flag in 
--					fnd_attached_documents in the document 
--					category is changed
--		05/06/2001  David Gough Customers application query
--					multi-org'd. SelectFrame cleared when new 
--					indexed query run.
--		05/06/2001  David Gough document_id added to imagedetails
--					procedure to make sure the correct
--					record is being dispalayed
--		14/06/2001  David Gough - out of subscript error corrected in 
--					imageDetails. document_id added to callback to imageDetails
--					when modify button used 
--
-- ============================================================================

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE  QueryIndex(	p_document VARCHAR2
						,p_userType VARCHAR2
						,p_userId VARCHAR2
						,p_respId VARCHAR2) IS

BEGIN
	gis_image_util.pageopen(p_heading => 'Document Search',p_procedure=>'gis_search.QueryIndex');
	gis_image_util.InfoHeader( 'Select Search Mode');
-- check the current user session is valid
	IF icx_sec.validateSession 
	THEN
		htp.br;
		htp.br;
		htp.p('  <TABLE WIDTH="75%" ALIGN="LEFT" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
		htp.p('		 <TD ALIGN="RIGHT"><B>Applications Query</FONT></B></TD>');
		htp.p('		 <TD ALIGN="LEFT"><A HREF="JavaScript:parent.QueryFrame.document.location='''||gis_image_util.c_pack_url||'gis_search.QueryContext?p_document=Indexed&p_navTo=&p_target=
									&p_userType='||REPLACE(p_userType,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId||'''" 
									'|| gis_search.onMouseOver('Query on all applications data (some records may not have images attached)')||'>
									<IMG SRC="'||gis_image_util.c_image_url||'b_query.gif" BORDER="0" ALIGN="TOP" ALT="Query on all applications data (some records may not have images attached)"></A>');
		htp.p('    </TR>');
		htp.p('    <TR>');
		htp.p('		 <TD ALIGN="RIGHT"><B>Imaging Query</FONT></B></TD>');
		htp.p('		 <TD ALIGN="LEFT"><A HREF="JavaScript:parent.QueryFrame.document.location='''||gis_image_util.c_pack_url||'gis_search.QueryContext?p_document=Pre+Index&p_navTo=&p_target=
									&p_userType='||REPLACE(p_userType,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId||'''"
									'|| gis_search.onMouseOver('Query on Global Imaging indexed images')||'>
			 						<IMG SRC="'||gis_image_util.c_image_url||'b_query.gif" BORDER="0" ALIGN="TOP" ALT="Query on Global Imaging indexed images"></A>');
		htp.p('    </TR>');
		htp.p('  </TABLE>');
		htp.p( '<SCRIPT LANGUAGE="javascript">' );
		htp.p( 'parent.ViewingFrame.document.location="gis_image_util.ViewingFrame?p_userType='|| REPLACE(p_userType,' ','+')||'"' );
		htp.p( '</SCRIPT>');
	ELSE
		htp.p(' Current user session is invalid or has expired');
	END IF;			
	gis_image_util.pageclose;
END QueryIndex;

FUNCTION viewSecureDocument( p_userId IN NUMBER, p_orgId IN NUMBER, p_context IN VARCHAR2)
RETURN BOOLEAN IS

CURSOR respCur( f_appId NUMBER, f_orgId NUMBER, f_userId NUMBER, f_optionName VARCHAR2) IS
SELECT count(optval.profile_option_value) recordExists
FROM fnd_profile_options_vl pro
, fnd_profile_option_values optval
, fnd_application ownerApp
, fnd_application userApp
, fnd_user_resp_groups usrep
WHERE pro.profile_option_name = f_optionName--'GIS_VIEW_CUST_SECURE_DOCUMENTS'
AND pro.application_id = ownerApp.application_id
AND ownerApp.application_short_name  = 'IMAGING'
AND optval.profile_option_value = 'Y'
AND optval.profile_option_id = pro.profile_option_id
AND optval.application_id =  pro.application_id
AND optval.level_id = 10003 -- 10003 responsibilty level, 10004 user level
AND optval.level_value_application_id = userApp.application_id
AND nvl(usrep.end_date,SYSDATE+1) > SYSDATE
AND usrep.responsibility_application_id = userApp.application_id
AND usrep.user_id =  f_userId -- user id
AND nvl(usrep.end_date,SYSDATE+1) > SYSDATE
AND optval.level_value = usrep.responsibility_id
AND optval.level_value IN ( SELECT responsibility_id
							    FROM fnd_responsibility_tl resp,
									fnd_profile_option_values optval,
									fnd_profile_options opt
								WHERE resp.application_id = f_appId
								AND resp.responsibility_id = optval.level_value
								AND optval.level_id = 10003
								AND optval.profile_option_id = opt.profile_option_id
								AND optval.application_id =  opt.application_id
								AND opt.profile_option_name = 'ORG_ID'
								AND optval.profile_option_value = f_orgId);

CURSOR userCur( f_userId NUMBER, f_optionName VARCHAR2) IS				
SELECT optval.profile_option_value viewSecureDoc
FROM fnd_profile_options_vl pro
, fnd_profile_option_values optval
, fnd_application app                                                                   
WHERE pro.profile_option_name = f_optionName--'GIS_VIEW_CUST_SECURE_DOCUMENTS'
AND pro.application_id = app.application_id
AND app.application_short_name  = 'IMAGING'
AND optval.profile_option_id = pro.profile_option_id
AND optval.application_id =  pro.application_id
AND optval.level_id = 10004 -- 10003 responsibilty level, 10004 user level
AND optval.level_value = f_userId; -- fnd_user_id

b_returnValue BOOLEAN := FALSE;
lv_viewSecureDoc stdVarchar;
ln_appId idNumber; 
lv_optionName stdVarchar;

FUNCTION ProfileOptionName( p_context IN VARCHAR) RETURN VARCHAR2 IS

lv_returnValue stdVarchar;

BEGIN
	IF ProfileOptionName.p_context = 'Customer'
	THEN
		lv_returnValue := 'GIS_VIEW_CUST_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Order Manageent'
	THEN
		lv_returnValue := 'GIS_VIEW_OM_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Contracts'
	THEN
		lv_returnValue := 'GIS_VIEW_OKS_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Agreements'
	THEN
		lv_returnValue := 'GIS_VIEW_AGRMT_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Suppliers'
	THEN
		lv_returnValue := 'GIS_VIEW_SUPPLIER_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Education Bookings'
	THEN
		lv_returnValue := 'GIS_VIEW_OTA_BOOKINGS_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Education Events'
	THEN
		lv_returnValue := 'GIS_VIEW_OTA_EVENTS_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'HR Assignments'
	THEN
		lv_returnValue := 'GIS_VIEW_HR_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Payables'
	THEN
		lv_returnValue := 'GIS_VIEW_PAY_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Projects'
	THEN
		lv_returnValue := 'GIS_VIEW_PROJECT_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Receivables'
	THEN
		lv_returnValue := 'GIS_VIEW_REC_SECURE_DOCUMENTS';
	ELSIF ProfileOptionName.p_context = 'Web Expenses'
	THEN
		lv_returnValue := 'GIS_VIEW_WEBEXP_SECURE_DOCUMENTS';
	ELSE
		lv_returnValue := 'Not Found';			
	END IF;	
	RETURN lv_returnValue;
END ProfileOptionName;
 
BEGIN
-- get the profile option name for the current context
	lv_optionName := ProfileOptionName( viewSecureDocument.p_context);
-- get the application id for the current context
	ln_appId := gis_image_util.applicationId( p_context);
-- get value of user set profile option
	FOR rec IN userCur( p_userId, lv_optionName)
	LOOP
		lv_viewSecureDoc := rec.viewSecureDoc;
	END LOOP;
	
-- if view secure document set at user level use it
	IF lv_viewSecureDoc = 'Y'
	THEN
		b_returnValue := TRUE;
	ELSIF lv_viewSecureDoc = 'N'
	THEN
		b_returnValue := FALSE;	
-- else check if view secure document has been set at responsibility level
	ELSE
		FOR rec IN respCur( ln_appId, p_orgId, p_userId, lv_optionName)
		LOOP
			IF rec.recordExists > 0
			THEN
				b_returnValue := TRUE;
			END IF;
		END LOOP;		
	END IF;
		
	RETURN b_returnValue;
	
END viewSecureDocument;

--
-- std set procedure for autoCommit flag
--
PROCEDURE setAutoCommit( p_value IN BOOLEAN)
IS
BEGIN
	b_autoCommit := p_value;
END setAutoCommit;        

--
-- commit function. autoCommit can be set to FALSE when running in test mode
-- to allow records to be altered without saving to the database
--
PROCEDURE AutoCommit( o_committed OUT BOOLEAN, o_mesg OUT stdVarchar)
IS
BEGIN
	IF b_autoCommit
	THEN
		COMMIT;
	ELSE
		o_committed := FALSE;
		o_mesg := 'autoCommit is currently off...';		
	END IF;

EXCEPTION
	WHEN OTHERS
	THEN
		DECLARE
			errorCode NUMBER := SQLCODE;
			errorMsg VARCHAR(300) := SQLERRM;
		BEGIN
			o_committed := FALSE;
			o_mesg := errorMsg;
		END;	 
END AutoCommit;

--
-- function used to validate currency values and turn them
-- into a number type. 0 is returned if the conversion fails
-- i.e. $1,890.99 returns 1890.99, 1.567.89 returns 0
--
FUNCTION Valid_value ( p_value VARCHAR2) RETURN NUMBER
IS

nReturnValue id32Number := 0;

BEGIN
	nReturnValue := ROUND(TO_NUMBER(REPLACE(REPLACE(p_value,','),'$')),2);
	RETURN nReturnValue;
EXCEPTION
	WHEN OTHERS 
	THEN
		RETURN nReturnValue;
END Valid_value;

--
-- js function creates a javaScript block using p_body
-- as the body of the function
-- i.e. js( ' function demo( demo){null;} 
--
FUNCTION js( p_body IN VARCHAR2) RETURN VARCHAR2 IS

v_header stdVarchar :='<SCRIPT LANGUAGE="javascript"> ';
v_footer stdVarchar:='  </SCRIPT>';
v_returnValue megaVarchar;

BEGIN                                   
	v_returnValue := v_header || p_body || v_footer;
	RETURN v_returnValue;
END js;

--
-- default error procedure. Displays ora error and GIS
-- error in a new window.
--
PROCEDURE ErrorWindow( p_errCode IN VARCHAR2 DEFAULT '-'
						, p_errMsg IN VARCHAR2 DEFAULT '-'
						, p_gisErr IN VARCHAR2 DEFAULT '-'
						, p_errorSource IN VARCHAR2 DEFAULT '-') IS

BEGIN
	gis_image_util.pageopen(p_heading => 'Error Details',p_procedure=>'gis_search.ErrorWindow');				
	gis_image_util.InfoHeader('Error Details...');
	htp.formOpen('', cmethod=>'POST', cattributes=>'NAME="ErrorDetails"');
	htp.p('  <TABLE  WIDTH="100%" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
	htp.p('		<TR>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Error Source...</B></FONT></TD>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" >'|| p_errorSource ||'</FONT></TD>');	
	htp.p('		</TR>');
	htp.p('		<TR>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>ORA Error Code...</B></FONT></TD>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" >'|| p_errCode ||'</FONT></TD>');
	htp.p('		</TR>');
	htp.p('		<TR>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>ORA Error Msg...</B></FONT></TD>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><TEXTAREA NAME="p_errMsg" ROWS="5" COLS="40" WRAP="PHYSICAL">'||p_errMsg||'</TEXTAREA></TD>');
	htp.p('		</TR>');
	htp.p('		<TR>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>GIS Error Msg...</B></FONT></TD>');
	htp.p('			<TD BGCOLOR="#C9C9C9"><TEXTAREA NAME="p_errMsg" ROWS="5" COLS="40" WRAP="PHYSICAL">'||p_gisErr||'</TEXTAREA></TD>');
	htp.p('		</TR>');
	htp.p('	 </TABLE>');	
	htp.br;		
	htp.p('  <TABLE  WIDTH="100%"  BORDER="0" CELLSPACING="0" CELLPADDING="2">
				<TR>	
					<TD ALIGN="CENTER"><A HREF="javascript:close()"'|| onMouseOver('Close Window')||'><IMG SRC="' || gis_image_util.c_image_url || 'b_ok_m.gif" BORDER="0" ALT="Close Window" ALIGN="TOP"></A></TD>
				</TR>
	         </TABLE>');
	htp.formClose;
	gis_image_util.pageclose;
END ErrorWindow;

--
-- default error procedure. opens new window to display error
--
FUNCTION showErr( p_gisErr VARCHAR2 DEFAULT NULL, p_errorSource IN VARCHAR2 DEFAULT NULL)
RETURN VARCHAR2 IS
  
v_returnValue megaVarchar;
v_url largeVarchar;
n_errorCode idNumber := SQLCODE;
v_errorMsg stdVarchar := SQLERRM;
			
BEGIN
	showErr.v_url := gis_image_util.c_pack_url||'gis_search.ErrorWindow?p_errCode=' || n_errorCode 
				|| '&p_errMsg=' || REPLACE(v_errorMsg,' ','+') || '&p_gisErr=' || REPLACE(p_gisErr,' ','+') ||'&p_errorSource=' || p_errorSource;
	showErr.v_returnValue := js('window.open("'|| showErr.v_url ||'", "ErrorWindow", "width=550,height=390,dependent=no,left=50,top=50,screenX=1,screenY=50,resizable=1,status=0,scrollbars=1")');
	RETURN showErr.v_returnValue;
END showErr;
  
PROCEDURE CountryInput( p_attrib VARCHAR2 DEFAULT '0'	
						,p_userId NUMBER DEFAULT NULL
						,p_context VARCHAR2)
IS

row_countryList cur_countryList%ROWTYPE;
row_countryListCount cur_countryListCount%ROWTYPE;
l_appId fnd_application.application_id%TYPE;
--l_respName VARCHAR2(15) := NULL;

BEGIN
--	htp.formHidden( p_context);use for debug only
	IF p_attrib != '1'
	THEN
		htp.p(' <TR><TD ALIGN="RIGHT"><FONT size=2><B>Organization</B></FONT></TD>');
	END IF;
	htp.p('<TD ALIGN="LEFT" VALIGN="CENTER"><FONT size=3>');

-- get the application id for the current context
-- this is used to check to see what org's the user has 
-- responsibility over for the selected application
 	l_appId := gis_image_util.applicationId( p_context);

	BEGIN
	-- how many organizations does the user have access to with the 
	-- the current responsibility?
		IF NOT cur_countryListCount%ISOPEN
		THEN
			OPEN cur_countryListCount( f_userId=>p_userId, f_appId=>l_appId, f_respName=>NULL);
		END IF;
		FETCH cur_countryListCount INTO row_countryListCount;
		IF row_countryListCount.orgCount < 1
		THEN
		-- error message for users who have been set up with the imaging responsibility
		-- but do not have an applications account setup correctly i.e. the MO: profile option
		-- value has not been set.                                                              
--			htp.p( '<SCRIPT LANGUAGE="javascript">' );
			htp.p(js( 'alert("You do not have an organization specific application responsibility for this context.... Please contact your system administrator")' ));
--			htp.p( '</SCRIPT>');
		ELSIF row_countryListCount.orgCount > 1
		THEN
		-- user has access to more than one organization
		-- so a select box needs to be displayed	
			htp.formSelectOpen(cname=>'p_org',nsize=>'1');	
			IF NOT cur_countryList%ISOPEN
			THEN
				OPEN cur_countryList( f_userId=>p_userId, f_appId=>l_appId, f_respName=>NULL);
			END IF;
			FETCH cur_countryList INTO row_countryList;
			IF p_attrib != 'no_all_option'
			THEN
				htp.formSelectOption( 'All', 'SELECTED',CATTRIBUTES=>'value="1"');
			END IF;
			WHILE cur_countryList%FOUND
			LOOP	
				htp.formSelectOption( substr(row_countryList.name,1,25), CATTRIBUTES=>'value="'||	
														row_countryList.organization_id||'"');
				FETCH cur_countryList INTO row_countryList;
			END LOOP;
			htp.formSelectClose; 
			htp.FormHidden('p_orgCount', '2');
		ELSE
			IF NOT cur_countryList%ISOPEN
			THEN
				OPEN cur_countryList( f_userId=>p_userId, f_appId=>l_appId, f_respName=>NULL);
			END IF;
			FETCH cur_countryList INTO row_countryList;
			htp.formText(cname=>'p_orgName',cvalue=>substr(row_countryList.name,1,25));	
			htp.formHidden('p_org', row_countryList.organization_id);   
			htp.FormHidden('p_orgCount', '1');
		END IF; 
		htp.p('	  </FONT></TD>');
		IF p_attrib IS NULL
		THEN
			htp.p(' </TR>');
		END IF;	
		CLOSE cur_countryList;
	    CLOSE cur_countryListCount;
	EXCEPTION
		WHEN OTHERS
		THEN
			htp.p(showErr('ERROR....You do not have an organization specific application responsibility for this context.... Please contact your system administrator'));
--			htp.p( 'ERROR....You do not have an organization specific application responsibility for this context.... Please contact your system administrator' );	
			htp.p('	  </TD>');
			IF p_attrib IS NULL
			THEN
				htp.p(' </TR>');
			END IF;
	END;		
END CountryInput;

 
---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE QueryContext( p_document VARCHAR2
						, p_navTo VARCHAR DEFAULT NULL
						, p_target VARCHAR2 DEFAULT NULL
						, p_userType VARCHAR2 DEFAULT NULL
						, p_userId VARCHAR2 DEFAULT NULL
						, p_respId VARCHAR2 DEFAULT NULL) IS

row_docContext cur_docContext%ROWTYPE;
l_document VARCHAR2(25) := REPLACE( p_document,' ','+');
l_navTo VARCHAR2(100) := nvl(p_navTo,'gis_search.QueryOptions');
l_target VARCHAR2(25);

BEGIN
	gis_image_util.pageopen(p_heading => 'Document Search',p_procedure=>'gis_search.QueryContext');
	gis_image_util.InfoHeader( 'Select '|| p_document || ' Document Context');
    
	htp.p( '<SCRIPT LANGUAGE="javascript">' );
	htp.p( 'parent.ViewingFrame.document.location="gis_image_util.ViewingFrame?p_userType='|| REPLACE(p_userType,' ','+')||'"' );
	IF l_navTo = 'gis_search.QueryOptions'
	THEN
	    htp.p( 'parent.SelectFrame.document.location="gis_image_util.BlankFrame"' );
	ELSE
	    htp.p( 'parent.SelectFrame.document.location="gis_process_image.refreshInterval"' );	
	END IF;
	htp.p( '</SCRIPT>');

	htp.formOpen(l_navTo, 'POST',ctarget=>p_target,cattributes=>'NAME="QueryOptions"');

	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('		<TR>');
	htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="'||gis_image_util.c_image_url||'empty.gif"></TD>');
	htp.p('      <TD WIDTH="98%" ALIGN="CENTER" VALIGN="MIDDLE">');
	htp.formHidden('p_refresh_rate',null);
	htp.formHidden( 'p_document', p_document);
	htp.formHidden( 'p_userId', p_userId);
	htp.formHidden( 'p_userType', p_userType);
	htp.formHidden( 'p_userResp', p_respId);
	IF NOT cur_docContext%ISOPEN
	THEN
		OPEN cur_docContext( p_userId);
	END IF;

	htp.formSelectOpen(cname=>'p_context',nsize=>'15');		
	FETCH cur_docContext INTO row_docContext;
	IF cur_docContext%NOTFOUND THEN
		htp.formSelectOption('ERROR','SELECTED',cattributes=>'VALUE="0"' );
		-- put some sort of error message in here   
		htp.p(js('alert("Error. You do not have required applications access.... Please contact your system administrator")' ));
	ELSE		
-- Modified by Patrick Low: 26/03/2001
-- ISIS 1211020: Commented out - first record is already FETCHed.
--               FETCH at end of loop will get next record.
--               Failure will be raised at top of loop
--		FETCH cur_docContext INTO row_docContext;
		WHILE cur_docContext%FOUND
		LOOP	
			IF p_document = 'Indexed'
			THEN
				IF gis_apps_search.IndexedSearchAvail(row_docContext.descriptive_flex_context_code)
				THEN
					htp.formSelectOption( row_docContext.description, CATTRIBUTES=>'value='||	
														replace(row_docContext.descriptive_flex_context_code,' ','+'));
-- option to see old renewal documents if the user has access to contracts
					IF row_docContext.descriptive_flex_context_code = 'Contracts'
					THEN
						htp.formSelectOption( 'Old Renewals', CATTRIBUTES=>'value='||'Old+Renewals');
					END IF;					
				END IF;
			ELSE
					htp.formSelectOption( row_docContext.description, CATTRIBUTES=>'value='||	
														replace(row_docContext.descriptive_flex_context_code,' ','+'));
			END IF;					
			FETCH cur_docContext INTO row_docContext;
		END LOOP;
	END IF;
	CLOSE cur_docContext;
	htp.formSelectClose;
	
	htp.p('</TD>');
	htp.p('      <TD WIDTH="1%"  ALIGN="CENTER" VALIGN="MIDDLE"><IMG SRC="'||gis_image_util.c_image_url||'empty.gif"></TD>');
	htp.p('    </TR>');
	htp.p('</TABLE>');
	htp.br;
	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('    <TR>');
	IF l_navTo = 'gis_search.QueryOptions'
	THEN
		htp.p('      <TD ALIGN="RIGHT">');
		htp.p('<A HREF="'||gis_image_util.c_pack_url||'gis_search.QueryIndex?p_document='||REPLACE(p_document,' ','+')||
										'&p_userType='||REPLACE(p_userType,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId||'" onMouseOver="window.status=''Back''; ');
		htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_l.gif" ');
		htp.p('				BORDER="0" ALT="Next" ALIGN="TOP"></A></TD>');
		htp.p('		 <TD ALIGN="LEFT"><A HREF="javascript:setProcessRefresh( '''||p_navTo||''','''||REPLACE(p_userType,' ','+')||''','||p_userId||','||p_respId||')" onMouseOver="window.status=''Next''; return true"');
		htp.p('				onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_next_r.gif" ');
		htp.p('				BORDER="0" ALT="Next" ALIGN="TOP"></A></TD>');
	ELSE	
		htp.p('		 <TD ALIGN="CENTER"><A HREF="javascript:setProcessRefresh( '''||p_navTo||''','''||REPLACE(p_userType,' ','+')||''','||p_userId||','||p_respId||')" onMouseOver="window.status=''Next''; return true"');
		htp.p('				onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_next.gif" ');
		htp.p('				BORDER="0" ALT="Next" ALIGN="TOP"></A></TD>');
	END IF;
	htp.p('    </TR>');
	htp.p('  </TABLE>');

	htp.formclose;
	gis_image_util.pageclose;
END QueryContext;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE DocStatusInput IS

CURSOR cur_docStatus IS
SELECT
doc_status_name
,doc_status_type_id
FROM
gis_doc_status_types
ORDER BY doc_status_type_id;

row_docStatus cur_docStatus%ROWTYPE;

BEGIN
	htp.p(' <TR><TD>');
	htp.hr;
	htp.p(' </TD><TD>');
	htp.hr;
	htp.p('</TD></TR>');
	htp.p(' <TR><TD ALIGN="RIGHT"><FONT size=2><B>Doc Status</B></FONT></TD><TD><FONT size=2>');
	htp.formSelectOpen(cname=>'p_doc_attribute6',nsize=>'1');	
	IF NOT cur_docStatus%ISOPEN
	THEN
		OPEN cur_docStatus;
	END IF;
	
	FETCH cur_docStatus INTO row_docStatus;
	IF cur_docStatus%NOTFOUND THEN
		htp.formSelectOption('ERROR','SELECTED',cattributes=>'VALUE="0"' );
		-- put some sort of error message in here
		htp.p(js( 'alert("Error. Document status types have not been defined.... Please contact your system administrator' ));
	ELSE
		htp.formSelectOption( 'All', 'SELECTED',CATTRIBUTES=>'value=1');
		WHILE cur_docStatus%FOUND
		LOOP	
			IF row_docStatus.doc_status_name != 'SCANNED'
			THEN
				htp.formSelectOption( row_docStatus.doc_status_name, CATTRIBUTES=>'value='||	
													row_docStatus.doc_status_type_id);
			END IF;
			FETCH cur_docStatus INTO row_docStatus;
		END LOOP;
	END IF;
	CLOSE cur_docStatus;
	htp.formSelectClose;
	htp.p('	  </TD></TR>');
END DocStatusInput;



---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE QueryOptionButtons (	p_document IN VARCHAR2
								,p_userId VARCHAR2 DEFAULT NULL	
								,p_userType VARCHAR2 DEFAULT NULL
								,p_respId VARCHAR2) IS
								
l_userType VARCHAR2(25) := 'Inquiry User';

BEGIN
	htp.line;
	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('    <TR>');

-- Amended by PL: 23/10/2000
-- Added reset option button to clear fields and moved report and export to seperate row
	htp.p('      <TD ALIGN="CENTER" VALIGN="MIDDLE">');
	htp.p('<A HREF="'||gis_image_util.c_pack_url||'gis_search.QueryContext?p_document='||p_document||
										'&p_userType='||REPLACE(l_userType,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId||'" onMouseOver="window.status=''Back''; ');
	htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_l.gif" ');
	htp.p('		BORDER="0" ALT="Back" ALIGN="TOP"></A>');
	htp.p('<A HREF="javascript:document.QueryOptions.reset()" onMouseOver="window.status=''Reset Fields''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_reset_m.gif" BORDER="0" ');
	htp.p('		ALT="Reset Fields" ALIGN="TOP"></A>');
	htp.p('<A HREF="javascript:if(isValid()){searchmenu(4,'''||p_document||''')}" onMouseOver="window.status=''Search''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_search_r.gif" BORDER="0" ');
	htp.p('		ALIGN="TOP" ALT="Search"></A>');	
	htp.p('		</TD>');
	htp.p('    </TR>');
	htp.p('      <TD ALIGN="CENTER" VALIGN="MIDDLE">');
	htp.p('<A HREF="javascript:if(isValid()){searchmenu(2,'''||p_document||''')}" onMouseOver="window.status=''Report''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_report_l.gif" BORDER="0" ');
	htp.p('		ALT="Report" ALIGN="TOP"></A>');
	htp.p('<A HREF="javascript:if(isValid()){searchmenu(3,'''||p_document||''')}" onMouseOver="window.status=''Export to Excel''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_xlsexp_r.gif" BORDER="0" ');
	htp.p('		ALT="Export" ALIGN="TOP"></A>');
	htp.p('		</TD>');
	htp.p('    </TR>');
	htp.p('  </TABLE>');
END QueryOptionButtons;

/*PROCEDURE indexedQueryOptions(	p_document VARCHAR2 DEFAULT NULL
								, p_context VARCHAR2 DEFAULT NULL
								,p_userId VARCHAR2 DEFAULT NULL
								,p_userType VARCHAR2 DEFAULT NULL
								,p_respId VARCHAR2) IS

l_document VARCHAR2(25) := REPLACE( p_document,' ','+');
l_context VARCHAR2(50) := replace(p_context,'+',' ');
x_context VARCHAR2(50);
y_context VARCHAR2(50):= replace(p_context,' ','_');  
l_searchOption NUMBER(1); 
v_viewFrame VARCHAR2(50);
								
BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'indexedQueryOptions');				
	gis_image_util.InfoHeader( l_context || ' - Query');
	IF l_context = 'Old Renewals'
	THEN
		x_context := 'Contracts';
		v_viewFrame := 'SelectFrame';
	ELSE
		x_context := l_context;
		v_viewFrame := 'ViewingFrame';
	END IF;

	htp.formOpen('gis_search.'||y_context|| 'IQActions', cmethod=>'POST',ctarget=>v_viewFrame, cattributes=>'NAME="indexedQueryOptions"');
	htp.formHidden( 'p_userId', p_userId);
	htp.formHidden( 'p_userType', p_userType);
	htp.formHidden( 'p_respId', p_respId);
	htp.formHidden( 'p_context', l_context);
    htp.formHidden( 'imageDisplayed', 'No');
    
	htp.p('  <TABLE WIDTH="95%" BORDER="0" ALIGN="CENTER" CELLSPACING="0" CELLPADDING="2">');
	-- display valid orgs to select from
	CountryInput( p_attrib=>'no_all_option',p_userId=>p_userId, p_context=>x_context);
				
	IF l_context = 'Agreements'
	THEN
		htp.p('Query Action not yet defined for selected context');	
	ELSIF l_context = 'Contracts'
	THEN
		gis_apps_search.ContractsQuery( p_userId, p_userType, p_respId);  
		l_searchOption := 6;
	ELSIF l_context = 'Old Renewals'
	THEN
		gis_apps_search.OldRenewalsQuery( p_userId, p_userType, p_respId);  
		l_searchOption := 7;
	ELSIF l_context = 'Order Management'
	THEN
		gis_apps_search.OrderHeadersQuery( p_userId, p_userType, p_respId);
		l_searchOption := 5;
	ELSIF l_context = 'Payables'
	THEN
		htp.p('Query Action not yet defined for selected context');	
	ELSIF l_context = 'Customer'
	THEN
		gis_apps_search.raCustomerQuery( p_userId, p_userType, p_respId);
		l_searchOption := 8;	
	ELSIF l_context = 'Projects'
	THEN
		htp.p('Query Action not yet defined for selected context');	
	ELSE
		htp.p('Query Action not yet defined for selected context');
	END IF;
	htp.p('	</TABLE>');		
	
	htp.line;
	htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
	htp.p('    <TR>');
	htp.p('      <TD ALIGN="CENTER" VALIGN="MIDDLE">');
	htp.p('<A HREF="'||gis_image_util.c_pack_url||'gis_search.QueryContext?p_document='||p_document||
										'&p_userType='||REPLACE(p_userType,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId||'" onMouseOver="window.status=''Back''; ');
	htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_l.gif" ');
	htp.p('		BORDER="0" ALT="Back" ALIGN="TOP"></A>');
	htp.p('<A HREF="javascript:document.indexedQueryOptions.reset()" onMouseOver="window.status=''Reset Fields''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_reset_m.gif" BORDER="0" ');
	htp.p('		ALT="Reset Fields" ALIGN="TOP"></A>');
	htp.p('<A HREF="javascript:if (isValid()){ parent.SelectFrame.location = '''||gis_image_util.c_pack_url||
			'gis_image_util.BlankFrame'' ;searchmenu('||l_searchOption||','''||p_document||''')}" onMouseOver="window.status=''Search''; return true" ');
	htp.p('		onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_search_r.gif" BORDER="0" ');
	htp.p('		ALIGN="TOP" ALT="Search"></A>');	
	htp.p('		</TD>');
	htp.p('    </TR>');
	htp.p('  </TABLE>');
	htp.formClose;
	gis_image_util.pageclose;
END indexedQueryOptions;*/

PROCEDURE CustNameLov( 	p_org VARCHAR2
						,p_custName	VARCHAR2 DEFAULT NULL) IS

CURSOR cur_custName(f_custName VARCHAR2) IS
SELECT customer_name
,customer_number
FROM ra_customers
WHERE upper(customer_name) LIKE f_custName
--AND party_type = 'ORGANIZATION'
ORDER BY customer_name;

row_custName cur_custName%ROWTYPE;
l_custName stdVarchar;

BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'CustNameLov');				
	gis_image_util.InfoHeader('Confirm Customer Name...');
	htp.formOpen('', cmethod=>'POST', cattributes=>'NAME="customerLov"');
	htp.br;
	IF INSTR( p_custName,'%') > 0 
	THEN
		htp.p('No wild card searches allowed....');
	ELSE
		IF LENGTH(p_custName) <= 3 OR p_custName IS NULL
		THEN  
			htp.p('You must specify at least the first four letters to search....');
		ELSE		
			l_custName := UPPER(RTRIM( REPLACE(p_custName,'~','&'))) || '%';
			IF NOT cur_custName%ISOPEN
			THEN
				OPEN cur_custName(l_custName);
			END IF;
			
			FETCH cur_custName INTO row_custName;
			IF cur_custName%NOTFOUND THEN
				htp.p(js( 'alert("No customer name matches found....Please try again' ));
			ELSE
				htp.p('  <TABLE WIDTH="95%" BORDER="1" ALIGN="CENTER" CELLSPACING="0" CELLPADDING="2">');
				htp.p('	<TR>
							<TD><B>Customer Name</B></TD><TD><B>Customer Number</B></TD><TD><IMG SRC="'||gis_image_util.c_image_url||'empty.gif"></TD>
						</TR>');
				WHILE cur_custName%FOUND
				LOOP
					htp.p('	<TR>
								<TD>'||row_custName.customer_name||'</TD><TD>'||row_custName.customer_number||'</TD>
								<TD><A HREF="JavaScript:opener.document.indexedQueryOptions.p_soldTo.value = '''||row_custName.customer_name||''';
														opener.document.indexedQueryOptions.p_customerNumber.value = '''||row_custName.customer_number||''';
														close();" onMouseOver="window.status=''Correct''; return true"
									onMouseOut="window.status=''''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_ok.gif" BORDER="0" ALT="Correct" ALIGN="TOP"></A></TD>
							</TR>');				
					FETCH cur_custName INTO row_custName;
				END LOOP;
				htp.p('</TABLE');
			END IF;
			CLOSE cur_custName;
		END IF;
	END IF;
	htp.br;
	htp.p('<TABLE WIDTH="95%" BORDER="0" CELLSPACING="0" CELLPADDING="1">
  				<TR>
    				<TD ALIGN="CENTER"><A HREF="javascript:close()" onMouseOver="window.status=''Incorrect''; return true" onMouseOut="window.status=''''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_cancel_m.gif" BORDER="0" ALT="Incorrect" ALIGN="TOP"></A></TD>
  				</TR>
			</TABLE>');
		
--	htp.p(p_custName);
--	htp.p(p_org);
	gis_image_util.pageclose;
END CustNameLov;



FUNCTION validURLstring( stringIn VARCHAR DEFAULT '-') RETURN VARCHAR2
IS

v_localString VARCHAR2(255);

BEGIN
	v_localString := replace( stringIn,' ','+');
	v_localString := replace( v_localString,'''','~');
	v_localString := replace( v_localString,'#','^');
	RETURN 	v_localString;
END validURLstring;



--
-- onMouseOver functions add p_mesg to the window status line
-- when mouse moved over the selected window object and clears
-- the mesg when mouse is moved away
-- i.e. called by onMouseOver('View Attachments for Order # '||l_orderNumber)
--
FUNCTION onMouseOver( p_mesg VARCHAR2) RETURN VARCHAR2 IS

v_returnString VARCHAR2(200);

BEGIN
	v_returnString := 'onMouseOver="window.status='''||p_mesg||'''; return true" 
						onMouseOut="window.status='''';	return true"';
	RETURN v_returnString;
END onMouseOver;
			
FUNCTION secureDocument( p_secure IN stdVarchar)
RETURN VARCHAR2 IS
           
v_returnValue minVarchar;

BEGIN  
	IF p_secure = 'SECURE'
	THEN
		v_returnValue := 'Yes';
	ELSE
		v_returnValue := 'No';
	END IF;
	RETURN v_returnValue;
END secureDocument;
	
---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE ScanIndexInput( p_queryColumns gis_search.stringArray) IS

BEGIN
-- javaScript code that checks that entered dates are in a valid format
-- i.e. dd-mmm-yyyy or dd/mmm/yyyy. Calls validation functions contained in the 
-- core_functions.js file
	htp.p('
		<SCRIPT language="javaScript">
		<!--BEGIN Script
		
		function isValid()
		{
			var lDate;
			var valid = true;
 			if(document.QueryOptions.p_scanned_date_from.value !="")
 			{
  				lDate = document.QueryOptions.p_scanned_date_from.value;
  				if(checkDate( lDate)) valid =  true;
  				else
  				{
  					alert( "Date format " + lDate + " is incorrect.....Query canceled. The correct format is DD-MON-YYYY or DD/MON/YYYY" );
  					valid = false;
  				} 
  			}
			if(document.QueryOptions.p_scanned_date_to.value !="")
 			{
  				lDate = document.QueryOptions.p_scanned_date_to.value;
  				if(checkDate( lDate)) valid =  true;
   				else
  				{
  					alert( "Date format " + lDate + " is incorrect.....Query canceled. The correct format is DD-MON-YYYY or DD/MON/YYYY" );
  					valid = false;
  				} 
  			}
			if(document.QueryOptions.p_indexed_date_from.value !="")
 			{
  				lDate = document.QueryOptions.p_indexed_date_from.value;
  				if(checkDate( lDate)) valid =  true;
  				else
  				{
  					alert( "Date format " + lDate + " is incorrect.....Query canceled. The correct format is DD-MON-YYYY or DD/MON/YYYY" );
  					valid = false;
  				} 
  			}
			if(document.QueryOptions.p_indexed_date_to.value !="")
 			{
  				lDate = document.QueryOptions.p_indexed_date_to.value;
  				if(checkDate( lDate)) valid =  true;
  				else
  				{
  					alert( "Date format " + lDate + " is incorrect.....Query canceled. The correct format is DD-MON-YYYY or DD/MON/YYYY" );
  					valid = false;
  				} 
  			}
  			return valid;
		}
		//-->
		</SCRIPT>');
		
	htp.p('		 <TR>');
	htp.p('          <TD></TD>');
	htp.p('          <TD><FONT size=2><B>From.... &nbsp&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp
								&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp&nbsp To....</FONT></B></TD>');
	htp.p('		 </TR>'); 
	htp.p('      <TR><TD  ALIGN="RIGHT" VALIGN="LEFT"><FONT size=2><B>Scanned</B></FONT></TD>');
	htp.p('          <TD><FONT size=2><INPUT NAME="p_scanned_date_from" COLS=11  size="12" maxlength="11"><A HREF="#" 
					onClick="window.dateField = document.QueryOptions.p_scanned_date_from;calendar = 
					window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=200,HEIGHT=250,RESIZABLE=0'')"><IMG SRC="' || 
					gis_image_util.c_image_url || 'b_cal.gif" BORDER="0" ALT="Calendar" ALIGN="TOP"></A>');
	htp.p('		     <INPUT NAME="p_scanned_date_to" COLS=11 size="12"  maxlength="11"><A HREF="#" 
					onClick="window.dateField = document.QueryOptions.p_scanned_date_to;calendar = 
					window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=200,HEIGHT=250,RESIZABLE=0'')"><IMG SRC="' || 
					gis_image_util.c_image_url || 'b_cal.gif" BORDER="0" ALT="Calendar" ALIGN="TOP"></A></FONT></TD>');
	htp.p('		 </TR>');	
	htp.p('      <TR><TD  ALIGN="RIGHT" VALIGN="LEFT"><FONT size=2><B>Indexed</B></FONT></TD>');
	htp.p('          <TD><FONT size=2><INPUT NAME="p_indexed_date_from" COLS=11  size="12" maxlength="11"><A HREF="#" 
					onClick="window.dateField = document.QueryOptions.p_indexed_date_from;calendar = 
					window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=200,HEIGHT=250,RESIZABLE=0'')"><IMG SRC="' || 
					gis_image_util.c_image_url || 'b_cal.gif" BORDER="0" ALT="Calendar" ALIGN="TOP"></A>');
	htp.p('		     <INPUT NAME="p_indexed_date_to" COLS=11 size="12"  maxlength="11"></FONT><A HREF="#" 
					onClick="window.dateField = document.QueryOptions.p_indexed_date_to;calendar = 
					window.open(''gis_image_util.show_calendar'',''cal'',''WIDTH=200,HEIGHT=250,RESIZABLE=0'')"><IMG SRC="' || 
					gis_image_util.c_image_url || 'b_cal.gif" BORDER="0" ALT="Calendar" ALIGN="TOP"></A></TD>');
	htp.p('		 </TR>');
 	htp.p('      <TR><TD  ALIGN="RIGHT"><FONT size=2><B>Order By</B></FONT></TD>');
-- show order by lov
	htp.p(' <TD><FONT size=2>');
	htp.formSelectOpen(cname=>'p_orderBy',nsize=>'1');
	htp.formSelectOption( 'None', 'SELECTED',CATTRIBUTES=>'value="None"');	
    FOR i IN 1..p_queryColumns.last
	LOOP
		htp.formSelectOption( substr(p_queryColumns(i),1,18), 'SELECTED',CATTRIBUTES=>'value="'||p_queryColumns(i)||'"');
	END LOOP;
	htp.formSelectOption( 'Scan Date',CATTRIBUTES=>'value="Scan Date"');
	htp.formSelectOption( 'Index Date',CATTRIBUTES=>'value="Index Date"');
	htp.formSelectClose;
	htp.p(' <B>Dir</B>');
	htp.formSelectOpen(cname=>'p_dir',nsize=>'1');
	htp.formSelectOption( 'Asc', 'SELECTED',CATTRIBUTES=>'value="Asc"');
	htp.formSelectOption( 'Desc', 'SELECTED',CATTRIBUTES=>'value="Desc"');
	htp.formSelectClose;
	htp.p('</FONT></TD>');
	htp.p(' </TR>');	
END ScanIndexInput;
							 		  
---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE QueryOptions( p_document VARCHAR2 DEFAULT NULL
						, p_context VARCHAR2 DEFAULT NULL
						,p_userId VARCHAR2 DEFAULT NULL
						,p_userType VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2) IS

row_columns cur_columns%ROWTYPE;
l_queryColumns stringArray := stringArray(); 
l_document VARCHAR2(25) := REPLACE( p_document,' ','+');
l_context VARCHAR2(50) := replace(p_context,'+',' ');
l_check BOOLEAN;
i NUMBER(5) := 1;

BEGIN
	gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'QueryOptions');				
	gis_image_util.InfoHeader( l_context || ' - Query');
	htp.p('<FORM NAME = "QueryOptions" onSubmit = "return isValid(this)" METHOD=POST ACTION="gis_search.QueryActions" TARGET="ViewingFrame">');
--	htp.formOpen('gis_search.QueryActions', cmethod=>'POST',ctarget=>'ViewingFrame', cattributes=>'NAME="QueryOptions"');
	htp.p('  <TABLE WIDTH="100%" BORDER="0" ALIGN="CENTER" CELLSPACING="0" CELLPADDING="2">');

	htp.formHidden( 'p_context', l_context);
	htp.formHidden( 'p_menuOption','1');
	htp.formHidden( 'p_userId', p_userId);
	htp.formHidden( 'p_userType',p_userType);
	htp.formHidden( 'p_respId',p_respId);			
	IF NOT cur_columns%ISOPEN
	THEN
		OPEN cur_columns(l_context);
	END IF;
	
	FETCH cur_columns INTO row_columns;
	IF cur_columns%NOTFOUND THEN
		-- need some sort of error handler here
		NULL;
	ELSE
		-- document description is standard
		htp.p('    <TR>');
		htp.p('      <TD WIDTH="60%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
		htp.p('			<FONT size=2><B>Description</B></FONT></DIV></TD>');
		htp.p('      <TD WIDTH="40%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
		htp.p('			<INPUT NAME="p_description" COLS=15 TYPE=TEXT size="30" maxlength="50">');
		htp.p('				<FONT size=2></TD>');
		htp.p('    </TR>');
		l_queryColumns.EXTEND;
		l_queryColumns(i) := 'Description';
		i := i+1;			
		WHILE cur_columns%FOUND
		LOOP
			htp.p('    <TR>');		
-- exception block to catch an error caused by users who do not have the required applications
-- responsibility
			BEGIN
				IF NOT gis_custom.custom_display_option(p_userId,row_columns.end_user_column_name,l_context, row_columns.application_column_name)
				THEN
					htp.p('      <TD WIDTH="60%"  ALIGN="RIGHT" VALIGN="LEFT"><DIV CLASS="inputtext" ID = "text">');
					htp.p('				<FONT size=2><B>'||row_columns.end_user_column_name||'</B></FONT></DIV></TD>');
					htp.p('      <TD WIDTH="40%" ALIGN="LEFT" VALIGN="RIGHT"><FONT size=2>');
					htp.p('			<INPUT NAME="p_'||REPLACE( row_columns.application_column_name,' ','_')||'" COLS=15 TYPE=TEXT size="25" maxlength="50">');
					htp.p('				<FONT size=2></TD>');
					-- this array is passed to the scan dates and order procedure
					-- so that the order by columns reflect the context
					l_queryColumns.EXTEND;
					l_queryColumns(i) := row_columns.end_user_column_name;
					i := i+1;
				ELSE
					l_queryColumns.EXTEND;
					l_queryColumns(i) := row_columns.end_user_column_name;
					i := i+1;
				END IF;
			EXCEPTION
			WHEN OTHERS
			THEN
		-- this is set to null as the country list procedure will show the required error message
				NULL;
			END;
			htp.p('    </TR>');			
			FETCH cur_columns INTO row_columns;
		END LOOP;
	END IF;
	CLOSE cur_columns;
--	htp.formSelectClose;
-- output standard query options
--

-- document category
   l_check := gis_custom.custom_display_option( p_userId,'Doc Type', p_context,'doc_category');
   l_queryColumns.EXTEND;
   l_queryColumns(i) := 'Doc Type';
   i := i+1;
-- document status input
	DocStatusInput;
   l_queryColumns.EXTEND;
   l_queryColumns(i) := 'Doc Status';
   i := i+1;
   	
-- country input
	CountryInput( p_userId=>p_userId,p_context=>p_context);
   l_queryColumns.EXTEND;
   l_queryColumns(i) := 'Organization';
   i := i+1;
   	
-- scan, index dates, and order by lov
	ScanIndexInput( l_queryColumns);
   l_queryColumns.EXTEND;
   l_queryColumns(i) := 'Scan Date';
   i := i+1;
   l_queryColumns.EXTEND;
   l_queryColumns(i) := 'Index Date';
--
-- going to leave the process date off the order by option at the moment as it causes an
-- extra overhead on the final query
--
--   i := i+1;
--   l_queryColumns.EXTEND;
--   l_queryColumns(i) := 'Process Date';  
	htp.p('	  </FONT></TD>');
	htp.p('  </TR>');
	htp.p('</TABLE>');

-- buttons at bottom of page
    QueryOptionbuttons( l_document, p_userId, p_userType, p_respId);

	htp.formclose;	
	gis_image_util.pageclose;

END QueryOptions;

FUNCTION PreIndexDate( p_document_id NUMBER)
RETURN gis_doc_status_record IS

l_rec gis_doc_status_record;

BEGIN
BEGIN
	SELECT 
	sta.last_update_date
	,usr.user_name
	INTO 
	l_rec.date_created
	,l_rec.created_by
	FROM
	fnd_user usr
	,gis_doc_status sta
	,gis_doc_status_types code
	WHERE sta.document_id = p_document_id
	AND sta.doc_status_type_id = code.doc_status_type_id
	AND code.doc_status_name = 'PRE-INDEXED'
	AND sta.created_by = usr.user_id;
EXCEPTION
	WHEN OTHERS
	THEN
		BEGIN 
		SELECT 
		sta.last_update_date
		,usr.user_name
		INTO 
		l_rec.date_created
		,l_rec.created_by
		FROM
		fnd_user usr
		,gis_doc_status sta
		,gis_doc_status_types code
		WHERE sta.document_id = p_document_id
		AND sta.doc_status_type_id = code.doc_status_type_id
		AND code.doc_status_name = 'PENDING'
		AND sta.created_by = usr.user_id;
EXCEPTION
	WHEN OTHERS
	THEN
		l_rec.date_processed := NULL;
		l_rec.processed_by	:= NULL;
END;		 
END;		 

BEGIN    
	SELECT 
	sta.last_update_date
	,usr.user_name
	INTO 
	l_rec.date_processed
	,l_rec.processed_by
	FROM
	fnd_user usr
	,gis_doc_status sta
	,gis_doc_status_types code
	WHERE sta.document_id = p_document_id
	AND sta.doc_status_type_id = code.doc_status_type_id
	AND code.doc_status_name = 'PROCESSED'
	AND sta.created_by = usr.user_id;
EXCEPTION
	WHEN OTHERS
	THEN
		l_rec.date_processed := NULL;
		l_rec.processed_by	:= NULL;
END;		 
	RETURN l_rec;	
END PreIndexDate;

FUNCTION getOrgList( p_userId NUMBER, p_context VARCHAR2)
RETURN org_array IS

row_countryList cur_countryList%ROWTYPE;
l_orgList  org_array:= org_array();
l_count NUMBER := 1;
l_appId NUMBER(15);

BEGIN
 	l_appId := gis_image_util.applicationId( p_context);
	IF NOT cur_countryList%ISOPEN
	THEN
		OPEN cur_countryList( f_userId=>p_userId, f_appId=>l_appId);
	END IF;
	
	FETCH cur_countryList INTO row_countryList;
	IF cur_countryList%NOTFOUND THEN
		NULL;
		-- put some sort of error message in here
	ELSE
		WHILE cur_countryList%FOUND
		LOOP	
			l_orgList.EXTEND;
			l_orgList( l_count) := row_countryList.organization_id;
			l_count := l_count + 1;			
			FETCH cur_countryList INTO row_countryList;
		END LOOP;
	END IF;
	CLOSE cur_countryList;
	RETURN l_orgList;
END getOrgList;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE QueryActions( p_context VARCHAR2 DEFAULT NULL,
						p_menuOption VARCHAR2 DEFAULT NULL,
						p_description VARCHAR2 DEFAULT NULL, 
						p_doc_attribute1 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute2 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute3 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute3_OP VARCHAR2 DEFAULT NULL,
					    p_doc_attribute4 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute4_OP VARCHAR2 DEFAULT NULL,
					    p_doc_attribute5 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute6 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute7 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute8 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute9 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute10 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute11 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute12 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute13 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute14 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute15 VARCHAR2 DEFAULT NULL,
					    p_Doc_Category NUMBER DEFAULT NULL,
					    p_org VARCHAR2 DEFAULT NULL ,
					    p_scanned_date_from VARCHAR2 DEFAULT NULL,
					    p_scanned_date_to VARCHAR2 DEFAULT NULL,
					    p_indexed_date_from VARCHAR2 DEFAULT NULL,
					    p_indexed_date_to VARCHAR2 DEFAULT NULL,
					    p_userId NUMBER DEFAULT NULL,
					    p_userType VARCHAR2 DEFAULT NULL,
					    p_respId VARCHAR2 DEFAULT NULL,
					    p_orgName VARCHAR2 DEFAULT NULL,
					    p_orderBy VARCHAR2 DEFAULT NULL,
					    p_dir VARCHAR2 DEFAULT NULL,
					    p_orgCount VARCHAR2 DEFAULT NULL ) IS
					    
row_columns cur_columns%ROWTYPE;

cid INTEGER;
sqlSourceColumns largeVarchar;
sqlSourceFrom largeVarchar;
sqlSourceWhere largeVarchar;
sqlOrderBy stdVarchar;
sqlSource largeVarchar;
rowCount INTEGER;

l_col_id idNumber;
l_com_id idNumber;
l_col_doc_id idNumber;
l_url largeVarchar;
l_col_count idNumber := 5;
l_context stdVarchar := REPLACE( p_context,' ','+');
l_rec gis_doc_status_record;  
l_hrefColor stdVarchar;
l_secureFlag stdVarchar;
ln_orgId idNumber; 
 
TYPE column_array IS VARRAY(15) OF stdVarchar;
arr_columns column_array:= column_array();
l_orgList  org_array:= org_array();

BEGIN
	sqlSourceColumns := 'SELECT '||
				  		'doc.description ' ||
				  		',hr.name '||
				  		',cat.user_name Doc_Category ';

-- get the required columns for the correct context
-- and feed into the select statement
	IF NOT cur_columns%ISOPEN
	THEN
		OPEN cur_columns(p_context);
	END IF;
	
	FETCH cur_columns INTO row_columns;
	IF cur_columns%NOTFOUND THEN
		-- need some sort of error handler here
		NULL;
	ELSE
		WHILE cur_columns%FOUND
		LOOP
 			sqlSourceColumns:= sqlSourceColumns ||', '|| 'dfv.' || REPLACE(row_columns.end_user_column_name,' ','_') || ' ';	
 			l_col_count := l_col_count + 1;
 			FETCH cur_columns INTO row_columns;
 		END LOOP;
 	END IF;
 	CLOSE cur_columns;	

	sqlSourceColumns := sqlSourceColumns ||',doc.doc_attribute6 '||             -- index_status (global)
								',doc.creation_date '||
				 				--',usr.user_name '||
				 				',lob.file_id '||  
				 				',doc.doc_attribute5 '||    -- comments_id (global)
				 				',doc.document_id '||
				 				',cat.attribute2 '||
				 				',hr.organization_id ';
				 				
	sqlSourceFrom :=	'FROM '||
						   --	' gis_scanners scn '||
							'hr_operating_units hr '||
							--',apps.fnd_user usr '||
							',fnd_lobs lob '||
							',fnd_document_categories_vl cat '||
							',fnd_documents docs '||
			 				',fnd_documents_tl_dfv dfv '||
			 				',fnd_documents_tl doc ';
-- Modified PL 10/05/2001- missing ' ' at end of string for next concat to SQL statement
	sqlSourceWhere :=  	'WHERE '||
			 	 		'doc.document_id = docs.document_id AND ' ||
				 		'doc.rowid = dfv.row_id ' ||--AND doc.created_by = usr.user_id '||
				 		'AND doc.media_id = lob.file_id ' ||
				 		'AND doc.language = userenv(''LANG'') '||
						'AND docs.category_id = cat.category_id and docs.datatype_id = 6 ';
			 
-- build the filter depending on the details entered				 
	IF 	p_context = 'Customer' 
		OR p_context = 'Payables' 
		OR p_context = 'Receivables' 
		OR p_context = 'HR Assignments'
		OR p_context = 'Suppliers'
	THEN
-- set security id to 2 ( set of books id)
		sqlSourceWhere := sqlSourceWhere ||	'AND ((docs.security_id = hr.set_of_books_id AND docs.security_type = 2) '||
											'OR ( docs.security_type = 4 AND docs.PUBLISH_FLAG = ''Y'')) ';
	ELSIF 	p_context = 'Education Events' 
			OR p_context = 'Education Bookings'
	THEN
-- set security id to 3 ( business group id)
		sqlSourceWhere := sqlSourceWhere ||	'AND ((docs.security_id = hr.business_group_id AND docs.security_type = 3) '||
											'OR ( docs.security_type = 4 AND docs.PUBLISH_FLAG = ''Y'')) ';		
	ELSE 
-- set security id to 1 ( organization id)
		sqlSourceWhere := sqlSourceWhere ||	'AND ((docs.security_id = hr.organization_id AND docs.security_type = 1) '||
											'OR ( docs.security_type = 4 AND docs.PUBLISH_FLAG = ''Y'')) ';	
	END IF;
	
	sqlSourceWhere := sqlSourceWhere || ' AND doc.doc_attribute_category = ''' || p_context || '''';
		
-- build the dynamic part of the where clause
	sqlSourceWhere := sqlSourceWhere || gis_custom.custom_where_clause( p_context
															 ,p_doc_attribute1
															 ,p_doc_attribute2
															 ,p_doc_attribute3
															 ,p_doc_attribute3_OP
															 ,p_doc_attribute4
															 ,p_doc_attribute4_OP
															 ,p_doc_attribute5
															 ,p_doc_attribute6
															 ,p_doc_attribute7
															 ,p_doc_attribute8
															 ,p_doc_attribute9
															 ,p_doc_attribute10
															 ,p_doc_attribute11
															 ,p_doc_attribute12
															 ,p_doc_attribute13
															 ,p_doc_attribute14
															 ,p_doc_attribute15);

-- document description
	IF p_description IS NOT NULL
   	THEN
		sqlSourceWhere := sqlSourceWhere || ' AND  upper(doc.description) like '''|| upper(p_description) || '''' ;
   	END IF;   			
		
-- query dates
	IF p_scanned_date_from IS NOT NULL
	THEN
		IF p_scanned_date_to IS NOT NULL
		THEN
			sqlSourceWhere := sqlSourceWhere || ' AND doc.creation_date BETWEEN '''||p_scanned_date_from||''' AND '''||p_scanned_date_to||'''';
		END IF;
			sqlSourceWhere := sqlSourceWhere || ' AND doc.creation_date >= '''|| p_scanned_date_from || '''';
-- if the scanned too date is not null the query is <= the p_scanned_date_to date 
	ELSIF p_scanned_date_to IS NOT NULL
	THEN
			sqlSourceWhere := sqlSourceWhere || ' AND doc.creation_date <= '''|| (to_date(p_scanned_date_to)+1) || '''';			
	END IF; 
	
	IF p_indexed_date_from IS NOT NULL OR p_orderBy = 'Index Date'
	THEN
	   	sqlSourceFrom := sqlSourceFrom || ',gis_doc_status sta ';
		sqlSourceWhere := sqlSourceWhere || ' AND doc.document_id = sta.document_id ';
	 	sqlSourceWhere := sqlSourceWhere || ' AND sta.doc_status_type_id = (select doc_status_type_id
																			FROM gis_doc_status_types
																			WHERE doc_status_name = ''PRE-INDEXED'') '; -- 'PRE-INDEXED' id
	 	IF p_indexed_date_from IS NOT NULL
	 	THEN		
			IF p_indexed_date_to IS NOT NULL
			THEN
				sqlSourceWhere := sqlSourceWhere || ' AND sta.date_created BETWEEN '''||p_indexed_date_from||''' AND '''||p_indexed_date_to||'''';
			ELSE
				sqlSourceWhere := sqlSourceWhere || ' AND sta.date_created >= '''|| to_date(p_indexed_date_from) || '''';
			END IF;
		END IF;
	ELSIF p_indexed_date_to IS NOT NULL
	THEN
		sqlSourceFrom := sqlSourceFrom || ',gis_doc_status sta ';
		sqlSourceWhere := sqlSourceWhere || ' AND doc.document_id = sta.document_id ';
	 	sqlSourceWhere := sqlSourceWhere || ' AND sta.doc_status_type_id = (select doc_status_type_id
																			FROM gis_doc_status_types
																			WHERE doc_status_name = ''PRE-INDEXED'') '; -- 'PRE-INDEXED' 
		sqlSourceWhere := sqlSourceWhere || ' AND sta.date_created <= '''|| (to_date(p_indexed_date_to)+1) || '''';
	END IF; 

	IF p_org > 1
	THEN
		sqlSourceWhere := sqlSourceWhere || ' AND hr.organization_id = '|| p_org ;
	ELSE
		l_orgList := getOrgList( p_userId, p_context);
		sqlSourceWhere := sqlSourceWhere || ' AND hr.organization_id IN ('; 
		FOR i IN 1..l_orgList.last
		LOOP
			IF i != 1
			THEN
				sqlSourceWhere := sqlSourceWhere ||	',';
			END IF;
			sqlSourceWhere := sqlSourceWhere || l_orgList(i);
		END LOOP;
		sqlSourceWhere := sqlSourceWhere || ') ';
	END IF; 

-- doc category filter
	IF nvl(p_Doc_Category,'0') != '0'
	THEN
		sqlSourceWhere := sqlSourceWhere || ' AND docs.category_id = '|| p_Doc_Category;
	END IF;
-- order by clause selected by user
	IF p_orderBy != 'None'
	THEN
		IF p_orderBy = 'Doc Type'
		THEN
			sqlOrderBy :=  ' order by  cat.user_name';
		ELSIF p_orderBy = 'Doc Status'
		THEN
			sqlOrderBy :=  ' order by doc.doc_attribute6';
		ELSIF p_orderBy = 'License Value'
		THEN
			sqlOrderBy :=  ' order by to_number(dfv.license_value)';
		ELSIF p_orderBy = 'Order Value'
		THEN
			sqlOrderBy :=  ' order by to_number(dfv.order_value)';
		ELSIF p_orderBy = 'Renewal Value'
		THEN
			sqlOrderBy :=  ' order by to_number(dfv.renewal_value)';
		ELSIF p_orderBy = 'Project Value'
		THEN
			sqlOrderBy :=  ' order by to_number(dfv.project_value)';
		ELSIF p_orderBy = 'Organization'
		THEN
			sqlOrderBy :=  ' order by hr.name';
		ELSIF p_orderBy = 'Organization'
		THEN
			sqlOrderBy :=  ' order by hr.name';	
		ELSIF p_orderBy = 'Scan Date'
		THEN
			sqlOrderBy :=  ' order by docs.creation_date';
		ELSIF p_orderBy = 'Index Date'
		THEN
			sqlOrderBy :=  ' order by sta.last_update_date';			
		ELSE
			sqlOrderBy :=  ' order by '|| REPLACE(p_orderBy,' ','_');
		END IF;
			sqlOrderBy :=  sqlOrderBy || ' ' || p_dir;
	END IF;
			
	sqlSource := sqlSourceColumns || sqlSourceFrom || sqlSourceWhere || sqlOrderBy;
--htp.p(sqlSource);
	IF p_menuOption = 2 OR p_menuOption = 3
		THEN
-- clear select frame
		cid := dbms_sql.open_cursor;

		dbms_sql.parse( cid, sqlSource, dbms_sql.v7);
					
		FOR i IN 1..l_col_count
		LOOP
		    arr_columns.EXTEND;
	       	dbms_sql.define_column( cid, i, arr_columns(i) ,50);
		END LOOP;
	
	-- the fnd_lobs_id column will always be the last column + 1
		dbms_sql.define_column( cid, l_col_count+1, l_col_id );  
	-- the comments_id column will always be the last column + 2
		dbms_sql.define_column( cid, l_col_count+2, l_com_id );
    -- the document_id will be the last column + 3
		dbms_sql.define_column( cid, l_col_count+3, l_col_doc_id );
	-- the secure document flag will be the last column + 4
		dbms_sql.define_column( cid, l_col_count+4, l_secureFlag,50 );
	-- the org id will be the last column + 5
		dbms_sql.define_column( cid, l_col_count+5, ln_orgId );	    
    
	
		rowCount := dbms_sql.execute_and_fetch( cid);
		IF rowCount != 1
		THEN
			gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'gis_search.QueryActions');
			htp.br;
			htp.br;
			htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
			htp.p('<FONT size=''5''><B>No Records Found</B></FONT>');
		ELSE
			IF p_menuOption = 3
			THEN 
			-- MIME header to export to excel
			    owa_util.mime_header( ccontent_type=> 'application/octet-stream' , bclose_header=> FALSE );
			    htp.p( 'Content-Disposition: filename=GIS_' || l_context || '_search_' || TO_CHAR( SYSDATE, 'YYYYMONDDHH24MI' ) || '.csv' );
				owa_util.mime_header( ccontent_type=> 'application/octet-stream' , bclose_header=>TRUE);
			    htp.prn( '"Description"' );
			    htp.prn( ',"Secure"');
			    htp.prn( ',"Organization"' );
			    htp.prn( ',"Category"' );
			ELSE
				gis_image_util.pageopen(p_heading => 'Query Details',p_procedure=>'gis_search.QueryActions');
				htp.p( '<SCRIPT LANGUAGE="javascript">' );
		    	htp.p( 'parent.SelectFrame.document.location="gis_image_util.BlankFrame"' );
				htp.p( '</SCRIPT>');
				gis_image_util.InfoHeader(p_context ||' Report Results');
			
				htp.p('  <TABLE  WIDTH="100%" BGCOLOR="WHITE" BORDER="1" CELLSPACING="0" CELLPADDING="2">');
				htp.p('	<TR>');
		-- description and org will always be there
				htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" ><B>Description </B></FONT></TD>');
				htp.p('		<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Secure</B></FONT></TD>');
				htp.p(' 	<TD BGCOLOR="#C9C9C9" ALIGN="CENTER"><FONT COLOR="BLACK"><B>Org</B></FONT></TD>');
				htp.p('		<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Category</B></FONT></TD>');
			END IF;
	-- the next headings are dynamic
			IF NOT cur_columns%ISOPEN
			THEN
				OPEN cur_columns(p_context);
			END IF;
			
			FETCH cur_columns INTO row_columns;
			IF cur_columns%NOTFOUND THEN
				-- need some sort of error handler here
				NULL;
			ELSE
				WHILE cur_columns%FOUND
				LOOP
					IF p_menuOption = 3-- output to excel
					THEN 
						htp.prn( ',"'||row_columns.end_user_column_name||'"' );
					ELSE
						htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>'||row_columns.end_user_column_name||'</B></FONT></TD>');
		 			END IF;
		 			FETCH cur_columns INTO row_columns;
		 		END LOOP;
		 	END IF;
		 	CLOSE cur_columns;
					
			IF p_menuOption = 3-- output to excel
			THEN
			    htp.prn( ',"Status"' );
			    htp.prn( ',"Scan Date"' );
			    htp.prn( ',"Index Date"' );
			    htp.prn( ',"Indexed By"' );
			    htp.prn( ',"Processed Date"' );
			    htp.prn( ',"Processed By"' );
			    htp.p;
			ELSE			 	
		-- status, scan date and created by will always be there
				htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Status</B></FONT></TD>');
				htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Scan Date</B></FONT></TD>');
				htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Index Date</B></FONT></TD>');
				htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Indexed By</B></FONT></TD>');
				htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Processed Date</B></FONT></TD>');
				htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK"><B>Processed By</B></FONT></TD>');
				htp.p('	</TR>');
			END IF;
			WHILE rowCount = 1 
			LOOP
	
				FOR i IN 1..(arr_columns.last)
	      		LOOP
					dbms_sql.column_value( cid, i, arr_columns( i));
				END LOOP;
				
	-- set the fnd_lob_id column value
				dbms_sql.column_value( cid, l_col_count+1, l_col_id);     
	-- set the comments_id column value
				dbms_sql.column_value( cid, l_col_count+2, l_com_id);
	-- set the document_id column
				dbms_sql.column_value( cid, l_col_count+3, l_col_doc_id);
	-- set the secure flag column
				dbms_sql.column_value( cid, l_col_count+4, l_secureFlag);
	-- set the org id column
				dbms_sql.column_value( cid, l_col_count+5, ln_orgId);	
	-- get the access code and url to view the image through fnd_gfm
				l_url := fnd_gfm.construct_download_url(gis_image_util.get_pack_url,l_col_id);
		-- get the index date and indexer	
			 	l_rec := PreIndexDate( l_col_doc_id); 
				IF l_com_id IS NOT NULL
				THEN
					l_hrefColor := 'RED';
				ELSE
					l_hrefColor := 'BLUE';
				END IF;	
				
				IF p_menuOption = 3-- output to excel
				THEN
			    	htp.prn( arr_columns(1)); -- description
			    	htp.prn( ','||secureDocument( l_secureFlag)); -- secure document flag
			    		-- the next columns are dynamic
					FOR i IN 2..arr_columns.last
					LOOP
						htp.prn( ','||nvl(arr_columns(i),'-'));
					END LOOP;
					-- Export the index date and indexer
					htp.prn( ','||nvl(l_rec.date_created,'-')); 
					htp.prn( ','||nvl(l_rec.created_by,'-')); 
					htp.prn( ','||nvl(l_rec.date_processed,'-')); 
					htp.prn( ','||nvl(l_rec.processed_by,'-'));
					htp.prn( ',');
					htp.p; 
				ELSE
					htp.p('	<TR>');
		-- document description will always be there
		-- test for secure flag
					IF secureDocument(l_secureFlag) = 'Yes'
					THEN
					-- test if user has access to this secure document 
						IF viewSecureDocument( p_userId, ln_orgId, p_context)
						THEN
					-- document is secure and the user does have access rights
							htp.p(' 	<TD><A HREF="'||gis_image_util.c_pack_url||'gis_search.ImageDisplay?p_file_id='||l_col_id||
										'&p_document_id='||l_col_doc_id||'&p_url='|| REPLACE(l_url,'&','~') ||'&p_context='||
										l_context||'&p_userId='||p_userId||'&p_respId='||p_respId||
										'" onMouseOver="window.status=''View Image''; ');
							htp.p('		return true" onMouseOut="window.status='' ''; return true"><FONT COLOR="'||l_hrefColor||'" SIZE="2">' || arr_columns(1) ||' </FONT></A></TD>');
						ELSE
					-- document is secure and user does not have the correct access rights
							htp.p(' 	<TD><FONT COLOR="BLACK" SIZE="2">' || arr_columns(1) ||' </FONT></TD>');
						END IF;
					ELSE
					-- the document is not secure
						htp.p(' 	<TD><A HREF="'||gis_image_util.c_pack_url||'gis_search.ImageDisplay?p_file_id='||l_col_id||
									'&p_document_id='||l_col_doc_id||'&p_url='|| REPLACE(l_url,'&','~') ||'&p_context='||l_context||
									'&p_userId='||p_userId||'&p_respId='||p_respId||'" onMouseOver="window.status=''View Image''; ');
						htp.p('		return true" onMouseOut="window.status='' ''; return true"><FONT COLOR="'||l_hrefColor||'" SIZE="2">' || arr_columns(1) ||' </FONT></A></TD>');
					END IF;

					htp.p(' 	<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">' || secureDocument(l_secureFlag) ||' </FONT></TD>');
		-- the next columns are dynamic
					FOR i IN 2..arr_columns.last
					LOOP
						htp.p(' 	<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">' || nvl(arr_columns(i),'-') ||' </FONT></TD>');
					END LOOP;
		-- display the index date and indexer
			  --		htp.p(l_col_doc_id);
			 --		l_rec := PreIndexDate( l_col_doc_id); 
			 		htp.p(' 	<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">' || nvl(l_rec.date_created,'-') ||' </FONT></TD>');
			 		htp.p(' 	<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">' || nvl(l_rec.created_by,'-') ||' </FONT></TD>');
			 		htp.p(' 	<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">' || nvl(l_rec.date_processed,'-') ||' </FONT></TD>');
			 		htp.p(' 	<TD ALIGN="CENTER"><FONT COLOR="BLACK" SIZE="2">' || nvl(l_rec.processed_by,'-') ||' </FONT></TD>');
					htp.p('	</TR>');
				END IF;
				rowCount := dbms_sql.fetch_rows( cid);
			END LOOP;
			
			IF p_menuOption = 2-- output to screen
			THEN
				htp.p('</TABLE>');
				htp.p('</FONT>');
				gis_image_util.pageclose;
			END IF;
		END IF;
					
		dbms_sql.close_cursor( cid);
--	htp.p(sqlSource);
	

	ELSIF p_menuOption = 4
	THEN
    	htp.p( '<SCRIPT LANGUAGE="javascript">' );
    	htp.p( 'parent.SelectFrame.document.location="gis_search.SearchActions?'||
    											'p_context='||REPLACE( p_context,' ','+')||
												'&p_doc_attribute1='|| REPLACE( p_doc_attribute1,' ','+') || 
											    '&p_doc_attribute2='|| REPLACE( p_doc_attribute2,' ','+') ||
											    '&p_doc_attribute3='|| REPLACE( p_doc_attribute3,' ','+') || 
											    '&p_doc_attribute4='|| REPLACE( p_doc_attribute4,' ','+') || 
											    '&p_doc_attribute5='|| REPLACE( p_doc_attribute5,' ','+') ||
											    '&p_doc_attribute6='|| REPLACE( p_doc_attribute6,' ','+') || 
											    '&p_doc_attribute7='|| REPLACE( p_doc_attribute7,' ','+') || 
											    '&p_doc_attribute8='|| REPLACE( p_doc_attribute8,' ','+') || 
											    '&p_doc_attribute9='|| REPLACE( p_doc_attribute9,' ','+') ||
											    '&p_doc_attribute10='|| REPLACE( p_doc_attribute10,' ','+') || 
											    '&p_doc_attribute11='|| REPLACE( p_doc_attribute11,' ','+') || 
											    '&p_doc_attribute12='|| REPLACE( p_doc_attribute12,' ','+') || 
											    '&p_doc_attribute13='|| REPLACE( p_doc_attribute13,' ','+') || 
											    '&p_doc_attribute14='|| REPLACE( p_doc_attribute14,' ','+') || 
											    '&p_doc_attribute15='|| REPLACE( p_doc_attribute15,' ','+') ||
											    '&p_org='|| p_org ||
					    						'&p_scanned_date_from='||p_scanned_date_from ||
					    						'&p_scanned_date_to='||p_scanned_date_to ||
					    						'&p_indexed_date_from='||p_indexed_date_from || 
					    						'&p_indexed_date_to='||p_indexed_date_to ||										    
											    '&p_sqlSource=' || REPLACE( REPLACE(sqlSourceWhere,'%','~'),' ','+') ||
											    '&p_col_count='||l_col_count || 
											    '&p_userId=' || p_userId ||
											    '&p_respId=' || p_respId||
											    '&p_orderBy=' || p_orderBy ||
											    '&p_dir=' || p_dir || '"');
    	htp.p( 'parent.ViewingFrame.document.location="gis_image_util.ViewingFrame?p_userType=Inquiry+User"' );
    	htp.p( '</SCRIPT>');	
    END IF;
EXCEPTION
	WHEN OTHERS
	THEN
		htp.p(showErr( 'Statement being executed at time of error... '||sqlSource,'gis_search.QueryActions'));
END QueryActions;		

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE SearchActions( p_context VARCHAR2 DEFAULT NULL, 
						p_doc_attribute1 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute2 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute3 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute4 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute5 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute6 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute7 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute8 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute9 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute10 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute11 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute12 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute13 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute14 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute15 VARCHAR2 DEFAULT NULL,
					    p_org VARCHAR2 DEFAULT NULL,
					    p_scanned_date_from VARCHAR2 DEFAULT NULL,
					    p_scanned_date_to VARCHAR2 DEFAULT NULL,
					    p_indexed_date_from VARCHAR2 DEFAULT NULL,
					    p_indexed_date_to VARCHAR2 DEFAULT NULL,
					    p_sqlSource	VARCHAR2 DEFAULT NULL,
					    p_col_count VARCHAR2 DEFAULT NULL,
					    p_userId VARCHAR2,
					    p_respId VARCHAR2,
					    p_orderBy VARCHAR2 DEFAULT NULL,
					    p_dir VARCHAR2 DEFAULT NULL) IS

cid INTEGER;
cid2 INTEGER;
rowCount INTEGER;
rowCount2 INTEGER;
l_col_count NUMBER := p_col_count;
TYPE column_array IS VARRAY(15) OF stdVarchar;
arr_columns column_array:= column_array();
l_col_id NUMBER(15);
l_col_1 stdVarchar;
l_col_2 stdVarchar;
l_col_3 stdVarchar;
l_col_5 stdVarchar;
l_col_6 stdVarchar;
l_col_7 NUMBER(15);
l_col_8 NUMBER(15); 
l_col_9 stdVarchar;
l_col_10 stdVarchar;
l_col_11 stdVarchar;
l_col_12 stdVarchar;
l_col_13 idNumber;
l_url largeVarchar;
l_count minVarchar;
row_columns cur_columns%ROWTYPE;
l_sqlSource megaVarchar;
flagUrl largeVarchar;
l_context stdVarchar := REPLACE( p_context,' ','+');
l_rec gis_doc_status_record; 
l_hrefColor minVarchar;
l_secureFlag stdVarchar;

BEGIN
	gis_image_util.pageopen(p_heading => 'Search Details',p_procedure=>'gis_search.SearchActions');
            			
	l_sqlSource := 'SELECT  doc.description '||
							',doc.creation_date '||
			 				--',usr.user_name '||
			 				',lob.file_id '||
			 				',scn.organization_id '||
			 				',hr.name || '' - '' ||scn.description description, '||
			 				'doc.document_id '||
			 				',doc.doc_attribute5 ' || -- global flexfield ( comments id)
			 				',doc_attribute6 ' || -- global flexfield ( doc status)
							',doc_attribute7 '|| -- global flexfield ( doc status date)
							',cat.name Document_type '||
							',substr(cat.user_name,7) document_desc '||
							',hr.organization_id '||
							',cat.attribute2 secure_flag '||
			 				'FROM '||
							' gis_scanners scn '||
							',hr_operating_units hr '||
							--',apps.fnd_user usr '||
							',fnd_lobs lob '||
							',fnd_document_categories_vl cat '||
							',fnd_documents docs '||
			 				',apps.fnd_documents_tl_dfv dfv '||
			 				',fnd_documents_tl doc ';
			 				
	IF p_indexed_date_from IS NOT NULL
	THEN
		l_sqlSource := l_sqlSource || ',gis_doc_status sta ';
	END IF;
	l_sqlSource := l_sqlSource || REPLACE(p_sqlSource,'~','%')|| ' AND scn.scanner_id = lob.program_tag AND docs.datatype_id = 6';
	-- || 
	--												' AND scn.organization_id = hr.organization_id '||
	--												'AND lob.program_tag = scn.scanner_id '||
	--												' Order by lob.file_id';
	
--	htp.p(l_sqlSource);
--	htp.p(p_sqlSource);
	cid := dbms_sql.open_cursor;
		dbms_sql.parse( cid, l_sqlSource, dbms_sql.v7);
		
		dbms_sql.define_column( cid, 1, l_col_1,50 );
--		dbms_sql.define_column( cid, 2, l_col_2,50 );
		dbms_sql.define_column( cid, 2, l_col_3,50 );
	-- the fnd_lobs_id column 
		dbms_sql.define_column( cid, 3, l_col_id );
		dbms_sql.define_column( cid, 4, l_col_5,50 );
		dbms_sql.define_column( cid, 5, l_col_6,150 );
		dbms_sql.define_column( cid, 6, l_col_7);-- document_id
		dbms_sql.define_column( cid, 7, l_col_8);
		dbms_sql.define_column( cid, 8, l_col_9,25);
		dbms_sql.define_column( cid, 9, l_col_10,25);
		dbms_sql.define_column( cid, 10, l_col_11,25);
		dbms_sql.define_column( cid, 11, l_col_12,50);
		dbms_sql.define_column( cid, 12, l_col_13);
		dbms_sql.define_column( cid, 13, l_secureFlag,150);				
		rowCount := dbms_sql.execute_and_fetch( cid);
		IF rowCount != 1
		THEN
			gis_image_util.InfoHeader(p_context ||' Search Results');
			htp.br;
			htp.br;
			htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
			htp.p('<FONT size=''5''><B>No Records Found</B></FONT>');
		ELSE
-- get the number of records returned from query
-- and display
			l_sqlSource := 'SELECT count(*) FROM '||
			 				'fnd_documents_tl doc '||
			 				',fnd_documents docs '||
			 				',apps.fnd_documents_tl_dfv dfv '||
			 				',fnd_lobs lob '||
			 				',hr_operating_units hr '||
			 				',gis_scanners scn '||
			 				',fnd_document_categories_tl cat ';

			IF p_indexed_date_from IS NOT NULL
			THEN
				l_sqlSource := l_sqlSource || ',gis_doc_status sta ';
			END IF;
				 				
			l_sqlSource := l_sqlSource || REPLACE(p_sqlSource,'~','%')|| ' AND scn.scanner_id = lob.program_tag';
			--htp.p(l_sqlSource);										 
			cid2 := dbms_sql.open_cursor;
			dbms_sql.parse( cid2, l_sqlSource, dbms_sql.v7);
			dbms_sql.define_column( cid2, 1, l_count, 10);
			rowCount2 := dbms_sql.execute_and_fetch( cid2);
			dbms_sql.column_value( cid2, 1, l_count);		
			gis_image_util.InfoHeader(p_context ||' Search Results ' || l_count || ' Documents Found');
			dbms_sql.close_cursor( cid2);
			htp.p('  <TABLE  WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
			htp.p('	<TR>');
	-- Document will always be there 
			htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" SIZE="2" ><B>Document </B></FONT></TD>');
	-- scan date and created by will always be there
			htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" SIZE="2"><B>Org</B></FONT></TD>');
			htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" SIZE="2"><B>Doc Cat.</B></FONT></TD>');
			htp.p(' 	<TD BGCOLOR="#C9C9C9"><FONT COLOR="BLACK" SIZE="2"><B>Processed</B></FONT></TD>');
			htp.p('	</TR>');
			WHILE rowCount = 1 
			LOOP

	-- set the fnd_lob_id column value
				dbms_sql.column_value( cid, 3, l_col_id);
	-- get the access code and url to view the image through fnd_gfm
				l_url := fnd_gfm.construct_download_url(gis_image_util.get_pack_url,l_col_id);

	-- the rest of the columns
				dbms_sql.column_value( cid, 1, l_col_1);
  --				dbms_sql.column_value( cid, 2, l_col_2);
				dbms_sql.column_value( cid, 2, l_col_3);
				dbms_sql.column_value( cid, 4, l_col_5);
				dbms_sql.column_value( cid, 5, l_col_6);
				dbms_sql.column_value( cid, 6, l_col_7); -- document_id
				dbms_sql.column_value( cid, 7, l_col_8);
				dbms_sql.column_value( cid, 8, l_col_9);
				dbms_sql.column_value( cid, 9, l_col_10);
				dbms_sql.column_value( cid, 10, l_col_11);
				dbms_sql.column_value( cid, 11, l_col_12);
				dbms_sql.column_value( cid, 12, l_col_13);
				dbms_sql.column_value( cid, 13, l_secureFlag);
	-- set the url for the required flag
				flagUrl := gis_image_util.c_flags_url || 'f_' || l_col_5 ||'.gif';
				htp.p('	<TR>');
	-- document description will always be there 
				IF l_col_8 IS NOT NULL
				THEN
					l_hrefColor := gis_image_util.c_comments_yes;
				ELSE
					l_hrefColor := gis_image_util.c_comments_no;
				END IF;					
		-- test for secure flag
				IF secureDocument(l_secureFlag) = 'Yes'
				THEN
				-- test if user has access to this secure document 
					IF viewSecureDocument( p_userId, l_col_13, p_context)
					THEN
				-- document is secure and the user does have access rights
						htp.p(' 	<TD><A HREF="JavaScript:searchimage('''||gis_image_util.c_pack_url||
									'gis_search.ImageDetails?p_file_id='||l_col_id||'&p_document_id='||l_col_7||
									'&p_context='||l_context||'&p_userId='||p_userId||'&p_respId='||p_respId||''','''||l_url||
									''')" onMouseOver="window.status=''View Image''; ');
						htp.p('		return true" onMouseOut="window.status='' ''; return true"><FONT COLOR="'||l_hrefColor||'" SIZE="2">' || l_col_1 ||' </FONT></A></TD>');
					ELSE
				-- document is secure and user does not have the correct access rights
						htp.p(' 	<TD><FONT COLOR="'||l_hrefColor||'" SIZE="2">' || l_col_1 ||' </FONT></A></TD>');
					END IF;
				ELSE
				-- the document is not secure
					htp.p(' 	<TD><A HREF="JavaScript:searchimage('''||gis_image_util.c_pack_url||
								'gis_search.ImageDetails?p_file_id='||l_col_id||'&p_document_id='||l_col_7||'&p_context='||
								l_context||'&p_userId='||p_userId||'&p_respId='||p_respId||''','''||l_url||
								''')" onMouseOver="window.status=''View Image''; ');
					htp.p('		return true" onMouseOut="window.status='' ''; return true"><FONT COLOR="'||l_hrefColor||'" SIZE="2">' || l_col_1 ||' </FONT></A></TD>');
				END IF;

--				htp.p(' 	<TD><A HREF="JavaScript:searchimage('''||gis_image_util.c_pack_url||'gis_search.ImageDetails?p_file_id='||l_col_id||'&p_context='||l_context||'&p_userId='||p_userId||'&p_respId='||p_respId||''','''||l_url||''')" onMouseOver="window.status=''View Image''; ');
--				htp.p('		return true" onMouseOut="window.status='' ''; return true"><FONT COLOR="'||l_hrefColor||'" SIZE="2">' || l_col_1 ||' </FONT></A></TD>');
				htp.p(' 	<TD ALIGN="CENTER" VALIGN="MIDDLE" '||gis_image_util.c_background_color||'><IMG SRC= "'||flagUrl||'"  ALIGN="CENTRE" ALT="'||l_col_6||'"></TD>');			
--				l_rec := PreIndexDate(l_col_7);
				htp.p(' 	<TD ALIGN="CENTER" VALIGN="MIDDLE"><A HREF=JavaScript:alert('''||REPLACE(l_col_12,' ','_')||''')><FONT COLOR="WHITE" SIZE="1">' || l_col_11 ||' </FONT></A></TD>');
			    IF l_col_9 = 'PROCESSED'
			    THEN
					htp.p(' 	<TD ALIGN="CENTER" VALIGN="MIDDLE"><FONT COLOR="WHITE" SIZE="2">'||l_col_10||'</FONT></TD>');			    
			    ELSIF l_col_9 = 'COMPLETED'
			    THEN
					htp.p(' 	<TD ALIGN="CENTER" VALIGN="MIDDLE"><FONT COLOR="WHITE" SIZE="2">Completed</FONT></TD>');
			    ELSE 
					htp.p(' 	<TD ALIGN="CENTER" VALIGN="MIDDLE"><FONT COLOR="WHITE" SIZE="2">-</FONT></TD>');
				END IF;
				htp.p('	</TR>');
				rowCount := dbms_sql.fetch_rows( cid);
			END LOOP;
			htp.p('</TABLE>');
			htp.p('</FONT>');
		END IF;
	dbms_sql.close_cursor( cid);			    
	gis_image_util.pageclose;			    

EXCEPTION
	WHEN OTHERS
	THEN
		htp.p(showErr( 'Statement being executed at time of error... '||l_sqlSource,'gis_search.SearchActions'));
END SearchActions;

---------------------------------------------------------------------------
--
--
--
---------------------------------------------------------------------------
PROCEDURE ImageDisplay( p_file_id VARCHAR2
						,p_document_id VARCHAR2
						,p_url VARCHAR2
						,p_context VARCHAR2
						,p_userId NUMBER
						,p_respId VARCHAR2) IS

l_context VARCHAR2(25) := REPLACE( p_context,' ','+');

BEGIN
-- check the current user session is valid
	IF icx_sec.validateSession 
	THEN
	-- show the image and doc details in the correct frames
		htp.p( js('	parent.QueryFrame.document.location="gis_search.ImageDetails?p_file_id='||
					p_file_id||'&p_context='||l_context||'&p_userId='||p_userId||'&p_respId='||p_respId||'";
					parent.SelectFrame.document.location="gis_image_util.BlankFrame";
					parent.ViewingFrame.document.location="'||REPLACE(p_url,'~','&')||'";
					parent.QueryFrame.document.location="gis_search.ImageDetails?p_file_id='||p_file_id||'&p_document_id='||
					p_document_id||'&p_context='||l_context||'&p_userId='||p_userId||'&p_respId='||p_respId||'";'));
	ELSE
		htp.p(' Current user session is invalid or has expired');	
	END IF;
END ImageDisplay;

---------------------------------------------------------------------------
-- ImageDetails procedure
-- This procedure displays the database stored details associated with the current
-- image. It is called from a number of packages and procedures so should be moved to
-- gis_image_util at some point
--
---------------------------------------------------------------------------
PROCEDURE ImageDetails( p_file_id VARCHAR2
						,p_document_id VARCHAR2
						,p_context VARCHAR2
						,p_navTo VARCHAR2 DEFAULT 'Back'
						,p_userId VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2)
IS

row_columns cur_columns%ROWTYPE;

l_accessCode NUMBER(25);
l_context_id NUMBER;
url VARCHAR2(200);
sqlSource VARCHAR2(1000);
l_col_count NUMBER :=7;
cid INTEGER;
rowCount INTEGER;
rec NUMBER := 1;
l_comments VARCHAR2(2000);
l_attrib NUMBER;
viewingFrameUrl VARCHAR2(250);
nResponsibility_id NUMBER(15);

TYPE column_array IS VARRAY(20) OF stdVarchar;
arr_columns column_array:= column_array();

BEGIN
	gis_image_util.pageopen(p_heading => 'Image Details',p_procedure=>'gis_search.ImageDetails');
	gis_image_util.InfoHeader('Image Details');
-- check the current user session is valid
	IF icx_sec.validateSession 
	THEN
		sqlSource := 'SELECT '||
					  'doc.description ' ||
					  ',cat.user_name doc_category ';
	
	-- get the required columns for the correct context
	-- and feed into the select statement
		IF NOT cur_columns%ISOPEN
		THEN
			OPEN cur_columns(p_context);
		END IF;
		
		FETCH cur_columns INTO row_columns;
		IF cur_columns%NOTFOUND THEN
			-- need some sort of error handler here
			NULL;
		ELSE
			WHILE cur_columns%FOUND
			LOOP
	 			sqlSource:= sqlSource ||',dfv.'||REPLACE(row_columns.end_user_column_name,' ','_') || ' ';	
	 			l_col_count := l_col_count + 1;
	 			FETCH cur_columns INTO row_columns;
	 		END LOOP;
	 	END IF;
	 	CLOSE cur_columns;	
	
		sqlSource := sqlSource ||  	',doc.doc_attribute6 ' ||    -- global flexfield (index status)
									',doc.creation_date '||
					 				--',usr.user_name '||
									',hr.name || '' - '' ||scn.description description '||
									',doc.doc_attribute5 ' ||    -- global flexfield (comments_id) 
									',to_char(doc.document_id) ' ||
									'FROM '||
					 				'fnd_documents_tl doc '||
					 				',fnd_documents docs '||
					 				',fnd_documents_tl_dfv dfv '||
					 				',fnd_document_categories_tl cat '||
					 				--',apps.fnd_user usr '||
					 				',gis_scanners scn'||
					 				',hr_operating_units hr '||
				 					',fnd_lobs lob '||
				 	 				'WHERE '||
				 	 				'doc.document_id = docs.document_id AND ' ||
					 				'doc.rowid = dfv.row_id '||--AND doc.created_by = usr.user_id '||
					 				'AND doc.media_id = lob.file_id '||
					 				'AND docs.category_id = cat.category_id '||
					 				'AND scn.organization_id = hr.organization_id '||
				 					'AND lob.program_tag = scn.scanner_id '||
				 					'AND doc.doc_attribute_category = ''' || p_context || ''''||
				 					' AND lob.file_id = '||p_file_id||
				 					' AND doc.document_id = '|| p_document_id;
	
	
	cid := dbms_sql.open_cursor;
	--	htp.p(sqlSource);
		dbms_sql.parse( cid, sqlSource, dbms_sql.v7);
					
		FOR i IN 1..l_col_count
		LOOP
		    arr_columns.EXTEND;
		   	dbms_sql.define_column( cid, i, arr_columns(i) ,50);
		END LOOP;
	
			rowCount := dbms_sql.execute_and_fetch( cid);
		IF rowCount != 1
		THEN
			htp.br;
			htp.br;
			htp.p('<IMG SRC="'||gis_image_util.c_image_url||'i_stop.gif">');
			htp.p('<FONT size=''5''><B>Error Finding Record</B></FONT>');
		ELSE
			FOR i IN 1..(arr_columns.last)
		   	LOOP
				dbms_sql.column_value( cid, i, arr_columns( i));
			END LOOP;				
		--	htp.p( sqlSource);
			htp.p('  <TABLE WIDTH="95%" BORDER="0" CELLSPACING="0" CELLPADDING="2">');
			htp.p('		<TR><TD ALIGN="LEFT"><B>Description: </B></TD><TD ALIGN="LEFT">'||arr_columns( rec)||'</TD></TR>');
			htp.p('		<TR><TD ALIGN="LEFT"><B>Doc Category: </B></TD><TD ALIGN="LEFT">'||arr_columns( rec+1)||'</TD></TR>');
	--	 the next headings are dynamic
			IF NOT cur_columns%ISOPEN
			THEN
				OPEN cur_columns(p_context);
			END IF;
			
			FETCH cur_columns INTO row_columns;
			IF cur_columns%NOTFOUND THEN
			-- need some sort of error handler here
				NULL;
			ELSE
				rec := 3;
				WHILE cur_columns%FOUND
				LOOP 
					htp.p(' 	<TR><TD ><B>'||row_columns.end_user_column_name||':</B></TD>');
					htp.p('		<TD ALIGN="LEFT">'||nvl(arr_columns(rec),'-')||'</TD></TR>');
					FETCH cur_columns INTO row_columns;
					rec := rec + 1;
				END LOOP;
			END IF;
			CLOSE cur_columns;
		
	-- The next headings are std
			htp.p('		<TR><TD><B>Doc Status: </B></TD><TD ALIGN="LEFT">'||arr_columns(rec)||'</TD></TR>');
			htp.p('		<TR><TD><B>Scanned On: </B></TD><TD ALIGN="LEFT">'||arr_columns(rec+1)||'</TD></TR>');
			htp.p('		<TR><TD><B>Scanned At: </B></TD><TD ALIGN="LEFT">'||arr_columns(rec+2)||'</TD></TR>');
	
	-- get any comments if they exist		
				htp.p('  </TABLE>');
				htp.p('  <TABLE WIDTH="95%" BORDER="0" CELLSPACING="0" CELLPADDING="2">'); 
				htp.p('		<TR><TD><B>Comments/Problems: </B>');  
				htp.p('		<A HREF="javascript:logComments('''||gis_image_util.c_pack_url||''','||p_file_id||','||p_userId||')">
				<IMG SRC="'||gis_image_util.c_image_url||'b_comment.gif" BORDER="0" ALT="Comments" ALIGN="TOP"></A></TD></TR>');-- BGCOLOR="#FFFFFF" COLSPAN="3" ALIGN="LEFT">');
				htp.p('  </TABLE>');
				htp.p('</FORM>');
			htp.p('  <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="0">');                                                                             
	
	----------------------------- display the available buttons at the bottom of the image details frame ---------------------------------
	
	-- build the back button url depending on which screens this procedure is being run from i.e. process screens
	-- or inquiry screens        
			IF (gis_image_util.userAccessRights( p_userId ,p_respId)) = 'Inquiry User'
			THEN
				url := gis_image_util.c_pack_url||'gis_search.QueryOptions?p_document=Pre+Index&p_context='||REPLACE(p_context,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId;
				l_attrib := 1;
				viewingFrameUrl := gis_image_util.c_pack_url||'gis_image_util.ViewingFrame?p_userType=Inquiry+User';		
			ELSE
				url := gis_image_util.c_pack_url||'gis_checkout_image.checkOutUsers?p_context='||REPLACE(p_context,' ','+')||'&p_userId='||p_userId||'&p_respId='||p_respId;
				l_attrib := 2;
				viewingFrameUrl := gis_image_util.c_pack_url||'gis_image_util.ViewingFrame?p_userType=Process+User';
			END IF;
			htp.br;
	
	-- if the current document is at the pre-indexed status and the current user has the process document responsibility
	-- show the process and reject buttons. It has also been defined as business rule that only documents at pre-indexed
	-- status can be modified and only by users with the process responsibility.		
		    IF arr_columns(rec) = 'PRE-INDEXED' 
		    THEN
	        	-- get the responsibility_id for 'GIS_02_PROCESSOR'     	
	        	SELECT resp.responsibility_id
				INTO nResponsibility_id
				FROM fnd_responsibility resp
					,fnd_menus menu
					,fnd_menu_entries ent
					,fnd_form_functions func
				WHERE func.function_name = 'GIS_02_PROCESSOR'
				AND resp.menu_id = menu.menu_id
				AND menu.menu_id = ent.menu_id
				AND ent.function_id = func.function_id;
	--only allow users to process documents if they have the 	
	--the imaging processor responsibility			
				IF (gis_image_util.userAccessRights( p_userId ,nResponsibility_id))  = 'Process User' 
	        	THEN					
	-- the back button
					htp.p('     <TR><TD ALIGN="CENTER"><A HREF="javaScript:backimage('''||url||''','||l_attrib||','''||viewingFrameUrl||
								''')" onMouseOver="window.status=''Back''; ');
					htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_l.gif" ');
					htp.p('		BORDER="0" ALT="Back" ALIGN="TOP"></A>');											                              
	-- the process button
	        		htp.p('     <A HREF="gis_process_image.imageProcessed?p_docid='||arr_columns(rec+4)||'&p_userId='||p_userId||'&p_context='||
	        					REPLACE(p_context,' ','+')||'&p_respId='||p_respId||
							'&p_navTo='||replace(url,'&','~')||'" onMouseOver="window.status=''Process Document''; ');
					htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||
								'b_process_m.gif" ');
					htp.p('		BORDER="0" ALT="Process Document" ALIGN="TOP"></A>');
	-- the reject button
					htp.p('     <A HREF="javaScript:rejectImage('||arr_columns(rec+4)||','''||REPLACE(p_context,' ','+')||''','||p_userId||','||
								 p_file_id||','''||gis_image_util.c_pack_url||''','||p_respId||','''||p_navTo||
								 ''')" onMouseOver="window.status=''Reject Document''; ');
					htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||
								'b_reject_m.gif" ');
					htp.p('		BORDER="0" ALT="Reject Document" ALIGN="TOP"></A>');
	-- the modify button
					htp.p('     <A HREF="gis_preindex.show_doc_types?p_user_id='||p_userId||'&p_context='||
								REPLACE(p_context,' ','+')||'&p_file_id='||p_file_id||'&p_def_context=All&p_refresh_rate=60000&p_navTo='||
								gis_image_util.c_pack_url||'gis_search.ImageDetails?p_file_id='||p_file_id||'~p_document_id='||p_document_id||
								'~p_context='||REPLACE(p_context,' ','+')||'~p_navTo='|| p_navTo ||'~p_userId='||p_userId||'~p_respId='||p_respId||
								'" onMouseOver="window.status=''Re-Index''; ');
					htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_reindex_r.gif" ');
					htp.p('		BORDER="0" ALT="Re-Index" ALIGN="TOP"></A></TD></TR>');
				ELSE
	-- the back button
					htp.p('     <TR><TD ALIGN="CENTER"><A HREF="javaScript:backimage('''||url||''','||l_attrib||','''||viewingFrameUrl||''')" onMouseOver="window.status=''Back''; ');
					htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_m.gif" ');
					htp.p('		BORDER="0" ALT="Back" ALIGN="TOP"></A>');
				END IF;
			ELSE
	-- the back button
			htp.p('     <TR><TD ALIGN="CENTER"><A HREF="javaScript:backimage('''||url||''','||l_attrib||','''||viewingFrameUrl||''')" onMouseOver="window.status=''Back''; ');
			htp.p('		return true" onMouseOut="window.status='' ''; return true"><IMG SRC="'||gis_image_util.c_image_url||'b_back_m.gif" ');
			htp.p('		BORDER="0" ALT="Back" ALIGN="TOP"></A>');
			END IF;
			htp.p('  </TABLE>');
			htp.br;
		END IF;
		dbms_sql.close_cursor( cid);
	ELSE
	    	htp.p( showErr( ' Current user session is invalid or has expired', 'gis_search.ImageDetails'));
	END IF;
	gis_image_util.pageclose;
EXCEPTION
	WHEN OTHERS 
	THEN
		htp.p( showErr( 'Statement being executed at time of error... '||sqlsource, 'gis_search.ImageDetails'));
END ImageDetails;

END gis_search;
/
