CREATE OR REPLACE
PACKAGE apps.gis_search AS
-- ============================================================================
--
--   NAME
--      gis_search_pks.sql
--
--   DESCRIPTION
--      This script is used to create the gis_search package spec 
--      
--	 Procedures
--		ViewingFrame
--		OptionFrame
--		BlankFrame
--		InfoHeader(p_heading  VARCHAR2 DEFAULT NULL)
--		QueryIndex(p_heading  VARCHAR2 DEFAULT NULL)
--		QueryContext( p_document VARCHAR2)
--		QueryOptions( p_document VARCHAR2, p_context NUMBER)
--		Error_message(p_message  VARCHAR2 DEFAULT NULL)
--		pageclose
--		pageheader(p_heading IN VARCHAR2,
--                 p_country IN VARCHAR2 DEFAULT NULL,
--                 p_refresh IN VARCHAR2 DEFAULT NULL,
--                 p_refresh_url IN VARCHAR2 DEFAULT NULL)
--		pageopen(p_heading IN VARCHAR2)
--		dummypage
--
--   HISTORY
--      10/08/2000 David Gough In Development
--		05/06/2001 David Gough p_org added to listDocuments
--		11/06/2001 David Gough FUNCTION viewSecureDocument made public
--
-- ============================================================================

-- autoCommit flag

b_autoCommit BOOLEAN := TRUE;

-- Public cursors ------------------------------------------------------------------
CURSOR cur_columns( f_context VARCHAR2) IS
SELECT
descriptive_flex_context_code,
column_seq_num
,application_column_name
,end_user_column_name
,description
,display_size
,form_left_prompt
FROM
apps.fnd_descr_flex_col_usage_vl
WHERE
descriptive_flexfield_name = 'ATCHMT_DOCUMENT_FLEX'
AND application_id = 0
AND enabled_flag = 'Y'
AND display_flag = 'Y'
AND (descriptive_flex_context_code = f_context
OR descriptive_flex_context_code = 'Global Data Elements')
ORDER BY column_seq_num,descriptive_flex_context_code;

-- new cursor to limit the context to those that the
-- user has access to
CURSOR cur_docContext(f_userId NUMBER DEFAULT 123455) IS
select distinct
--rownum+1 row_id
con.descriptive_flexfield_name
,con.descriptive_flex_context_code
,con.description
,con.descriptive_flex_context_name
from FND_DESCR_FLEX_CONTEXTS_VL con,
	fnd_user_resp_groups usrep,
	fnd_application_tl app,
	fnd_responsibility_tl resp,
	fnd_user usr
where
	usr.user_id = f_userId
and
	usr.user_id = usrep.user_id
and
	nvl(usrep.end_date,sysdate+1) > sysdate
and
	usrep.responsibility_application_id = app.application_id
and
 	usrep.responsibility_id = resp.responsibility_id
and
	usrep.responsibility_application_id = resp.application_id
AND
	usr.user_id = usrep.user_id
AND
	con.descriptive_flexfield_name = 'ATCHMT_DOCUMENT_FLEX'
and
	descriptive_flex_context_code != 'Global Data Elements'
and
	app.application_name = con.descriptive_flex_context_name
order by
-- Modified by Patrick Low: 26/03/2001
-- Change order by to description field, as context for Contracts is described as Renewals
	con.description;

CURSOR cur_countryList( f_userId NUMBER, f_appId NUMBER, f_orgId VARCHAR2 DEFAULT NULL, f_respName VARCHAR2 DEFAULT NULL) IS
SELECT DISTINCT
	optval.profile_option_value organization_id,
	hr.name,
	usr.user_name,
	usr.user_id
FROM
    hr_organization_units hr,
	fnd_application_tl app,
	fnd_responsibility_tl resp,
	fnd_profile_option_values optval,
	fnd_profile_options opt,
	fnd_user_resp_groups usrep,
	fnd_user usr
WHERE
	usr.user_id = f_userId
AND
	usrep.responsibility_application_id = f_appId
AND
	optval.profile_option_value = NVL( f_orgId, optval.profile_option_value)
AND
	usr.user_id = usrep.user_id
AND
	resp.responsibility_name like NVL( f_respName, resp.responsibility_name)
AND
	nvl(usrep.end_date,SYSDATE+1) > SYSDATE
AND
	usrep.responsibility_application_id = app.application_id
AND
 	usrep.responsibility_id = resp.responsibility_id
AND
	usrep.responsibility_application_id = resp.application_id
AND
	usr.user_id = usrep.user_id
AND
	usrep.responsibility_id = optval.level_value
AND
	optval.profile_option_id = opt.profile_option_id
AND
	optval.application_id =  opt.application_id
AND
	opt.profile_option_name = 'ORG_ID'
AND
	optval.profile_option_value = hr.organization_id;  
	
CURSOR cur_countryListCount( f_userId NUMBER, f_appId NUMBER, f_orgId VARCHAR2 DEFAULT NULL, f_respName VARCHAR2 DEFAULT NULL) IS
SELECT DISTINCT
	count(hr.name) AS orgCount
FROM
    hr_organization_units hr,
	fnd_application_tl app,
	fnd_responsibility_tl resp,
	fnd_profile_option_values optval,
	fnd_profile_options opt,
	fnd_user_resp_groups usrep,
	fnd_user usr
WHERE
	usr.user_id = f_userId
AND
	usrep.responsibility_application_id = f_appId
AND
	optval.profile_option_value = NVL( f_orgId, optval.profile_option_value)
AND
	usr.user_id = usrep.user_id
AND
	resp.responsibility_name like NVL( f_respName, resp.responsibility_name)
AND
	nvl(usrep.end_date,SYSDATE+1) > SYSDATE
AND
	usrep.responsibility_application_id = app.application_id
AND
 	usrep.responsibility_id = resp.responsibility_id
AND
	usrep.responsibility_application_id = resp.application_id
AND
	usr.user_id = usrep.user_id
AND
	usrep.responsibility_id = optval.level_value
AND
	optval.profile_option_id = opt.profile_option_id
AND
	optval.application_id =  opt.application_id
AND
	opt.profile_option_name = 'ORG_ID'
AND
	optval.profile_option_value = hr.organization_id;
------------------------------------------------------------------------------------
-- public types
TYPE gis_doc_status_record IS RECORD(	date_created VARCHAR2(15),
							  			created_by VARCHAR2(50),
							  			date_processed VARCHAR2(15),
							  			processed_by VARCHAR2(50));
TYPE org_array IS VARRAY(50) OF NUMBER(10);	
TYPE stringArray IS VARRAY(50) OF VARCHAR2(50); 
SUBTYPE megaVarchar IS VARCHAR2(4000);
SUBTYPE LargeVarchar IS VARCHAR2(2000);
SUBTYPE stdVarchar IS VARCHAR2(255);
SUBTYPE minVarchar IS VARCHAR2(15);
SUBTYPE idNumber IS NUMBER(15);
SUBTYPE id32Number IS NUMBER(32);
					  			
------------------------------------------------------------------------------------
-- Public Procedures

PROCEDURE QueryContext( p_document VARCHAR2
						, p_navTo VARCHAR DEFAULT NULL
						, p_target VARCHAR2 DEFAULT NULL
						,p_userType VARCHAR2 DEFAULT NULL
						, p_userId VARCHAR2 DEFAULT NULL
						, p_respId VARCHAR2 DEFAULT NULL);

PROCEDURE QueryOptions( p_document VARCHAR2 DEFAULT NULL
						, p_context VARCHAR2 DEFAULT NULL
						,p_userId VARCHAR2 DEFAULT NULL
						, p_userType VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2);

PROCEDURE CustNameLov( 	p_org VARCHAR2
						,p_custName	VARCHAR2 DEFAULT NULL);
						

PROCEDURE  QueryIndex(	p_document VARCHAR2
						,p_userType VARCHAR2
						,p_userId VARCHAR2
						,p_respId VARCHAR2);
/*						
PROCEDURE indexedQueryOptions(	p_document VARCHAR2 DEFAULT NULL
								, p_context VARCHAR2 DEFAULT NULL
								,p_userId VARCHAR2 DEFAULT NULL
								,p_userType VARCHAR2 DEFAULT NULL
								,p_respId VARCHAR2);
								
PROCEDURE OrderHeadersQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2);

PROCEDURE ListDocuments(p_docRef VARCHAR2
						,p_pkValue VARCHAR2
						,p_context VARCHAR2
						,p_userType VARCHAR2
						,p_userId VARCHAR2
						,p_respId VARCHAR2
						,p_org VARCHAR2 DEFAULT NULL 
						,p_attributes VARCHAR2);
							 
PROCEDURE Order_ManagementIQActions(	p_userId VARCHAR2
							 		,p_userType VARCHAR2
							 		,p_respId VARCHAR2
							 		,p_context VARCHAR2
							 		,p_org VARCHAR2
							 		,p_orgCount VARCHAR2
							 		,imageDisplayed VARCHAR2
							 		,p_orderNumber VARCHAR2 DEFAULT NULL
							 		,p_orderDateFrom VARCHAR2 DEFAULT NULL
							 		,p_orderDateTo VARCHAR2 DEFAULT NULL
							 		,p_docRef VARCHAR2 DEFAULT NULL
							 		,p_soldTo VARCHAR2 DEFAULT NULL
							 		,p_customerNumber VARCHAR2 DEFAULT NULL
							 		,p_orgName VARCHAR2 DEFAULT NULL);
							 		
PROCEDURE ContractsQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2);   

PROCEDURE CustomerIQActions(	p_userId VARCHAR2
							 	,p_userType VARCHAR2
							 	,p_respId VARCHAR2
							 	,p_context VARCHAR2
							 	,p_org VARCHAR2
							 	,p_orgCount VARCHAR2
							 	,imageDisplayed VARCHAR2
							 	,p_customerName VARCHAR2 DEFAULT NULL
							 	,p_customerNumber VARCHAR2 DEFAULT NULL
							 	,p_orgName VARCHAR2 DEFAULT NULL);
							 								 
PROCEDURE ContractsIQActions(	p_userId VARCHAR2
							 		,p_userType VARCHAR2
							 		,p_respId VARCHAR2
							 		,p_context VARCHAR2
							 		,p_org VARCHAR2 
							 		,p_orgCount VARCHAR2
							 		,imageDisplayed VARCHAR2
							 		,p_contractNumber VARCHAR2 DEFAULT NULL
							 		,p_contractModifier VARCHAR2 DEFAULT NULL
							 		,p_soldTo VARCHAR2 DEFAULT NULL
							 		,p_customerNumber VARCHAR2 DEFAULT NULL
							 		,p_orgName VARCHAR2 DEFAULT NULL);
							 		
PROCEDURE Old_RenewalsIQActions(	p_userId VARCHAR2
							 		,p_userType VARCHAR2
							 		,p_respId VARCHAR2
							 		,p_context VARCHAR2
							 		,p_org VARCHAR2
							 		,p_orgCount VARCHAR2
							 		,imageDisplayed VARCHAR2
							 		,p_renewalId VARCHAR2 DEFAULT NULL
							 		,p_soldTo VARCHAR2 DEFAULT NULL
							 		,p_customerNumber VARCHAR2 DEFAULT NULL
							 		,p_orgName VARCHAR2 DEFAULT NULL);

PROCEDURE OldRenewalsQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2);

FUNCTION Valid_value ( p_value VARCHAR2) RETURN NUMBER;
                                                         
PROCEDURE UpdateField( 	p_field VARCHAR2 DEFAULT NULL
						,p_value VARCHAR2 DEFAULT NULL
						,p_docId VARCHAR2 DEFAULT NULL
						,p_docRef VARCHAR2 DEFAULT NULL
						,p_pkValue VARCHAR2 DEFAULT NULL
						,p_context VARCHAR2 DEFAULT NULL
						,p_userType VARCHAR2 DEFAULT NULL
						,p_userId VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2 DEFAULT NULL
						,p_attributes VARCHAR2 DEFAULT NULL);

PROCEDURE SaveUpdate( 	p_field VARCHAR2
						,p_newValue VARCHAR2 DEFAULT NULL
						,p_docId VARCHAR2
						,p_docRef VARCHAR2 DEFAULT NULL
						,p_pkValue VARCHAR2 DEFAULT NULL
						,p_context VARCHAR2 DEFAULT NULL
						,p_userType VARCHAR2 DEFAULT NULL
						,p_userId VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2 DEFAULT NULL
						,p_attributes VARCHAR2 DEFAULT NULL);

PROCEDURE raCustomerQuery( p_userId VARCHAR2 DEFAULT NULL
							 ,p_userType VARCHAR2 DEFAULT NULL
							 ,p_respId VARCHAR2);

FUNCTION viewSecureDocument( p_userId IN NUMBER, p_orgId IN NUMBER, p_context IN VARCHAR2)
RETURN BOOLEAN;*/
								
PROCEDURE QueryActions( p_context VARCHAR2 DEFAULT NULL,
						p_menuOption VARCHAR2, 
						p_description VARCHAR2,
						p_doc_attribute1 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute2 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute3 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute3_OP VARCHAR2 DEFAULT NULL,
					    p_doc_attribute4 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute4_OP VARCHAR2 DEFAULT NULL,
					    p_doc_attribute5 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute6 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute7 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute8 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute9 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute10 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute11 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute12 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute13 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute14 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute15 VARCHAR2 DEFAULT NULL,
					    p_Doc_Category NUMBER DEFAULT NULL,
					    p_org VARCHAR2 DEFAULT NULL,
					    p_scanned_date_from VARCHAR2 DEFAULT NULL,
					    p_scanned_date_to VARCHAR2 DEFAULT NULL,
					    p_indexed_date_from VARCHAR2 DEFAULT NULL,
					    p_indexed_date_to VARCHAR2 DEFAULT NULL,
					    p_userId NUMBER,
					    p_userType VARCHAR2,
					    p_respId VARCHAR2,
					    p_orgName VARCHAR2 DEFAULT NULL,
					    p_orderBy VARCHAR2 DEFAULT NULL,
					    p_dir VARCHAR2 DEFAULT NULL,
					    p_orgCount VARCHAR2 DEFAULT NULL);

PROCEDURE SearchActions( p_context VARCHAR2 DEFAULT NULL, 
						p_doc_attribute1 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute2 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute3 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute4 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute5 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute6 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute7 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute8 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute9 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute10 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute11 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute12 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute13 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute14 VARCHAR2 DEFAULT NULL,
					    p_doc_attribute15 VARCHAR2 DEFAULT NULL,
					    p_org VARCHAR2 DEFAULT NULL,
					    p_scanned_date_from VARCHAR2 DEFAULT NULL,
					    p_scanned_date_to VARCHAR2 DEFAULT NULL,
					    p_indexed_date_from VARCHAR2 DEFAULT NULL,
					    p_indexed_date_to VARCHAR2 DEFAULT NULL,
					    p_sqlSource	VARCHAR2 DEFAULT NULL,
					    p_col_count VARCHAR2 DEFAULT NULL,
					    p_userId VARCHAR2,
					    p_respId VARCHAR2,
					    p_orderBy VARCHAR2 DEFAULT NULL,
					    p_dir VARCHAR2 DEFAULT NULL);

PROCEDURE ImageDisplay( p_file_id VARCHAR2
						,p_document_id VARCHAR2
						,p_url VARCHAR2
						,p_context VARCHAR2
						,p_userId NUMBER
						,p_respId VARCHAR2);
					    					    
PROCEDURE ImageDetails( p_file_id VARCHAR2
						,p_document_id VARCHAR2
						,p_context VARCHAR2
						,p_navTo VARCHAR2 DEFAULT 'Back'
						,p_userId VARCHAR2 DEFAULT NULL
						,p_respId VARCHAR2);

PROCEDURE CountryInput( p_attrib VARCHAR2 DEFAULT '0'	
						,p_userId NUMBER DEFAULT NULL
						,p_context VARCHAR2);

FUNCTION getOrgList( p_userId NUMBER, p_context VARCHAR2) RETURN org_array; 
 
FUNCTION onMouseOver( p_mesg VARCHAR2) RETURN VARCHAR2;
							 
PROCEDURE ErrorWindow( p_errCode IN VARCHAR2 DEFAULT '-'
						, p_errMsg IN VARCHAR2 DEFAULT '-'
						, p_gisErr IN VARCHAR2 DEFAULT '-'
						, p_errorSource IN VARCHAR2 DEFAULT '-');
						

							 
FUNCTION js( p_body IN VARCHAR2) RETURN VARCHAR2;

FUNCTION showErr( p_gisErr VARCHAR2 DEFAULT NULL, p_errorSource IN VARCHAR2 DEFAULT NULL)
RETURN VARCHAR2;

FUNCTION secureDocument( p_secure IN stdVarchar)
RETURN VARCHAR2;

FUNCTION viewSecureDocument( p_userId IN NUMBER, p_orgId IN NUMBER, p_context IN VARCHAR2)
RETURN BOOLEAN;                                                      

FUNCTION validURLstring( stringIn VARCHAR DEFAULT '-') RETURN VARCHAR2;               

END gis_search;
/
