--
-- file: seed document category usage.sql
--
-- Purpose: To attach document categories to forms and functions
--
-- History: David Gough 18-04-2001 Initial version
--
-- NOTE for USAGE: Change the contents of the category array to the required category names
-- and the v_formFunctionName to the form / function that the categories need attaching
-- each time this script is used.
--

DECLARE
TYPE  tCategoryArray IS VARRAY(10) OF VARCHAR2(55);
cArray tCategoryArray:= tCategoryArray('GIS - Purchase Order'
										,'GIS - Cust Purchase Order');  -- categories which need attaching
n_doc_category_usage_id NUMBER(32);
v_formFunctionName VARCHAR2(55) := 'APXIWALL';  -- form to which the categories should be attached
n_attachment_function_id NUMBER(32);
n_category_id NUMBER(32);

BEGIN
-- get the attachment_function_id
    SELECT attachment_function_id
    INTO n_attachment_function_id
	FROM fnd_attachment_functions
	WHERE function_type = 'O'  -- form  'F' = function
	AND  function_name = v_formFunctionName;

-- loop for the number of categorys that need seeding
-- into fnd_doc_category_usages
	FOR i IN 1..cArray.last
 	LOOP

	 	SELECT fnd_doc_category_usages_s.nextval
	    INTO n_doc_category_usage_id
	    FROM dual;

        SELECT category_id
        INTO n_category_id
        FROM fnd_document_categories_tl
        WHERE user_name = cArray(i);

		dbms_output.put_line(to_char(n_category_id));
		INSERT INTO fnd_doc_category_usages( doc_category_usage_id
										,category_id
										,attachment_function_id
										,enabled_flag
										,creation_date
										,created_by
										,last_update_date
										,last_updated_by
										,last_update_login
										,format)
		SELECT  n_doc_category_usage_id
				,n_category_id
				,n_attachment_function_id
				,'Y'
				,SYSDATE
				,1
				,SYSDATE
				,1
				,1
				,NULL
		FROM DUAL
		WHERE NOT EXISTS (  select 'X'
							from fnd_doc_category_usages
							where n_category_id = category_id
							AND n_attachment_function_id = attachment_function_id);
	END LOOP;
	COMMIT;
END;

