-- ============================================================================
--
--   NAME
--      gis_doc_tables.sql
--
--   DESCRIPTION
--      Script to create the gis base tables
--
--   HISTORY
--      29/09/2000 David Gough Original version
--	    15/12/2000 David Gough gis_migrate_check added
--
-- ============================================================================

-- run in imaging schema

WHENEVER SQLERROR CONTINUE

--select * from user_tables ;
DROP TABLE GIS_DOC_STATUS;
CREATE TABLE GIS_DOC_STATUS
(document_id NUMBER(15) NOT NULL,
doc_status_type_id NUMBER(15) NOT NULL,
date_created DATE NOT NULL,
created_by NUMBER(15) NOT NULL,
last_update_date DATE NOT NULL,
last_updated_by NUMBER(15) NOT NULL)
TABLESPACE &table_t
STORAGE (initial 500K next 250K pctincrease 0 maxextents 200);

DROP TABLE GIS_DOC_STATUS_TYPES;
CREATE TABLE GIS_DOC_STATUS_TYPES
(doc_status_type_id NUMBER(15) NOT NULL,
doc_status_name VARCHAR2(50),
doc_status_description VARCHAR2(150),
date_created DATE NOT NULL,
created_by NUMBER(15) NOT NULL,
last_update_date DATE NOT NULL,
last_updated_by NUMBER(15) NOT NULL)
TABLESPACE &table_t
STORAGE (initial 500K next 250K pctincrease 0 maxextents 200);

DROP TABLE GIS_SCAN_USERS;
CREATE TABLE GIS_SCAN_USERS
(scanner_id VARCHAR2(15) NOT NULL,
fnd_user_id NUMBER(15) NOT NULL,
active_start_date DATE,
active_end_date DATE,
date_created DATE NOT NULL,
created_by NUMBER(15) NOT NULL,
last_update_date DATE NOT NULL,
last_updated_by NUMBER(15) NOT NULL,
attribute_category  VARCHAR2(25),
attribute1 VARCHAR2(150),
attribute2 VARCHAR2(150),
attribute3 VARCHAR2(150),
attribute4 VARCHAR2(150),
attribute5 VARCHAR2(150),
attribute6 VARCHAR2(150),
attribute7 VARCHAR2(150),
attribute8 VARCHAR2(150),
attribute9 VARCHAR2(150),
attribute10 VARCHAR2(150),
attribute11 VARCHAR2(150),
attribute12 VARCHAR2(150),
attribute13 VARCHAR2(150),
attribute14 VARCHAR2(150),
attribute15 VARCHAR2(150))
TABLESPACE &table_t
STORAGE (initial 500K next 250K pctincrease 0 maxextents 200);

DROP TABLE GIS_SCANNERS;
CREATE TABLE GIS_SCANNERS
(scanner_id VARCHAR2(15) NOT NULL,
organization_id NUMBER(15) NOT NULL,
ip_address VARCHAR2(25),
hostname VARCHAR2(50),
password VARCHAR2(25),
description VARCHAR2(150),
date_created DATE NOT NULL,
created_by NUMBER(15) NOT NULL,
last_update_date DATE NOT NULL,
last_updated_by NUMBER(15) NOT NULL,
attribute_category  VARCHAR2(25),
attribute1 VARCHAR2(150),
attribute2 VARCHAR2(150),
attribute3 VARCHAR2(150),
attribute4 VARCHAR2(150),
attribute5 VARCHAR2(150),
attribute6 VARCHAR2(150),
attribute7 VARCHAR2(150),
attribute8 VARCHAR2(150),
attribute9 VARCHAR2(150),
attribute10 VARCHAR2(150),
attribute11 VARCHAR2(150),
attribute12 VARCHAR2(150),
attribute13 VARCHAR2(150),
attribute14 VARCHAR2(150),
attribute15 VARCHAR2(150))
TABLESPACE &table_t
STORAGE (initial 500K next 250K pctincrease 0 maxextents 200);

/* Create gis_interface_all table */
DROP TABLE imaging.gis_interface_all;
CREATE TABLE imaging.gis_interface_all
(gis_id            number         not null,
 file_id           number         not null,
 gtn_id            number         not null,
 customer_id       number                 ,
 customer_name     varchar2(50)   not null,
 customer_number   varchar2(30)           ,
 order_type        varchar2(40)   not null,
 order_number      number                 ,
 order_amount      number                 ,
 interface_status  number         not null,
 status_date       date           not null,
 last_error_id     number                 ,
 last_updated_by   number(15)     not null,
 last_update_date  date           not null,
 created_by        number(15)     not null,
 creation_date     date           not null,
 org_id            number(15)     default to_number(decode(substr(userenv('CLIENT_INFO'),1,1),' ',null,substr(userenv('CLIENT_INFO'),1,10)))
)
TABLESPACE &table_t
STORAGE (initial 500K next 250K pctincrease 0 maxextents 200);

/* Create gis_error_log_all table */
DROP TABLE imaging.gis_error_log_all;
CREATE TABLE imaging.gis_error_log_all
(error_id          number         not null,
 file_id           number         not null,
 object_name       varchar2(240)          ,
 input_parameters  varchar2(240)          ,
 event             varchar2(240)          ,
 system_error      varchar2(240)          ,
 status_error      varchar2(240)          ,
 last_updated_by   number(15)     not null,
 last_update_date  date           not null,
 last_update_login number(15)             ,
 created_by        number(15)     not null,
 creation_date     date           not null,
 org_id            number(15)     default to_number(decode(substr(userenv('CLIENT_INFO'),1,1),' ',null,substr(userenv('CLIENT_INFO'),1,10)))
)
TABLESPACE &table_t
STORAGE (initial 500K next 250K pctincrease 0 maxextents 200);

/* Create gis_event_log_all table */
DROP TABLE imaging.gis_event_log_all;
CREATE TABLE imaging.gis_event_log_all
(event_id          number(15)     not null,
 file_id           number(15)     not null,
 gtn_id            number(15)     not null,
 object_name       varchar2(240)           ,
 input_parameters  varchar2(240)          ,
 error_event       varchar2(240)          ,
 error_message     varchar2(240)          ,
 last_updated_by   number(15)     not null,
 last_update_date  date           not null,
 last_update_login number(15)             ,
 created_by        number(15)     not null,
 creation_date     date           not null,
 org_id            number(15)         default to_number(decode(substr(userenv('CLIENT_INFO'),1,1),' ',null,substr(userenv('CLIENT_INFO'),1,10)))
)
TABLESPACE &table_t
STORAGE (initial 500K next 250K pctincrease 0 maxextents 200);

DROP TABLE imaging.gis_migrate_check;
CREATE TABLE imaging.gis_migrate_check
(VS_DOCID     NUMBER(15) NOT NULL,
 DOC_TYPE     VARCHAR2(10),
 AGREEMENT_ID NUMBER(15),
 HEADER_ID    NUMBER(15),
 CUSTOMER_ID  NUMBER(15),
 PROJECT_ID   NUMBER(15),
 INVOICE_ID   NUMBER(15),
 GSR_ID       NUMBER(15),
 COMMENTS     VARCHAR2(121)
 )
TABLESPACE &table_t
STORAGE (initial 5000K next 1000K pctincrease 0 maxextents 200);

COMMIT;
/
