-- ============================================================================
--
--   NAME
--      apps_views.sql
--
--   DESCRIPTION
--      Script to create views required for GIS in APPS schema
--
--   HISTORY
--      01/03/2001 Patrick Low - Original version
--      29/03/2001 Patrick Low - Added country code
--      18/05/2001 Patrick Low - Added status + performance tuning
--		08/06/2001 David Gough - Added new version of fnd_documents_vl
--								 view for secure document functionality
--
-- ============================================================================

/*****************************/
/* Run as apps user          */
/*****************************/
connect &&apps_usr/&&apps_pwd
/* Create gis_metrics_report_v view */

CREATE OR REPLACE VIEW GIS_METRICS_REPORT_V AS
SELECT s.document_id document_id,
       t.doc_attribute_category lob,
       gis_report_pkg.doctype(s.document_id) document_type,
       DECODE(t.doc_attribute_category, 'Order Management', 
       gis_report_pkg.lic_ord_value(s.document_id,'LICENSE'), NULL) 
						license_value,
       DECODE(t.doc_attribute_category, 'Order Management', 
       gis_report_pkg.lic_ord_value(s.document_id,'ORDER'), NULL) 
						order_value,
       gis_report_pkg.namedate(s.document_id, 'DATE', 1) create_date,
       gis_report_pkg.namedate(s.document_id, 'BYWHOM', 1) create_by,
       gis_report_pkg.namedate(s.document_id, 'DATE', 2) pending_date,
       gis_report_pkg.namedate(s.document_id, 'BYWHOM', 2) pending_by,
       gis_report_pkg.namedate(s.document_id, 'DATE', 3) preindex_date,
       gis_report_pkg.namedate(s.document_id, 'BYWHOM', 3) preindex_by,
       gis_report_pkg.namedate(s.document_id, 'DATE', 4) processed_date,
       gis_report_pkg.namedate(s.document_id, 'BYWHOM', 4) processed_by,
       gis_report_pkg.namedate(s.document_id, 'DATE', 5) rejected_date,
       gis_report_pkg.namedate(s.document_id, 'BYWHOM', 5) rejected_by,
       gis_report_pkg.namedate(s.document_id, 'DATE', 6) completed_date,
       gis_report_pkg.namedate(s.document_id, 'BYWHOM', 6) completed_by,
       gis_report_pkg.namedate(s.document_id, 'DATE', 7) reprocessing_date,
       gis_report_pkg.namedate(s.document_id, 'BYWHOM', 7) reprocessing_by,
       s.scanner_id scanner_id,
       s.organization_id organization_id,
       b.legislation_code country,
       DECODE(v.context_value,
              'Agreements', v.agreement_name,
              'Customer', v.customer_name,
              'Order Management', v.oe_number,
              'Payables', v.invoice_number || ' - ' || v.supplier_name,
              'Projects', v.project_number,
              'Receivables', v.invoice_number,
              'Contracts', v.contracts_number || DECODE(v.contracts_modifier, NULL, NULL, ' - ' || v.contracts_modifier),
              'Web Expenses', v.expense_report_number) document_reference,
       v.index_status_id status
FROM   gis_doc_status s, fnd_documents_tl t, fnd_lobs l, gis_scanners s, per_business_groups b, fnd_documents_tl_dfv v
WHERE  s.document_id = t.document_id
AND    t.media_id = l.file_id
AND    l.file_name LIKE s.scanner_id || '%'
AND    l.program_name = 'GIS'
AND    l.program_tag = s.scanner_id
AND    s.organization_id = b.organization_id
AND    t.rowid = v.rowid
GROUP BY s.document_id, t.doc_attribute_category, 
	 s.scanner_id, s.organization_id, b.legislation_code,
         DECODE(v.context_value,
                'Agreements', v.agreement_name,
                'Customer', v.customer_name,
                'Order Management', v.oe_number,
                'Payables', v.invoice_number || ' - ' || v.supplier_name,
                'Projects', v.project_number,
                'Receivables', v.invoice_number,
                'Contracts', v.contracts_number || DECODE(v.contracts_modifier, NULL, NULL, ' - ' || v.contracts_modifier),
                'Web Expenses', v.expense_report_number),
         v.index_status_id;

-- new  FND_DOCUMENTS_VL view for secure document
-- functionality
CREATE OR REPLACE VIEW FND_DOCUMENTS_VL(ROW_ID
		,DOCUMENT_ID
		,CREATION_DATE
		,CREATED_BY
		,LAST_UPDATE_DATE
		,LAST_UPDATED_BY
		,LAST_UPDATE_LOGIN
		,DATATYPE_ID
		,DATATYPE_NAME
		,DESCRIPTION
		,FILE_NAME
		,MEDIA_ID
		,STORAGE_TYPE
		,CATEGORY_APPLICATION_ID
		,CATEGORY_ID
		,CATEGORY_DESCRIPTION
		,SECURITY_TYPE
		,SECURITY_ID
		,PUBLISH_FLAG
		,IMAGE_TYPE
		,USAGE_TYPE
		,USAGE_TYPE_DESCR
		,START_DATE_ACTIVE
		,END_DATE_ACTIVE
		,REQUEST_ID
		,PROGRAM_APPLICATION_ID
		,PROGRAM_ID
		,PROGRAM_UPDATE_DATE
		,DOC_ATTRIBUTE_CATEGORY
		,DOC_ATTRIBUTE1
		,DOC_ATTRIBUTE2
		,DOC_ATTRIBUTE3
		,DOC_ATTRIBUTE4
		,DOC_ATTRIBUTE5
		,DOC_ATTRIBUTE6
		,DOC_ATTRIBUTE7
		,DOC_ATTRIBUTE8
		,DOC_ATTRIBUTE9
		,DOC_ATTRIBUTE10
		,DOC_ATTRIBUTE11
		,DOC_ATTRIBUTE12
		,DOC_ATTRIBUTE13
		,DOC_ATTRIBUTE14
		,DOC_ATTRIBUTE15) AS
SELECT D.ROWID
, D.DOCUMENT_ID
, D.CREATION_DATE
, D.CREATED_BY
, D.LAST_UPDATE_DATE
, D.LAST_UPDATED_BY
, D.LAST_UPDATE_LOGIN
, D.DATATYPE_ID
, DD.USER_NAME
, DL.DESCRIPTION
, DL.FILE_NAME
, DL.MEDIA_ID
, D.STORAGE_TYPE
, C.APPLICATION_ID
, D.CATEGORY_ID
, CL.USER_NAME
, D.SECURITY_TYPE
, D.SECURITY_ID
, D.PUBLISH_FLAG
, D.IMAGE_TYPE
, D.USAGE_TYPE
, L.MEANING
, D.START_DATE_ACTIVE
, D.END_DATE_ACTIVE
, D.REQUEST_ID
, D.PROGRAM_APPLICATION_ID
, D.PROGRAM_ID
, D.PROGRAM_UPDATE_DATE
, DL.DOC_ATTRIBUTE_CATEGORY
, DL.DOC_ATTRIBUTE1
, DL.DOC_ATTRIBUTE2
, DL.DOC_ATTRIBUTE3
, DL.DOC_ATTRIBUTE4
, DL.DOC_ATTRIBUTE5
, DL.DOC_ATTRIBUTE6
, DL.DOC_ATTRIBUTE7
, DL.DOC_ATTRIBUTE8
, DL.DOC_ATTRIBUTE9
, DL.DOC_ATTRIBUTE10
, DL.DOC_ATTRIBUTE11
, DL.DOC_ATTRIBUTE12
, DL.DOC_ATTRIBUTE13
, DL.DOC_ATTRIBUTE14
, DL.DOC_ATTRIBUTE15
FROM FND_DOCUMENT_CATEGORIES_TL CL
, FND_DOCUMENT_CATEGORIES C
, FND_DOCUMENT_DATATYPES DD
, FND_LOOKUP_VALUES L
, FND_DOCUMENTS_TL DL
, FND_DOCUMENTS D
WHERE D.DOCUMENT_ID = DL.DOCUMENT_ID
AND DL.LANGUAGE= USERENV('LANG')
AND D.DATATYPE_ID = DD.DATATYPE_ID
AND DD.LANGUAGE = USERENV('LANG')
AND D.CATEGORY_ID = C.CATEGORY_ID
AND C.CATEGORY_ID = CL.CATEGORY_ID
AND CL.LANGUAGE = USERENV('LANG')
AND D.USAGE_TYPE = L.LOOKUP_CODE
AND L.LANGUAGE = USERENV('LANG')
AND L.LOOKUP_TYPE = 'ATCHMT_DOCUMENT_TYPE'
AND NVL(C.ATTRIBUTE2,'OPEN') != 'SECURE'; 
-- DG added this attribute flag to prevent 
-- secure documents being viewed in
-- the document cataloger
COMMIT;
/
